@@ -1,5 +1,5 @@
 from . import dc
-from . import logger
+from . import exception
 from . import util
 from .header import Header
 from .header_map import HeaderMap
@@ -31,4 +31,6 @@ from . import currencies
 from . import related_records
 from . import record
 from . import blue_print
-from . import file
\ No newline at end of file
+from . import file
+from . import notification
+from . import query
