@@ -1,9 +1,9 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class Attachment(object):
@@ -52,7 +52,7 @@ class Attachment(object):
 		except Exception:
 			from ..users import User
 
-		if not isinstance(owner, User):
+		if owner is not None and not isinstance(owner, User):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: owner EXPECTED TYPE: User', None, None)
 		
 		self.__owner = owner
@@ -78,7 +78,7 @@ class Attachment(object):
 
 		from datetime import datetime
 
-		if not isinstance(modified_time, datetime):
+		if modified_time is not None and not isinstance(modified_time, datetime):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modified_time EXPECTED TYPE: datetime', None, None)
 		
 		self.__modified_time = modified_time
@@ -99,10 +99,10 @@ class Attachment(object):
 		The method to set the value to file_name
 
 		Parameters:
-			file_name (string) : A string value
+			file_name (string) : A string representing the file_name
 		"""
 
-		if not isinstance(file_name, str):
+		if file_name is not None and not isinstance(file_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: file_name EXPECTED TYPE: str', None, None)
 		
 		self.__file_name = file_name
@@ -128,7 +128,7 @@ class Attachment(object):
 
 		from datetime import datetime
 
-		if not isinstance(created_time, datetime):
+		if created_time is not None and not isinstance(created_time, datetime):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: created_time EXPECTED TYPE: datetime', None, None)
 		
 		self.__created_time = created_time
@@ -149,10 +149,10 @@ class Attachment(object):
 		The method to set the value to size
 
 		Parameters:
-			size (int) : A int value
+			size (int) : An int representing the size
 		"""
 
-		if not isinstance(size, int):
+		if size is not None and not isinstance(size, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: size EXPECTED TYPE: int', None, None)
 		
 		self.__size = size
@@ -181,7 +181,7 @@ class Attachment(object):
 		except Exception:
 			from ..record import Record
 
-		if not isinstance(parent_id, Record):
+		if parent_id is not None and not isinstance(parent_id, Record):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: parent_id EXPECTED TYPE: Record', None, None)
 		
 		self.__parent_id = parent_id
@@ -202,10 +202,10 @@ class Attachment(object):
 		The method to set the value to editable
 
 		Parameters:
-			editable (bool) : A bool value
+			editable (bool) : A bool representing the editable
 		"""
 
-		if not isinstance(editable, bool):
+		if editable is not None and not isinstance(editable, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: editable EXPECTED TYPE: bool', None, None)
 		
 		self.__editable = editable
@@ -226,10 +226,10 @@ class Attachment(object):
 		The method to set the value to file_id
 
 		Parameters:
-			file_id (string) : A string value
+			file_id (string) : A string representing the file_id
 		"""
 
-		if not isinstance(file_id, str):
+		if file_id is not None and not isinstance(file_id, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: file_id EXPECTED TYPE: str', None, None)
 		
 		self.__file_id = file_id
@@ -250,10 +250,10 @@ class Attachment(object):
 		The method to set the value to type
 
 		Parameters:
-			type (string) : A string value
+			type (string) : A string representing the type
 		"""
 
-		if not isinstance(type, str):
+		if type is not None and not isinstance(type, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: type EXPECTED TYPE: str', None, None)
 		
 		self.__type = type
@@ -274,10 +274,10 @@ class Attachment(object):
 		The method to set the value to se_module
 
 		Parameters:
-			se_module (string) : A string value
+			se_module (string) : A string representing the se_module
 		"""
 
-		if not isinstance(se_module, str):
+		if se_module is not None and not isinstance(se_module, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: se_module EXPECTED TYPE: str', None, None)
 		
 		self.__se_module = se_module
@@ -306,7 +306,7 @@ class Attachment(object):
 		except Exception:
 			from ..users import User
 
-		if not isinstance(modified_by, User):
+		if modified_by is not None and not isinstance(modified_by, User):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modified_by EXPECTED TYPE: User', None, None)
 		
 		self.__modified_by = modified_by
@@ -327,10 +327,10 @@ class Attachment(object):
 		The method to set the value to state
 
 		Parameters:
-			state (string) : A string value
+			state (string) : A string representing the state
 		"""
 
-		if not isinstance(state, str):
+		if state is not None and not isinstance(state, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: state EXPECTED TYPE: str', None, None)
 		
 		self.__state = state
@@ -341,7 +341,7 @@ class Attachment(object):
 		The method to get the id
 
 		Returns:
-			string: A string value
+			int: A int value
 		"""
 
 		return self.__id
@@ -351,11 +351,11 @@ class Attachment(object):
 		The method to set the value to id
 
 		Parameters:
-			id (string) : A string value
+			id (int) : An int representing the id
 		"""
 
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		self.__id = id
 		self.__key_modified['id'] = 1
@@ -383,7 +383,7 @@ class Attachment(object):
 		except Exception:
 			from ..users import User
 
-		if not isinstance(created_by, User):
+		if created_by is not None and not isinstance(created_by, User):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: created_by EXPECTED TYPE: User', None, None)
 		
 		self.__created_by = created_by
@@ -404,10 +404,10 @@ class Attachment(object):
 		The method to set the value to link_url
 
 		Parameters:
-			link_url (string) : A string value
+			link_url (string) : A string representing the link_url
 		"""
 
-		if not isinstance(link_url, str):
+		if link_url is not None and not isinstance(link_url, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: link_url EXPECTED TYPE: str', None, None)
 		
 		self.__link_url = link_url
@@ -428,10 +428,10 @@ class Attachment(object):
 		The method to set the value to description
 
 		Parameters:
-			description (string) : A string value
+			description (string) : A string representing the description
 		"""
 
-		if not isinstance(description, str):
+		if description is not None and not isinstance(description, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: description EXPECTED TYPE: str', None, None)
 		
 		self.__description = description
@@ -452,10 +452,10 @@ class Attachment(object):
 		The method to set the value to category
 
 		Parameters:
-			category (string) : A string value
+			category (string) : A string representing the category
 		"""
 
-		if not isinstance(category, str):
+		if category is not None and not isinstance(category, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: category EXPECTED TYPE: str', None, None)
 		
 		self.__category = category
@@ -466,13 +466,13 @@ class Attachment(object):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -485,14 +485,14 @@ class Attachment(object):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
