@@ -1,13 +1,13 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.parameter_map import ParameterMap
 	from zcrmsdk.src.com.zoho.crm.api.util import APIResponse, CommonAPIHandler, Constants
 	from zcrmsdk.src.com.zoho.crm.api.param import Param
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..parameter_map import ParameterMap
 	from ..util import APIResponse, CommonAPIHandler, Constants
 	from ..param import Param
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class AttachmentsOperations(object):
@@ -16,14 +16,14 @@ class AttachmentsOperations(object):
 		Creates an instance of AttachmentsOperations with the given parameters
 
 		Parameters:
-			record_id (string) : A string value
-			module_api_name (string) : A string value
+			record_id (int) : An int representing the record_id
+			module_api_name (string) : A string representing the module_api_name
 		"""
 
-		if not isinstance(record_id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: record_id EXPECTED TYPE: str', None, None)
+		if record_id is not None and not isinstance(record_id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: record_id EXPECTED TYPE: int', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		self.__record_id = record_id
@@ -35,14 +35,17 @@ class AttachmentsOperations(object):
 		The method to download attachment
 
 		Parameters:
-			id (string) : A string value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -54,6 +57,7 @@ class AttachmentsOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.attachments.response_handler import ResponseHandler
 		except Exception:
@@ -65,14 +69,17 @@ class AttachmentsOperations(object):
 		The method to delete attachment
 
 		Parameters:
-			id (string) : A string value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -84,6 +91,7 @@ class AttachmentsOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.attachments.action_handler import ActionHandler
 		except Exception:
@@ -96,6 +104,9 @@ class AttachmentsOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		handler_instance = CommonAPIHandler()
@@ -107,6 +118,7 @@ class AttachmentsOperations(object):
 		api_path = api_path + '/Attachments'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.attachments.response_handler import ResponseHandler
 		except Exception:
@@ -122,6 +134,9 @@ class AttachmentsOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -129,7 +144,7 @@ class AttachmentsOperations(object):
 		except Exception:
 			from .file_body_wrapper import FileBodyWrapper
 
-		if not isinstance(request, FileBodyWrapper):
+		if request is not None and not isinstance(request, FileBodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: FileBodyWrapper', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -141,8 +156,10 @@ class AttachmentsOperations(object):
 		api_path = api_path + '/Attachments'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.content_type = 'multipart/form-data'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.attachments.action_handler import ActionHandler
 		except Exception:
@@ -158,6 +175,9 @@ class AttachmentsOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
@@ -172,7 +192,9 @@ class AttachmentsOperations(object):
 		api_path = api_path + '/Attachments'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.param = param_instance
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.attachments.action_handler import ActionHandler
 		except Exception:
@@ -188,6 +210,9 @@ class AttachmentsOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
@@ -202,6 +227,7 @@ class AttachmentsOperations(object):
 		api_path = api_path + '/Attachments'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
 		handler_instance.param = param_instance
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.attachments.action_handler import ActionHandler
@@ -216,4 +242,3 @@ class UploadLinkAttachmentParam(object):
 
 class DeleteAttachmentsParam(object):
 	ids = Param('ids', 'com.zoho.crm.api.Attachments.DeleteAttachmentsParam')
-
