@@ -1,10 +1,10 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.attachments.response_handler import ResponseHandler
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from .response_handler import ResponseHandler
 
 
@@ -14,6 +14,7 @@ class ResponseWrapper(ResponseHandler):
 		super().__init__()
 
 		self.__data = None
+		self.__info = None
 		self.__key_modified = dict()
 
 	def get_data(self):
@@ -34,24 +35,53 @@ class ResponseWrapper(ResponseHandler):
 			data (list) : An instance of list
 		"""
 
-		if not isinstance(data, list):
+		if data is not None and not isinstance(data, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: data EXPECTED TYPE: list', None, None)
 		
 		self.__data = data
 		self.__key_modified['data'] = 1
 
+	def get_info(self):
+		"""
+		The method to get the info
+
+		Returns:
+			Info: An instance of Info
+		"""
+
+		return self.__info
+
+	def set_info(self, info):
+		"""
+		The method to set the value to info
+
+		Parameters:
+			info (Info) : An instance of Info
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record import Info
+		except Exception:
+			from ..record import Info
+
+		if info is not None and not isinstance(info, Info):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: info EXPECTED TYPE: Info', None, None)
+		
+		self.__info = info
+		self.__key_modified['info'] = 1
+
 	def is_key_modified(self, key):
 		"""
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -64,14 +94,14 @@ class ResponseWrapper(ResponseHandler):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
