@@ -1,9 +1,9 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class ProcessInfo(object):
@@ -37,10 +37,10 @@ class ProcessInfo(object):
 		The method to set the value to field_id
 
 		Parameters:
-			field_id (string) : A string value
+			field_id (string) : A string representing the field_id
 		"""
 
-		if not isinstance(field_id, str):
+		if field_id is not None and not isinstance(field_id, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: field_id EXPECTED TYPE: str', None, None)
 		
 		self.__field_id = field_id
@@ -61,10 +61,10 @@ class ProcessInfo(object):
 		The method to set the value to is_continuous
 
 		Parameters:
-			is_continuous (bool) : A bool value
+			is_continuous (bool) : A bool representing the is_continuous
 		"""
 
-		if not isinstance(is_continuous, bool):
+		if is_continuous is not None and not isinstance(is_continuous, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: is_continuous EXPECTED TYPE: bool', None, None)
 		
 		self.__is_continuous = is_continuous
@@ -85,10 +85,10 @@ class ProcessInfo(object):
 		The method to set the value to api_name
 
 		Parameters:
-			api_name (string) : A string value
+			api_name (string) : A string representing the api_name
 		"""
 
-		if not isinstance(api_name, str):
+		if api_name is not None and not isinstance(api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: api_name EXPECTED TYPE: str', None, None)
 		
 		self.__api_name = api_name
@@ -109,10 +109,10 @@ class ProcessInfo(object):
 		The method to set the value to continuous
 
 		Parameters:
-			continuous (bool) : A bool value
+			continuous (bool) : A bool representing the continuous
 		"""
 
-		if not isinstance(continuous, bool):
+		if continuous is not None and not isinstance(continuous, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: continuous EXPECTED TYPE: bool', None, None)
 		
 		self.__continuous = continuous
@@ -133,10 +133,10 @@ class ProcessInfo(object):
 		The method to set the value to field_label
 
 		Parameters:
-			field_label (string) : A string value
+			field_label (string) : A string representing the field_label
 		"""
 
-		if not isinstance(field_label, str):
+		if field_label is not None and not isinstance(field_label, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: field_label EXPECTED TYPE: str', None, None)
 		
 		self.__field_label = field_label
@@ -157,10 +157,10 @@ class ProcessInfo(object):
 		The method to set the value to name
 
 		Parameters:
-			name (string) : A string value
+			name (string) : A string representing the name
 		"""
 
-		if not isinstance(name, str):
+		if name is not None and not isinstance(name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: name EXPECTED TYPE: str', None, None)
 		
 		self.__name = name
@@ -181,10 +181,10 @@ class ProcessInfo(object):
 		The method to set the value to column_name
 
 		Parameters:
-			column_name (string) : A string value
+			column_name (string) : A string representing the column_name
 		"""
 
-		if not isinstance(column_name, str):
+		if column_name is not None and not isinstance(column_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: column_name EXPECTED TYPE: str', None, None)
 		
 		self.__column_name = column_name
@@ -205,10 +205,10 @@ class ProcessInfo(object):
 		The method to set the value to field_value
 
 		Parameters:
-			field_value (string) : A string value
+			field_value (string) : A string representing the field_value
 		"""
 
-		if not isinstance(field_value, str):
+		if field_value is not None and not isinstance(field_value, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: field_value EXPECTED TYPE: str', None, None)
 		
 		self.__field_value = field_value
@@ -219,7 +219,7 @@ class ProcessInfo(object):
 		The method to get the id
 
 		Returns:
-			string: A string value
+			int: A int value
 		"""
 
 		return self.__id
@@ -229,11 +229,11 @@ class ProcessInfo(object):
 		The method to set the value to id
 
 		Parameters:
-			id (string) : A string value
+			id (int) : An int representing the id
 		"""
 
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		self.__id = id
 		self.__key_modified['id'] = 1
@@ -253,10 +253,10 @@ class ProcessInfo(object):
 		The method to set the value to field_name
 
 		Parameters:
-			field_name (string) : A string value
+			field_name (string) : A string representing the field_name
 		"""
 
-		if not isinstance(field_name, str):
+		if field_name is not None and not isinstance(field_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: field_name EXPECTED TYPE: str', None, None)
 		
 		self.__field_name = field_name
@@ -267,13 +267,13 @@ class ProcessInfo(object):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -286,14 +286,14 @@ class ProcessInfo(object):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
