@@ -1,9 +1,9 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class Transition(object):
@@ -39,7 +39,7 @@ class Transition(object):
 			next_transitions (list) : An instance of list
 		"""
 
-		if not isinstance(next_transitions, list):
+		if next_transitions is not None and not isinstance(next_transitions, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: next_transitions EXPECTED TYPE: list', None, None)
 		
 		self.__next_transitions = next_transitions
@@ -60,10 +60,10 @@ class Transition(object):
 		The method to set the value to percent_partial_save
 
 		Parameters:
-			percent_partial_save (float) : A float value
+			percent_partial_save (float) : A float representing the percent_partial_save
 		"""
 
-		if not isinstance(percent_partial_save, float):
+		if percent_partial_save is not None and not isinstance(percent_partial_save, float):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: percent_partial_save EXPECTED TYPE: float', None, None)
 		
 		self.__percent_partial_save = percent_partial_save
@@ -92,7 +92,7 @@ class Transition(object):
 		except Exception:
 			from ..record import Record
 
-		if not isinstance(data, Record):
+		if data is not None and not isinstance(data, Record):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: data EXPECTED TYPE: Record', None, None)
 		
 		self.__data = data
@@ -113,10 +113,10 @@ class Transition(object):
 		The method to set the value to next_field_value
 
 		Parameters:
-			next_field_value (string) : A string value
+			next_field_value (string) : A string representing the next_field_value
 		"""
 
-		if not isinstance(next_field_value, str):
+		if next_field_value is not None and not isinstance(next_field_value, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: next_field_value EXPECTED TYPE: str', None, None)
 		
 		self.__next_field_value = next_field_value
@@ -137,10 +137,10 @@ class Transition(object):
 		The method to set the value to name
 
 		Parameters:
-			name (string) : A string value
+			name (string) : A string representing the name
 		"""
 
-		if not isinstance(name, str):
+		if name is not None and not isinstance(name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: name EXPECTED TYPE: str', None, None)
 		
 		self.__name = name
@@ -161,10 +161,10 @@ class Transition(object):
 		The method to set the value to criteria_matched
 
 		Parameters:
-			criteria_matched (bool) : A bool value
+			criteria_matched (bool) : A bool representing the criteria_matched
 		"""
 
-		if not isinstance(criteria_matched, bool):
+		if criteria_matched is not None and not isinstance(criteria_matched, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: criteria_matched EXPECTED TYPE: bool', None, None)
 		
 		self.__criteria_matched = criteria_matched
@@ -175,7 +175,7 @@ class Transition(object):
 		The method to get the id
 
 		Returns:
-			string: A string value
+			int: A int value
 		"""
 
 		return self.__id
@@ -185,11 +185,11 @@ class Transition(object):
 		The method to set the value to id
 
 		Parameters:
-			id (string) : A string value
+			id (int) : An int representing the id
 		"""
 
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		self.__id = id
 		self.__key_modified['id'] = 1
@@ -212,7 +212,7 @@ class Transition(object):
 			fields (list) : An instance of list
 		"""
 
-		if not isinstance(fields, list):
+		if fields is not None and not isinstance(fields, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: fields EXPECTED TYPE: list', None, None)
 		
 		self.__fields = fields
@@ -233,10 +233,10 @@ class Transition(object):
 		The method to set the value to criteria_message
 
 		Parameters:
-			criteria_message (string) : A string value
+			criteria_message (string) : A string representing the criteria_message
 		"""
 
-		if not isinstance(criteria_message, str):
+		if criteria_message is not None and not isinstance(criteria_message, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: criteria_message EXPECTED TYPE: str', None, None)
 		
 		self.__criteria_message = criteria_message
@@ -247,13 +247,13 @@ class Transition(object):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -266,14 +266,14 @@ class Transition(object):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
