@@ -1,10 +1,10 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.bulk_read.action_handler import ActionHandler
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from .action_handler import ActionHandler
 
 
@@ -35,7 +35,7 @@ class ActionWrapper(ActionHandler):
 			data (list) : An instance of list
 		"""
 
-		if not isinstance(data, list):
+		if data is not None and not isinstance(data, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: data EXPECTED TYPE: list', None, None)
 		
 		self.__data = data
@@ -59,7 +59,7 @@ class ActionWrapper(ActionHandler):
 			info (dict) : An instance of dict
 		"""
 
-		if not isinstance(info, dict):
+		if info is not None and not isinstance(info, dict):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: info EXPECTED TYPE: dict', None, None)
 		
 		self.__info = info
@@ -70,13 +70,13 @@ class ActionWrapper(ActionHandler):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -89,14 +89,14 @@ class ActionWrapper(ActionHandler):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
