@@ -1,11 +1,11 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import APIResponse, CommonAPIHandler, Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.header import Header
 	from zcrmsdk.src.com.zoho.crm.api.header_map import HeaderMap
 except Exception:
+	from ..exception import SDKException
 	from ..util import APIResponse, CommonAPIHandler, Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from ..header import Header
 	from ..header_map import HeaderMap
 
@@ -25,6 +25,9 @@ class BulkWriteOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -32,7 +35,7 @@ class BulkWriteOperations(object):
 		except Exception:
 			from .file_body_wrapper import FileBodyWrapper
 
-		if not isinstance(request, FileBodyWrapper):
+		if request is not None and not isinstance(request, FileBodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: FileBodyWrapper', None, None)
 		
 		if header_instance is not None and not isinstance(header_instance, HeaderMap):
@@ -43,8 +46,10 @@ class BulkWriteOperations(object):
 		api_path = api_path + 'https://content.zohoapis.com/crm/v2/upload'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.content_type = 'multipart/form-data'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		handler_instance.header = header_instance
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.bulk_write.action_response import ActionResponse
@@ -61,6 +66,9 @@ class BulkWriteOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -68,7 +76,7 @@ class BulkWriteOperations(object):
 		except Exception:
 			from .request_wrapper import RequestWrapper
 
-		if not isinstance(request, RequestWrapper):
+		if request is not None and not isinstance(request, RequestWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: RequestWrapper', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -76,8 +84,10 @@ class BulkWriteOperations(object):
 		api_path = api_path + '/crm/bulk/v2/write'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.bulk_write.action_response import ActionResponse
 		except Exception:
@@ -89,14 +99,17 @@ class BulkWriteOperations(object):
 		The method to get bulk write job details
 
 		Parameters:
-			job_id (string) : A string value
+			job_id (int) : An int representing the job_id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
-		if not isinstance(job_id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: job_id EXPECTED TYPE: str', None, None)
+		if job_id is not None and not isinstance(job_id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: job_id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -104,6 +117,7 @@ class BulkWriteOperations(object):
 		api_path = api_path + str(job_id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.bulk_write.response_wrapper import ResponseWrapper
 		except Exception:
@@ -115,13 +129,16 @@ class BulkWriteOperations(object):
 		The method to download bulk write result
 
 		Parameters:
-			download_url (string) : A string value
+			download_url (string) : A string representing the download_url
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
-		if not isinstance(download_url, str):
+		if download_url is not None and not isinstance(download_url, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: download_url EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -130,6 +147,7 @@ class BulkWriteOperations(object):
 		api_path = api_path + str(download_url)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.bulk_write.response_handler import ResponseHandler
 		except Exception:
@@ -139,6 +157,4 @@ class BulkWriteOperations(object):
 
 class UploadFileHeader(object):
 	feature = Header('feature', 'com.zoho.crm.api.BulkWrite.UploadFileHeader')
-
 	x_crm_org = Header('X-CRM-ORG', 'com.zoho.crm.api.BulkWrite.UploadFileHeader')
-
