@@ -1,9 +1,9 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Choice, Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..util import Choice, Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class Resource(object):
@@ -38,7 +38,7 @@ class Resource(object):
 			status (Choice) : An instance of Choice
 		"""
 
-		if not isinstance(status, Choice):
+		if status is not None and not isinstance(status, Choice):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: status EXPECTED TYPE: Choice', None, None)
 		
 		self.__status = status
@@ -62,7 +62,7 @@ class Resource(object):
 			type (Choice) : An instance of Choice
 		"""
 
-		if not isinstance(type, Choice):
+		if type is not None and not isinstance(type, Choice):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: type EXPECTED TYPE: Choice', None, None)
 		
 		self.__type = type
@@ -83,10 +83,10 @@ class Resource(object):
 		The method to set the value to module
 
 		Parameters:
-			module (string) : A string value
+			module (string) : A string representing the module
 		"""
 
-		if not isinstance(module, str):
+		if module is not None and not isinstance(module, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module EXPECTED TYPE: str', None, None)
 		
 		self.__module = module
@@ -107,10 +107,10 @@ class Resource(object):
 		The method to set the value to file_id
 
 		Parameters:
-			file_id (string) : A string value
+			file_id (string) : A string representing the file_id
 		"""
 
-		if not isinstance(file_id, str):
+		if file_id is not None and not isinstance(file_id, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: file_id EXPECTED TYPE: str', None, None)
 		
 		self.__file_id = file_id
@@ -131,10 +131,10 @@ class Resource(object):
 		The method to set the value to ignore_empty
 
 		Parameters:
-			ignore_empty (bool) : A bool value
+			ignore_empty (bool) : A bool representing the ignore_empty
 		"""
 
-		if not isinstance(ignore_empty, bool):
+		if ignore_empty is not None and not isinstance(ignore_empty, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: ignore_empty EXPECTED TYPE: bool', None, None)
 		
 		self.__ignore_empty = ignore_empty
@@ -155,10 +155,10 @@ class Resource(object):
 		The method to set the value to find_by
 
 		Parameters:
-			find_by (string) : A string value
+			find_by (string) : A string representing the find_by
 		"""
 
-		if not isinstance(find_by, str):
+		if find_by is not None and not isinstance(find_by, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: find_by EXPECTED TYPE: str', None, None)
 		
 		self.__find_by = find_by
@@ -182,7 +182,7 @@ class Resource(object):
 			field_mappings (list) : An instance of list
 		"""
 
-		if not isinstance(field_mappings, list):
+		if field_mappings is not None and not isinstance(field_mappings, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: field_mappings EXPECTED TYPE: list', None, None)
 		
 		self.__field_mappings = field_mappings
@@ -211,7 +211,7 @@ class Resource(object):
 		except Exception:
 			from .file import File
 
-		if not isinstance(file, File):
+		if file is not None and not isinstance(file, File):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: file EXPECTED TYPE: File', None, None)
 		
 		self.__file = file
@@ -222,13 +222,13 @@ class Resource(object):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -241,14 +241,14 @@ class Resource(object):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
