@@ -1,13 +1,13 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.parameter_map import ParameterMap
 	from zcrmsdk.src.com.zoho.crm.api.util import APIResponse, CommonAPIHandler, Constants
 	from zcrmsdk.src.com.zoho.crm.api.param import Param
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..parameter_map import ParameterMap
 	from ..util import APIResponse, CommonAPIHandler, Constants
 	from ..param import Param
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class ContactRolesOperations(object):
@@ -21,6 +21,9 @@ class ContactRolesOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		handler_instance = CommonAPIHandler()
@@ -28,6 +31,7 @@ class ContactRolesOperations(object):
 		api_path = api_path + '/crm/v2/Contacts/roles'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.contact_roles.response_handler import ResponseHandler
 		except Exception:
@@ -43,6 +47,9 @@ class ContactRolesOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -50,7 +57,7 @@ class ContactRolesOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -58,8 +65,10 @@ class ContactRolesOperations(object):
 		api_path = api_path + '/crm/v2/Contacts/roles'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.contact_roles.action_handler import ActionHandler
 		except Exception:
@@ -75,6 +84,9 @@ class ContactRolesOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -82,7 +94,7 @@ class ContactRolesOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -90,8 +102,10 @@ class ContactRolesOperations(object):
 		api_path = api_path + '/crm/v2/Contacts/roles'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.contact_roles.action_handler import ActionHandler
 		except Exception:
@@ -107,6 +121,9 @@ class ContactRolesOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
@@ -117,6 +134,7 @@ class ContactRolesOperations(object):
 		api_path = api_path + '/crm/v2/Contacts/roles'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
 		handler_instance.param = param_instance
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.contact_roles.action_handler import ActionHandler
@@ -129,14 +147,17 @@ class ContactRolesOperations(object):
 		The method to get contact role
 
 		Parameters:
-			id (string) : A string value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -144,6 +165,7 @@ class ContactRolesOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.contact_roles.response_handler import ResponseHandler
 		except Exception:
@@ -156,10 +178,13 @@ class ContactRolesOperations(object):
 
 		Parameters:
 			request (BodyWrapper) : An instance of BodyWrapper
-			id (string) : A string value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -167,11 +192,11 @@ class ContactRolesOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -179,6 +204,7 @@ class ContactRolesOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
 		try:
@@ -192,14 +218,17 @@ class ContactRolesOperations(object):
 		The method to delete contact role
 
 		Parameters:
-			id (string) : A string value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -207,6 +236,7 @@ class ContactRolesOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.contact_roles.action_handler import ActionHandler
 		except Exception:
@@ -216,4 +246,3 @@ class ContactRolesOperations(object):
 
 class DeleteContactRolesParam(object):
 	ids = Param('ids', 'com.zoho.crm.api.ContactRoles.DeleteContactRolesParam')
-
