@@ -1,10 +1,10 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.currencies.base_currency_action_handler import BaseCurrencyActionHandler
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from .base_currency_action_handler import BaseCurrencyActionHandler
 
 
@@ -39,7 +39,7 @@ class BaseCurrencyActionWrapper(BaseCurrencyActionHandler):
 		except Exception:
 			from .action_response import ActionResponse
 
-		if not isinstance(base_currency, ActionResponse):
+		if base_currency is not None and not isinstance(base_currency, ActionResponse):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: base_currency EXPECTED TYPE: ActionResponse', None, None)
 		
 		self.__base_currency = base_currency
@@ -50,13 +50,13 @@ class BaseCurrencyActionWrapper(BaseCurrencyActionHandler):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -69,14 +69,14 @@ class BaseCurrencyActionWrapper(BaseCurrencyActionHandler):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
