@@ -1,11 +1,15 @@
+from .related_details import RelatedDetails
 from .crypt import Crypt
 from .module import Module
-from .fields_operations import FieldsOperations
+from .view_type import ViewType
+from .lookup_field import LookupField
+from .fields_operations import FieldsOperations, GetFieldsParam
 from .multi_select_lookup import MultiSelectLookup
 from .tool_tip import ToolTip
 from .api_exception import APIException
 from .response_handler import ResponseHandler
 from .field import Field
+from .association_details import AssociationDetails
 from .unique import Unique
 from .response_wrapper import ResponseWrapper
 from .formula import Formula
