@@ -1,9 +1,9 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class Field(object):
@@ -74,10 +74,10 @@ class Field(object):
 		The method to set the value to system_mandatory
 
 		Parameters:
-			system_mandatory (bool) : A bool value
+			system_mandatory (bool) : A bool representing the system_mandatory
 		"""
 
-		if not isinstance(system_mandatory, bool):
+		if system_mandatory is not None and not isinstance(system_mandatory, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: system_mandatory EXPECTED TYPE: bool', None, None)
 		
 		self.__system_mandatory = system_mandatory
@@ -98,10 +98,10 @@ class Field(object):
 		The method to set the value to webhook
 
 		Parameters:
-			webhook (bool) : A bool value
+			webhook (bool) : A bool representing the webhook
 		"""
 
-		if not isinstance(webhook, bool):
+		if webhook is not None and not isinstance(webhook, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: webhook EXPECTED TYPE: bool', None, None)
 		
 		self.__webhook = webhook
@@ -130,7 +130,7 @@ class Field(object):
 		except Exception:
 			from ..layouts import Layout
 
-		if not isinstance(layouts, Layout):
+		if layouts is not None and not isinstance(layouts, Layout):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: layouts EXPECTED TYPE: Layout', None, None)
 		
 		self.__layouts = layouts
@@ -151,10 +151,10 @@ class Field(object):
 		The method to set the value to content
 
 		Parameters:
-			content (string) : A string value
+			content (string) : A string representing the content
 		"""
 
-		if not isinstance(content, str):
+		if content is not None and not isinstance(content, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: content EXPECTED TYPE: str', None, None)
 		
 		self.__content = content
@@ -175,10 +175,10 @@ class Field(object):
 		The method to set the value to column_name
 
 		Parameters:
-			column_name (string) : A string value
+			column_name (string) : A string representing the column_name
 		"""
 
-		if not isinstance(column_name, str):
+		if column_name is not None and not isinstance(column_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: column_name EXPECTED TYPE: str', None, None)
 		
 		self.__column_name = column_name
@@ -199,10 +199,10 @@ class Field(object):
 		The method to set the value to type
 
 		Parameters:
-			type (string) : A string value
+			type (string) : A string representing the type
 		"""
 
-		if not isinstance(type, str):
+		if type is not None and not isinstance(type, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: type EXPECTED TYPE: str', None, None)
 		
 		self.__type = type
@@ -223,10 +223,10 @@ class Field(object):
 		The method to set the value to transition_sequence
 
 		Parameters:
-			transition_sequence (int) : A int value
+			transition_sequence (int) : An int representing the transition_sequence
 		"""
 
-		if not isinstance(transition_sequence, int):
+		if transition_sequence is not None and not isinstance(transition_sequence, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: transition_sequence EXPECTED TYPE: int', None, None)
 		
 		self.__transition_sequence = transition_sequence
@@ -247,10 +247,10 @@ class Field(object):
 		The method to set the value to personality_name
 
 		Parameters:
-			personality_name (string) : A string value
+			personality_name (string) : A string representing the personality_name
 		"""
 
-		if not isinstance(personality_name, str):
+		if personality_name is not None and not isinstance(personality_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: personality_name EXPECTED TYPE: str', None, None)
 		
 		self.__personality_name = personality_name
@@ -271,10 +271,10 @@ class Field(object):
 		The method to set the value to message
 
 		Parameters:
-			message (string) : A string value
+			message (string) : A string representing the message
 		"""
 
-		if not isinstance(message, str):
+		if message is not None and not isinstance(message, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: message EXPECTED TYPE: str', None, None)
 		
 		self.__message = message
@@ -295,10 +295,10 @@ class Field(object):
 		The method to set the value to mandatory
 
 		Parameters:
-			mandatory (bool) : A bool value
+			mandatory (bool) : A bool representing the mandatory
 		"""
 
-		if not isinstance(mandatory, bool):
+		if mandatory is not None and not isinstance(mandatory, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: mandatory EXPECTED TYPE: bool', None, None)
 		
 		self.__mandatory = mandatory
@@ -327,7 +327,7 @@ class Field(object):
 		except Exception:
 			from ..custom_views import Criteria
 
-		if not isinstance(criteria, Criteria):
+		if criteria is not None and not isinstance(criteria, Criteria):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: criteria EXPECTED TYPE: Criteria', None, None)
 		
 		self.__criteria = criteria
@@ -356,7 +356,7 @@ class Field(object):
 		except Exception:
 			from .related_details import RelatedDetails
 
-		if not isinstance(related_details, RelatedDetails):
+		if related_details is not None and not isinstance(related_details, RelatedDetails):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: related_details EXPECTED TYPE: RelatedDetails', None, None)
 		
 		self.__related_details = related_details
@@ -377,10 +377,10 @@ class Field(object):
 		The method to set the value to json_type
 
 		Parameters:
-			json_type (string) : A string value
+			json_type (string) : A string representing the json_type
 		"""
 
-		if not isinstance(json_type, str):
+		if json_type is not None and not isinstance(json_type, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: json_type EXPECTED TYPE: str', None, None)
 		
 		self.__json_type = json_type
@@ -409,7 +409,7 @@ class Field(object):
 		except Exception:
 			from .crypt import Crypt
 
-		if not isinstance(crypt, Crypt):
+		if crypt is not None and not isinstance(crypt, Crypt):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: crypt EXPECTED TYPE: Crypt', None, None)
 		
 		self.__crypt = crypt
@@ -430,10 +430,10 @@ class Field(object):
 		The method to set the value to field_label
 
 		Parameters:
-			field_label (string) : A string value
+			field_label (string) : A string representing the field_label
 		"""
 
-		if not isinstance(field_label, str):
+		if field_label is not None and not isinstance(field_label, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: field_label EXPECTED TYPE: str', None, None)
 		
 		self.__field_label = field_label
@@ -462,7 +462,7 @@ class Field(object):
 		except Exception:
 			from .tool_tip import ToolTip
 
-		if not isinstance(tooltip, ToolTip):
+		if tooltip is not None and not isinstance(tooltip, ToolTip):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: tooltip EXPECTED TYPE: ToolTip', None, None)
 		
 		self.__tooltip = tooltip
@@ -483,10 +483,10 @@ class Field(object):
 		The method to set the value to created_source
 
 		Parameters:
-			created_source (string) : A string value
+			created_source (string) : A string representing the created_source
 		"""
 
-		if not isinstance(created_source, str):
+		if created_source is not None and not isinstance(created_source, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: created_source EXPECTED TYPE: str', None, None)
 		
 		self.__created_source = created_source
@@ -507,10 +507,10 @@ class Field(object):
 		The method to set the value to field_read_only
 
 		Parameters:
-			field_read_only (bool) : A bool value
+			field_read_only (bool) : A bool representing the field_read_only
 		"""
 
-		if not isinstance(field_read_only, bool):
+		if field_read_only is not None and not isinstance(field_read_only, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: field_read_only EXPECTED TYPE: bool', None, None)
 		
 		self.__field_read_only = field_read_only
@@ -531,10 +531,10 @@ class Field(object):
 		The method to set the value to display_label
 
 		Parameters:
-			display_label (string) : A string value
+			display_label (string) : A string representing the display_label
 		"""
 
-		if not isinstance(display_label, str):
+		if display_label is not None and not isinstance(display_label, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: display_label EXPECTED TYPE: str', None, None)
 		
 		self.__display_label = display_label
@@ -555,10 +555,10 @@ class Field(object):
 		The method to set the value to read_only
 
 		Parameters:
-			read_only (bool) : A bool value
+			read_only (bool) : A bool representing the read_only
 		"""
 
-		if not isinstance(read_only, bool):
+		if read_only is not None and not isinstance(read_only, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: read_only EXPECTED TYPE: bool', None, None)
 		
 		self.__read_only = read_only
@@ -587,7 +587,7 @@ class Field(object):
 		except Exception:
 			from .association_details import AssociationDetails
 
-		if not isinstance(association_details, AssociationDetails):
+		if association_details is not None and not isinstance(association_details, AssociationDetails):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: association_details EXPECTED TYPE: AssociationDetails', None, None)
 		
 		self.__association_details = association_details
@@ -608,10 +608,10 @@ class Field(object):
 		The method to set the value to quick_sequence_number
 
 		Parameters:
-			quick_sequence_number (int) : A int value
+			quick_sequence_number (int) : An int representing the quick_sequence_number
 		"""
 
-		if not isinstance(quick_sequence_number, int):
+		if quick_sequence_number is not None and not isinstance(quick_sequence_number, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: quick_sequence_number EXPECTED TYPE: int', None, None)
 		
 		self.__quick_sequence_number = quick_sequence_number
@@ -632,10 +632,10 @@ class Field(object):
 		The method to set the value to businesscard_supported
 
 		Parameters:
-			businesscard_supported (bool) : A bool value
+			businesscard_supported (bool) : A bool representing the businesscard_supported
 		"""
 
-		if not isinstance(businesscard_supported, bool):
+		if businesscard_supported is not None and not isinstance(businesscard_supported, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: businesscard_supported EXPECTED TYPE: bool', None, None)
 		
 		self.__businesscard_supported = businesscard_supported
@@ -659,7 +659,7 @@ class Field(object):
 			multi_module_lookup (dict) : An instance of dict
 		"""
 
-		if not isinstance(multi_module_lookup, dict):
+		if multi_module_lookup is not None and not isinstance(multi_module_lookup, dict):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: multi_module_lookup EXPECTED TYPE: dict', None, None)
 		
 		self.__multi_module_lookup = multi_module_lookup
@@ -688,7 +688,7 @@ class Field(object):
 		except Exception:
 			from .currency import Currency
 
-		if not isinstance(currency, Currency):
+		if currency is not None and not isinstance(currency, Currency):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: currency EXPECTED TYPE: Currency', None, None)
 		
 		self.__currency = currency
@@ -699,7 +699,7 @@ class Field(object):
 		The method to get the id
 
 		Returns:
-			string: A string value
+			int: A int value
 		"""
 
 		return self.__id
@@ -709,11 +709,11 @@ class Field(object):
 		The method to set the value to id
 
 		Parameters:
-			id (string) : A string value
+			id (int) : An int representing the id
 		"""
 
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		self.__id = id
 		self.__key_modified['id'] = 1
@@ -733,10 +733,10 @@ class Field(object):
 		The method to set the value to custom_field
 
 		Parameters:
-			custom_field (bool) : A bool value
+			custom_field (bool) : A bool representing the custom_field
 		"""
 
-		if not isinstance(custom_field, bool):
+		if custom_field is not None and not isinstance(custom_field, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: custom_field EXPECTED TYPE: bool', None, None)
 		
 		self.__custom_field = custom_field
@@ -765,7 +765,7 @@ class Field(object):
 		except Exception:
 			from .module import Module
 
-		if not isinstance(lookup, Module):
+		if lookup is not None and not isinstance(lookup, Module):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: lookup EXPECTED TYPE: Module', None, None)
 		
 		self.__lookup = lookup
@@ -786,10 +786,10 @@ class Field(object):
 		The method to set the value to visible
 
 		Parameters:
-			visible (bool) : A bool value
+			visible (bool) : A bool representing the visible
 		"""
 
-		if not isinstance(visible, bool):
+		if visible is not None and not isinstance(visible, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: visible EXPECTED TYPE: bool', None, None)
 		
 		self.__visible = visible
@@ -810,10 +810,10 @@ class Field(object):
 		The method to set the value to length
 
 		Parameters:
-			length (int) : A int value
+			length (int) : An int representing the length
 		"""
 
-		if not isinstance(length, int):
+		if length is not None and not isinstance(length, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: length EXPECTED TYPE: int', None, None)
 		
 		self.__length = length
@@ -842,7 +842,7 @@ class Field(object):
 		except Exception:
 			from .view_type import ViewType
 
-		if not isinstance(view_type, ViewType):
+		if view_type is not None and not isinstance(view_type, ViewType):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: view_type EXPECTED TYPE: ViewType', None, None)
 		
 		self.__view_type = view_type
@@ -871,7 +871,7 @@ class Field(object):
 		except Exception:
 			from .module import Module
 
-		if not isinstance(subform, Module):
+		if subform is not None and not isinstance(subform, Module):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: subform EXPECTED TYPE: Module', None, None)
 		
 		self.__subform = subform
@@ -892,10 +892,10 @@ class Field(object):
 		The method to set the value to api_name
 
 		Parameters:
-			api_name (string) : A string value
+			api_name (string) : A string representing the api_name
 		"""
 
-		if not isinstance(api_name, str):
+		if api_name is not None and not isinstance(api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: api_name EXPECTED TYPE: str', None, None)
 		
 		self.__api_name = api_name
@@ -924,7 +924,7 @@ class Field(object):
 		except Exception:
 			from .unique import Unique
 
-		if not isinstance(unique, Unique):
+		if unique is not None and not isinstance(unique, Unique):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: unique EXPECTED TYPE: Unique', None, None)
 		
 		self.__unique = unique
@@ -945,10 +945,10 @@ class Field(object):
 		The method to set the value to history_tracking
 
 		Parameters:
-			history_tracking (bool) : A bool value
+			history_tracking (bool) : A bool representing the history_tracking
 		"""
 
-		if not isinstance(history_tracking, bool):
+		if history_tracking is not None and not isinstance(history_tracking, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: history_tracking EXPECTED TYPE: bool', None, None)
 		
 		self.__history_tracking = history_tracking
@@ -969,10 +969,10 @@ class Field(object):
 		The method to set the value to data_type
 
 		Parameters:
-			data_type (string) : A string value
+			data_type (string) : A string representing the data_type
 		"""
 
-		if not isinstance(data_type, str):
+		if data_type is not None and not isinstance(data_type, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: data_type EXPECTED TYPE: str', None, None)
 		
 		self.__data_type = data_type
@@ -1001,7 +1001,7 @@ class Field(object):
 		except Exception:
 			from .formula import Formula
 
-		if not isinstance(formula, Formula):
+		if formula is not None and not isinstance(formula, Formula):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: formula EXPECTED TYPE: Formula', None, None)
 		
 		self.__formula = formula
@@ -1022,10 +1022,10 @@ class Field(object):
 		The method to set the value to decimal_place
 
 		Parameters:
-			decimal_place (int) : A int value
+			decimal_place (int) : An int representing the decimal_place
 		"""
 
-		if not isinstance(decimal_place, int):
+		if decimal_place is not None and not isinstance(decimal_place, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: decimal_place EXPECTED TYPE: int', None, None)
 		
 		self.__decimal_place = decimal_place
@@ -1046,10 +1046,10 @@ class Field(object):
 		The method to set the value to mass_update
 
 		Parameters:
-			mass_update (bool) : A bool value
+			mass_update (bool) : A bool representing the mass_update
 		"""
 
-		if not isinstance(mass_update, bool):
+		if mass_update is not None and not isinstance(mass_update, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: mass_update EXPECTED TYPE: bool', None, None)
 		
 		self.__mass_update = mass_update
@@ -1070,10 +1070,10 @@ class Field(object):
 		The method to set the value to blueprint_supported
 
 		Parameters:
-			blueprint_supported (bool) : A bool value
+			blueprint_supported (bool) : A bool representing the blueprint_supported
 		"""
 
-		if not isinstance(blueprint_supported, bool):
+		if blueprint_supported is not None and not isinstance(blueprint_supported, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: blueprint_supported EXPECTED TYPE: bool', None, None)
 		
 		self.__blueprint_supported = blueprint_supported
@@ -1102,7 +1102,7 @@ class Field(object):
 		except Exception:
 			from .multi_select_lookup import MultiSelectLookup
 
-		if not isinstance(multiselectlookup, MultiSelectLookup):
+		if multiselectlookup is not None and not isinstance(multiselectlookup, MultiSelectLookup):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: multiselectlookup EXPECTED TYPE: MultiSelectLookup', None, None)
 		
 		self.__multiselectlookup = multiselectlookup
@@ -1126,7 +1126,7 @@ class Field(object):
 			pick_list_values (list) : An instance of list
 		"""
 
-		if not isinstance(pick_list_values, list):
+		if pick_list_values is not None and not isinstance(pick_list_values, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: pick_list_values EXPECTED TYPE: list', None, None)
 		
 		self.__pick_list_values = pick_list_values
@@ -1155,7 +1155,7 @@ class Field(object):
 		except Exception:
 			from .auto_number import AutoNumber
 
-		if not isinstance(auto_number, AutoNumber):
+		if auto_number is not None and not isinstance(auto_number, AutoNumber):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: auto_number EXPECTED TYPE: AutoNumber', None, None)
 		
 		self.__auto_number = auto_number
@@ -1176,10 +1176,10 @@ class Field(object):
 		The method to set the value to default_value
 
 		Parameters:
-			default_value (string) : A string value
+			default_value (string) : A string representing the default_value
 		"""
 
-		if not isinstance(default_value, str):
+		if default_value is not None and not isinstance(default_value, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: default_value EXPECTED TYPE: str', None, None)
 		
 		self.__default_value = default_value
@@ -1200,10 +1200,10 @@ class Field(object):
 		The method to set the value to section_id
 
 		Parameters:
-			section_id (int) : A int value
+			section_id (int) : An int representing the section_id
 		"""
 
-		if not isinstance(section_id, int):
+		if section_id is not None and not isinstance(section_id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: section_id EXPECTED TYPE: int', None, None)
 		
 		self.__section_id = section_id
@@ -1227,7 +1227,7 @@ class Field(object):
 			validation_rule (dict) : An instance of dict
 		"""
 
-		if not isinstance(validation_rule, dict):
+		if validation_rule is not None and not isinstance(validation_rule, dict):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: validation_rule EXPECTED TYPE: dict', None, None)
 		
 		self.__validation_rule = validation_rule
@@ -1251,7 +1251,7 @@ class Field(object):
 			convert_mapping (dict) : An instance of dict
 		"""
 
-		if not isinstance(convert_mapping, dict):
+		if convert_mapping is not None and not isinstance(convert_mapping, dict):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: convert_mapping EXPECTED TYPE: dict', None, None)
 		
 		self.__convert_mapping = convert_mapping
@@ -1262,13 +1262,13 @@ class Field(object):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -1281,14 +1281,14 @@ class Field(object):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
