@@ -1,8 +1,9 @@
 from .action_wrapper import ActionWrapper
-from .file_operations import FileOperations, GetFileParam
+from .file_operations import FileOperations, UploadFileParam, GetFileParam
 from .api_exception import APIException
 from .response_handler import ResponseHandler
 from .action_response import ActionResponse
 from .success_response import SuccessResponse
 from .file_body_wrapper import FileBodyWrapper
+from .body_wrapper import BodyWrapper
 from .action_handler import ActionHandler
