@@ -1,9 +1,9 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class Layout(object):
@@ -44,7 +44,7 @@ class Layout(object):
 
 		from datetime import datetime
 
-		if not isinstance(created_time, datetime):
+		if created_time is not None and not isinstance(created_time, datetime):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: created_time EXPECTED TYPE: datetime', None, None)
 		
 		self.__created_time = created_time
@@ -68,7 +68,7 @@ class Layout(object):
 			convert_mapping (dict) : An instance of dict
 		"""
 
-		if not isinstance(convert_mapping, dict):
+		if convert_mapping is not None and not isinstance(convert_mapping, dict):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: convert_mapping EXPECTED TYPE: dict', None, None)
 		
 		self.__convert_mapping = convert_mapping
@@ -94,7 +94,7 @@ class Layout(object):
 
 		from datetime import datetime
 
-		if not isinstance(modified_time, datetime):
+		if modified_time is not None and not isinstance(modified_time, datetime):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modified_time EXPECTED TYPE: datetime', None, None)
 		
 		self.__modified_time = modified_time
@@ -115,10 +115,10 @@ class Layout(object):
 		The method to set the value to visible
 
 		Parameters:
-			visible (bool) : A bool value
+			visible (bool) : A bool representing the visible
 		"""
 
-		if not isinstance(visible, bool):
+		if visible is not None and not isinstance(visible, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: visible EXPECTED TYPE: bool', None, None)
 		
 		self.__visible = visible
@@ -147,7 +147,7 @@ class Layout(object):
 		except Exception:
 			from ..users import User
 
-		if not isinstance(created_for, User):
+		if created_for is not None and not isinstance(created_for, User):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: created_for EXPECTED TYPE: User', None, None)
 		
 		self.__created_for = created_for
@@ -168,10 +168,10 @@ class Layout(object):
 		The method to set the value to name
 
 		Parameters:
-			name (string) : A string value
+			name (string) : A string representing the name
 		"""
 
-		if not isinstance(name, str):
+		if name is not None and not isinstance(name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: name EXPECTED TYPE: str', None, None)
 		
 		self.__name = name
@@ -200,7 +200,7 @@ class Layout(object):
 		except Exception:
 			from ..users import User
 
-		if not isinstance(modified_by, User):
+		if modified_by is not None and not isinstance(modified_by, User):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modified_by EXPECTED TYPE: User', None, None)
 		
 		self.__modified_by = modified_by
@@ -224,7 +224,7 @@ class Layout(object):
 			profiles (list) : An instance of list
 		"""
 
-		if not isinstance(profiles, list):
+		if profiles is not None and not isinstance(profiles, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: profiles EXPECTED TYPE: list', None, None)
 		
 		self.__profiles = profiles
@@ -235,7 +235,7 @@ class Layout(object):
 		The method to get the id
 
 		Returns:
-			string: A string value
+			int: A int value
 		"""
 
 		return self.__id
@@ -245,11 +245,11 @@ class Layout(object):
 		The method to set the value to id
 
 		Parameters:
-			id (string) : A string value
+			id (int) : An int representing the id
 		"""
 
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		self.__id = id
 		self.__key_modified['id'] = 1
@@ -277,7 +277,7 @@ class Layout(object):
 		except Exception:
 			from ..users import User
 
-		if not isinstance(created_by, User):
+		if created_by is not None and not isinstance(created_by, User):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: created_by EXPECTED TYPE: User', None, None)
 		
 		self.__created_by = created_by
@@ -301,7 +301,7 @@ class Layout(object):
 			sections (list) : An instance of list
 		"""
 
-		if not isinstance(sections, list):
+		if sections is not None and not isinstance(sections, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: sections EXPECTED TYPE: list', None, None)
 		
 		self.__sections = sections
@@ -322,10 +322,10 @@ class Layout(object):
 		The method to set the value to status
 
 		Parameters:
-			status (int) : A int value
+			status (int) : An int representing the status
 		"""
 
-		if not isinstance(status, int):
+		if status is not None and not isinstance(status, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: status EXPECTED TYPE: int', None, None)
 		
 		self.__status = status
@@ -336,13 +336,13 @@ class Layout(object):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -355,14 +355,14 @@ class Layout(object):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
