@@ -1,9 +1,9 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class Section(object):
@@ -37,10 +37,10 @@ class Section(object):
 		The method to set the value to display_label
 
 		Parameters:
-			display_label (string) : A string value
+			display_label (string) : A string representing the display_label
 		"""
 
-		if not isinstance(display_label, str):
+		if display_label is not None and not isinstance(display_label, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: display_label EXPECTED TYPE: str', None, None)
 		
 		self.__display_label = display_label
@@ -61,10 +61,10 @@ class Section(object):
 		The method to set the value to sequence_number
 
 		Parameters:
-			sequence_number (int) : A int value
+			sequence_number (int) : An int representing the sequence_number
 		"""
 
-		if not isinstance(sequence_number, int):
+		if sequence_number is not None and not isinstance(sequence_number, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: sequence_number EXPECTED TYPE: int', None, None)
 		
 		self.__sequence_number = sequence_number
@@ -85,10 +85,10 @@ class Section(object):
 		The method to set the value to issubformsection
 
 		Parameters:
-			issubformsection (bool) : A bool value
+			issubformsection (bool) : A bool representing the issubformsection
 		"""
 
-		if not isinstance(issubformsection, bool):
+		if issubformsection is not None and not isinstance(issubformsection, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: issubformsection EXPECTED TYPE: bool', None, None)
 		
 		self.__issubformsection = issubformsection
@@ -109,10 +109,10 @@ class Section(object):
 		The method to set the value to tab_traversal
 
 		Parameters:
-			tab_traversal (int) : A int value
+			tab_traversal (int) : An int representing the tab_traversal
 		"""
 
-		if not isinstance(tab_traversal, int):
+		if tab_traversal is not None and not isinstance(tab_traversal, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: tab_traversal EXPECTED TYPE: int', None, None)
 		
 		self.__tab_traversal = tab_traversal
@@ -133,10 +133,10 @@ class Section(object):
 		The method to set the value to api_name
 
 		Parameters:
-			api_name (string) : A string value
+			api_name (string) : A string representing the api_name
 		"""
 
-		if not isinstance(api_name, str):
+		if api_name is not None and not isinstance(api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: api_name EXPECTED TYPE: str', None, None)
 		
 		self.__api_name = api_name
@@ -157,10 +157,10 @@ class Section(object):
 		The method to set the value to column_count
 
 		Parameters:
-			column_count (int) : A int value
+			column_count (int) : An int representing the column_count
 		"""
 
-		if not isinstance(column_count, int):
+		if column_count is not None and not isinstance(column_count, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: column_count EXPECTED TYPE: int', None, None)
 		
 		self.__column_count = column_count
@@ -181,10 +181,10 @@ class Section(object):
 		The method to set the value to name
 
 		Parameters:
-			name (string) : A string value
+			name (string) : A string representing the name
 		"""
 
-		if not isinstance(name, str):
+		if name is not None and not isinstance(name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: name EXPECTED TYPE: str', None, None)
 		
 		self.__name = name
@@ -205,10 +205,10 @@ class Section(object):
 		The method to set the value to generated_type
 
 		Parameters:
-			generated_type (string) : A string value
+			generated_type (string) : A string representing the generated_type
 		"""
 
-		if not isinstance(generated_type, str):
+		if generated_type is not None and not isinstance(generated_type, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: generated_type EXPECTED TYPE: str', None, None)
 		
 		self.__generated_type = generated_type
@@ -232,7 +232,7 @@ class Section(object):
 			fields (list) : An instance of list
 		"""
 
-		if not isinstance(fields, list):
+		if fields is not None and not isinstance(fields, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: fields EXPECTED TYPE: list', None, None)
 		
 		self.__fields = fields
@@ -261,7 +261,7 @@ class Section(object):
 		except Exception:
 			from .properties import Properties
 
-		if not isinstance(properties, Properties):
+		if properties is not None and not isinstance(properties, Properties):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: properties EXPECTED TYPE: Properties', None, None)
 		
 		self.__properties = properties
@@ -272,13 +272,13 @@ class Section(object):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -291,14 +291,14 @@ class Section(object):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
