@@ -1,9 +1,9 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Choice, Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..util import Choice, Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class Module(object):
@@ -71,10 +71,10 @@ class Module(object):
 		The method to set the value to name
 
 		Parameters:
-			name (string) : A string value
+			name (string) : A string representing the name
 		"""
 
-		if not isinstance(name, str):
+		if name is not None and not isinstance(name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: name EXPECTED TYPE: str', None, None)
 		
 		self.__name = name
@@ -95,10 +95,10 @@ class Module(object):
 		The method to set the value to global_search_supported
 
 		Parameters:
-			global_search_supported (bool) : A bool value
+			global_search_supported (bool) : A bool representing the global_search_supported
 		"""
 
-		if not isinstance(global_search_supported, bool):
+		if global_search_supported is not None and not isinstance(global_search_supported, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: global_search_supported EXPECTED TYPE: bool', None, None)
 		
 		self.__global_search_supported = global_search_supported
@@ -119,10 +119,10 @@ class Module(object):
 		The method to set the value to kanban_view
 
 		Parameters:
-			kanban_view (bool) : A bool value
+			kanban_view (bool) : A bool representing the kanban_view
 		"""
 
-		if not isinstance(kanban_view, bool):
+		if kanban_view is not None and not isinstance(kanban_view, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: kanban_view EXPECTED TYPE: bool', None, None)
 		
 		self.__kanban_view = kanban_view
@@ -143,10 +143,10 @@ class Module(object):
 		The method to set the value to deletable
 
 		Parameters:
-			deletable (bool) : A bool value
+			deletable (bool) : A bool representing the deletable
 		"""
 
-		if not isinstance(deletable, bool):
+		if deletable is not None and not isinstance(deletable, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: deletable EXPECTED TYPE: bool', None, None)
 		
 		self.__deletable = deletable
@@ -167,10 +167,10 @@ class Module(object):
 		The method to set the value to description
 
 		Parameters:
-			description (string) : A string value
+			description (string) : A string representing the description
 		"""
 
-		if not isinstance(description, str):
+		if description is not None and not isinstance(description, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: description EXPECTED TYPE: str', None, None)
 		
 		self.__description = description
@@ -191,10 +191,10 @@ class Module(object):
 		The method to set the value to creatable
 
 		Parameters:
-			creatable (bool) : A bool value
+			creatable (bool) : A bool representing the creatable
 		"""
 
-		if not isinstance(creatable, bool):
+		if creatable is not None and not isinstance(creatable, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: creatable EXPECTED TYPE: bool', None, None)
 		
 		self.__creatable = creatable
@@ -215,10 +215,10 @@ class Module(object):
 		The method to set the value to filter_status
 
 		Parameters:
-			filter_status (bool) : A bool value
+			filter_status (bool) : A bool representing the filter_status
 		"""
 
-		if not isinstance(filter_status, bool):
+		if filter_status is not None and not isinstance(filter_status, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: filter_status EXPECTED TYPE: bool', None, None)
 		
 		self.__filter_status = filter_status
@@ -239,10 +239,10 @@ class Module(object):
 		The method to set the value to inventory_template_supported
 
 		Parameters:
-			inventory_template_supported (bool) : A bool value
+			inventory_template_supported (bool) : A bool representing the inventory_template_supported
 		"""
 
-		if not isinstance(inventory_template_supported, bool):
+		if inventory_template_supported is not None and not isinstance(inventory_template_supported, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: inventory_template_supported EXPECTED TYPE: bool', None, None)
 		
 		self.__inventory_template_supported = inventory_template_supported
@@ -268,7 +268,7 @@ class Module(object):
 
 		from datetime import datetime
 
-		if not isinstance(modified_time, datetime):
+		if modified_time is not None and not isinstance(modified_time, datetime):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modified_time EXPECTED TYPE: datetime', None, None)
 		
 		self.__modified_time = modified_time
@@ -289,10 +289,10 @@ class Module(object):
 		The method to set the value to plural_label
 
 		Parameters:
-			plural_label (string) : A string value
+			plural_label (string) : A string representing the plural_label
 		"""
 
-		if not isinstance(plural_label, str):
+		if plural_label is not None and not isinstance(plural_label, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: plural_label EXPECTED TYPE: str', None, None)
 		
 		self.__plural_label = plural_label
@@ -313,10 +313,10 @@ class Module(object):
 		The method to set the value to presence_sub_menu
 
 		Parameters:
-			presence_sub_menu (bool) : A bool value
+			presence_sub_menu (bool) : A bool representing the presence_sub_menu
 		"""
 
-		if not isinstance(presence_sub_menu, bool):
+		if presence_sub_menu is not None and not isinstance(presence_sub_menu, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: presence_sub_menu EXPECTED TYPE: bool', None, None)
 		
 		self.__presence_sub_menu = presence_sub_menu
@@ -337,10 +337,10 @@ class Module(object):
 		The method to set the value to triggers_supported
 
 		Parameters:
-			triggers_supported (bool) : A bool value
+			triggers_supported (bool) : A bool representing the triggers_supported
 		"""
 
-		if not isinstance(triggers_supported, bool):
+		if triggers_supported is not None and not isinstance(triggers_supported, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: triggers_supported EXPECTED TYPE: bool', None, None)
 		
 		self.__triggers_supported = triggers_supported
@@ -361,10 +361,10 @@ class Module(object):
 		The method to set the value to id
 
 		Parameters:
-			id (int) : A int value
+			id (int) : An int representing the id
 		"""
 
-		if not isinstance(id, int):
+		if id is not None and not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		self.__id = id
@@ -393,7 +393,7 @@ class Module(object):
 		except Exception:
 			from .related_list_properties import RelatedListProperties
 
-		if not isinstance(related_list_properties, RelatedListProperties):
+		if related_list_properties is not None and not isinstance(related_list_properties, RelatedListProperties):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: related_list_properties EXPECTED TYPE: RelatedListProperties', None, None)
 		
 		self.__related_list_properties = related_list_properties
@@ -417,7 +417,7 @@ class Module(object):
 			properties (list) : An instance of list
 		"""
 
-		if not isinstance(properties, list):
+		if properties is not None and not isinstance(properties, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: properties EXPECTED TYPE: list', None, None)
 		
 		self.__properties = properties
@@ -438,10 +438,10 @@ class Module(object):
 		The method to set the value to per_page
 
 		Parameters:
-			per_page (int) : A int value
+			per_page (int) : An int representing the per_page
 		"""
 
-		if not isinstance(per_page, int):
+		if per_page is not None and not isinstance(per_page, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: per_page EXPECTED TYPE: int', None, None)
 		
 		self.__per_page = per_page
@@ -462,10 +462,10 @@ class Module(object):
 		The method to set the value to visibility
 
 		Parameters:
-			visibility (int) : A int value
+			visibility (int) : An int representing the visibility
 		"""
 
-		if not isinstance(visibility, int):
+		if visibility is not None and not isinstance(visibility, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: visibility EXPECTED TYPE: int', None, None)
 		
 		self.__visibility = visibility
@@ -486,10 +486,10 @@ class Module(object):
 		The method to set the value to convertable
 
 		Parameters:
-			convertable (bool) : A bool value
+			convertable (bool) : A bool representing the convertable
 		"""
 
-		if not isinstance(convertable, bool):
+		if convertable is not None and not isinstance(convertable, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: convertable EXPECTED TYPE: bool', None, None)
 		
 		self.__convertable = convertable
@@ -510,10 +510,10 @@ class Module(object):
 		The method to set the value to editable
 
 		Parameters:
-			editable (bool) : A bool value
+			editable (bool) : A bool representing the editable
 		"""
 
-		if not isinstance(editable, bool):
+		if editable is not None and not isinstance(editable, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: editable EXPECTED TYPE: bool', None, None)
 		
 		self.__editable = editable
@@ -534,10 +534,10 @@ class Module(object):
 		The method to set the value to emailtemplate_support
 
 		Parameters:
-			emailtemplate_support (bool) : A bool value
+			emailtemplate_support (bool) : A bool representing the emailtemplate_support
 		"""
 
-		if not isinstance(emailtemplate_support, bool):
+		if emailtemplate_support is not None and not isinstance(emailtemplate_support, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: emailtemplate_support EXPECTED TYPE: bool', None, None)
 		
 		self.__emailtemplate_support = emailtemplate_support
@@ -561,7 +561,7 @@ class Module(object):
 			profiles (list) : An instance of list
 		"""
 
-		if not isinstance(profiles, list):
+		if profiles is not None and not isinstance(profiles, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: profiles EXPECTED TYPE: list', None, None)
 		
 		self.__profiles = profiles
@@ -582,10 +582,10 @@ class Module(object):
 		The method to set the value to filter_supported
 
 		Parameters:
-			filter_supported (bool) : A bool value
+			filter_supported (bool) : A bool representing the filter_supported
 		"""
 
-		if not isinstance(filter_supported, bool):
+		if filter_supported is not None and not isinstance(filter_supported, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: filter_supported EXPECTED TYPE: bool', None, None)
 		
 		self.__filter_supported = filter_supported
@@ -606,10 +606,10 @@ class Module(object):
 		The method to set the value to display_field
 
 		Parameters:
-			display_field (string) : A string value
+			display_field (string) : A string representing the display_field
 		"""
 
-		if not isinstance(display_field, str):
+		if display_field is not None and not isinstance(display_field, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: display_field EXPECTED TYPE: str', None, None)
 		
 		self.__display_field = display_field
@@ -633,7 +633,7 @@ class Module(object):
 			search_layout_fields (list) : An instance of list
 		"""
 
-		if not isinstance(search_layout_fields, list):
+		if search_layout_fields is not None and not isinstance(search_layout_fields, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: search_layout_fields EXPECTED TYPE: list', None, None)
 		
 		self.__search_layout_fields = search_layout_fields
@@ -654,10 +654,10 @@ class Module(object):
 		The method to set the value to kanban_view_supported
 
 		Parameters:
-			kanban_view_supported (bool) : A bool value
+			kanban_view_supported (bool) : A bool representing the kanban_view_supported
 		"""
 
-		if not isinstance(kanban_view_supported, bool):
+		if kanban_view_supported is not None and not isinstance(kanban_view_supported, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: kanban_view_supported EXPECTED TYPE: bool', None, None)
 		
 		self.__kanban_view_supported = kanban_view_supported
@@ -678,10 +678,10 @@ class Module(object):
 		The method to set the value to show_as_tab
 
 		Parameters:
-			show_as_tab (bool) : A bool value
+			show_as_tab (bool) : A bool representing the show_as_tab
 		"""
 
-		if not isinstance(show_as_tab, bool):
+		if show_as_tab is not None and not isinstance(show_as_tab, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: show_as_tab EXPECTED TYPE: bool', None, None)
 		
 		self.__show_as_tab = show_as_tab
@@ -702,10 +702,10 @@ class Module(object):
 		The method to set the value to web_link
 
 		Parameters:
-			web_link (string) : A string value
+			web_link (string) : A string representing the web_link
 		"""
 
-		if not isinstance(web_link, str):
+		if web_link is not None and not isinstance(web_link, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: web_link EXPECTED TYPE: str', None, None)
 		
 		self.__web_link = web_link
@@ -726,10 +726,10 @@ class Module(object):
 		The method to set the value to sequence_number
 
 		Parameters:
-			sequence_number (int) : A int value
+			sequence_number (int) : An int representing the sequence_number
 		"""
 
-		if not isinstance(sequence_number, int):
+		if sequence_number is not None and not isinstance(sequence_number, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: sequence_number EXPECTED TYPE: int', None, None)
 		
 		self.__sequence_number = sequence_number
@@ -750,10 +750,10 @@ class Module(object):
 		The method to set the value to singular_label
 
 		Parameters:
-			singular_label (string) : A string value
+			singular_label (string) : A string representing the singular_label
 		"""
 
-		if not isinstance(singular_label, str):
+		if singular_label is not None and not isinstance(singular_label, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: singular_label EXPECTED TYPE: str', None, None)
 		
 		self.__singular_label = singular_label
@@ -774,10 +774,10 @@ class Module(object):
 		The method to set the value to viewable
 
 		Parameters:
-			viewable (bool) : A bool value
+			viewable (bool) : A bool representing the viewable
 		"""
 
-		if not isinstance(viewable, bool):
+		if viewable is not None and not isinstance(viewable, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: viewable EXPECTED TYPE: bool', None, None)
 		
 		self.__viewable = viewable
@@ -798,10 +798,10 @@ class Module(object):
 		The method to set the value to api_supported
 
 		Parameters:
-			api_supported (bool) : A bool value
+			api_supported (bool) : A bool representing the api_supported
 		"""
 
-		if not isinstance(api_supported, bool):
+		if api_supported is not None and not isinstance(api_supported, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: api_supported EXPECTED TYPE: bool', None, None)
 		
 		self.__api_supported = api_supported
@@ -822,10 +822,10 @@ class Module(object):
 		The method to set the value to api_name
 
 		Parameters:
-			api_name (string) : A string value
+			api_name (string) : A string representing the api_name
 		"""
 
-		if not isinstance(api_name, str):
+		if api_name is not None and not isinstance(api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: api_name EXPECTED TYPE: str', None, None)
 		
 		self.__api_name = api_name
@@ -846,10 +846,10 @@ class Module(object):
 		The method to set the value to quick_create
 
 		Parameters:
-			quick_create (bool) : A bool value
+			quick_create (bool) : A bool representing the quick_create
 		"""
 
-		if not isinstance(quick_create, bool):
+		if quick_create is not None and not isinstance(quick_create, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: quick_create EXPECTED TYPE: bool', None, None)
 		
 		self.__quick_create = quick_create
@@ -878,7 +878,7 @@ class Module(object):
 		except Exception:
 			from ..users import User
 
-		if not isinstance(modified_by, User):
+		if modified_by is not None and not isinstance(modified_by, User):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modified_by EXPECTED TYPE: User', None, None)
 		
 		self.__modified_by = modified_by
@@ -902,7 +902,7 @@ class Module(object):
 			generated_type (Choice) : An instance of Choice
 		"""
 
-		if not isinstance(generated_type, Choice):
+		if generated_type is not None and not isinstance(generated_type, Choice):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: generated_type EXPECTED TYPE: Choice', None, None)
 		
 		self.__generated_type = generated_type
@@ -923,10 +923,10 @@ class Module(object):
 		The method to set the value to feeds_required
 
 		Parameters:
-			feeds_required (bool) : A bool value
+			feeds_required (bool) : A bool representing the feeds_required
 		"""
 
-		if not isinstance(feeds_required, bool):
+		if feeds_required is not None and not isinstance(feeds_required, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: feeds_required EXPECTED TYPE: bool', None, None)
 		
 		self.__feeds_required = feeds_required
@@ -947,10 +947,10 @@ class Module(object):
 		The method to set the value to scoring_supported
 
 		Parameters:
-			scoring_supported (bool) : A bool value
+			scoring_supported (bool) : A bool representing the scoring_supported
 		"""
 
-		if not isinstance(scoring_supported, bool):
+		if scoring_supported is not None and not isinstance(scoring_supported, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: scoring_supported EXPECTED TYPE: bool', None, None)
 		
 		self.__scoring_supported = scoring_supported
@@ -971,10 +971,10 @@ class Module(object):
 		The method to set the value to webform_supported
 
 		Parameters:
-			webform_supported (bool) : A bool value
+			webform_supported (bool) : A bool representing the webform_supported
 		"""
 
-		if not isinstance(webform_supported, bool):
+		if webform_supported is not None and not isinstance(webform_supported, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: webform_supported EXPECTED TYPE: bool', None, None)
 		
 		self.__webform_supported = webform_supported
@@ -998,7 +998,7 @@ class Module(object):
 			arguments (list) : An instance of list
 		"""
 
-		if not isinstance(arguments, list):
+		if arguments is not None and not isinstance(arguments, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: arguments EXPECTED TYPE: list', None, None)
 		
 		self.__arguments = arguments
@@ -1019,10 +1019,10 @@ class Module(object):
 		The method to set the value to module_name
 
 		Parameters:
-			module_name (string) : A string value
+			module_name (string) : A string representing the module_name
 		"""
 
-		if not isinstance(module_name, str):
+		if module_name is not None and not isinstance(module_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_name EXPECTED TYPE: str', None, None)
 		
 		self.__module_name = module_name
@@ -1043,10 +1043,10 @@ class Module(object):
 		The method to set the value to business_card_field_limit
 
 		Parameters:
-			business_card_field_limit (int) : A int value
+			business_card_field_limit (int) : An int representing the business_card_field_limit
 		"""
 
-		if not isinstance(business_card_field_limit, int):
+		if business_card_field_limit is not None and not isinstance(business_card_field_limit, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: business_card_field_limit EXPECTED TYPE: int', None, None)
 		
 		self.__business_card_field_limit = business_card_field_limit
@@ -1075,7 +1075,7 @@ class Module(object):
 		except Exception:
 			from ..custom_views import CustomView
 
-		if not isinstance(custom_view, CustomView):
+		if custom_view is not None and not isinstance(custom_view, CustomView):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: custom_view EXPECTED TYPE: CustomView', None, None)
 		
 		self.__custom_view = custom_view
@@ -1104,7 +1104,7 @@ class Module(object):
 		except Exception:
 			from .module import Module
 
-		if not isinstance(parent_module, Module):
+		if parent_module is not None and not isinstance(parent_module, Module):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: parent_module EXPECTED TYPE: Module', None, None)
 		
 		self.__parent_module = parent_module
@@ -1133,7 +1133,7 @@ class Module(object):
 		except Exception:
 			from .territory import Territory
 
-		if not isinstance(territory, Territory):
+		if territory is not None and not isinstance(territory, Territory):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: territory EXPECTED TYPE: Territory', None, None)
 		
 		self.__territory = territory
@@ -1144,13 +1144,13 @@ class Module(object):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -1163,14 +1163,14 @@ class Module(object):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
