@@ -1,9 +1,9 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class Note(object):
@@ -51,7 +51,7 @@ class Note(object):
 		except Exception:
 			from ..users import User
 
-		if not isinstance(owner, User):
+		if owner is not None and not isinstance(owner, User):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: owner EXPECTED TYPE: User', None, None)
 		
 		self.__owner = owner
@@ -77,7 +77,7 @@ class Note(object):
 
 		from datetime import datetime
 
-		if not isinstance(modified_time, datetime):
+		if modified_time is not None and not isinstance(modified_time, datetime):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modified_time EXPECTED TYPE: datetime', None, None)
 		
 		self.__modified_time = modified_time
@@ -101,7 +101,7 @@ class Note(object):
 			attachments (list) : An instance of list
 		"""
 
-		if not isinstance(attachments, list):
+		if attachments is not None and not isinstance(attachments, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: attachments EXPECTED TYPE: list', None, None)
 		
 		self.__attachments = attachments
@@ -127,7 +127,7 @@ class Note(object):
 
 		from datetime import datetime
 
-		if not isinstance(created_time, datetime):
+		if created_time is not None and not isinstance(created_time, datetime):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: created_time EXPECTED TYPE: datetime', None, None)
 		
 		self.__created_time = created_time
@@ -156,7 +156,7 @@ class Note(object):
 		except Exception:
 			from ..record import Record
 
-		if not isinstance(parent_id, Record):
+		if parent_id is not None and not isinstance(parent_id, Record):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: parent_id EXPECTED TYPE: Record', None, None)
 		
 		self.__parent_id = parent_id
@@ -177,10 +177,10 @@ class Note(object):
 		The method to set the value to editable
 
 		Parameters:
-			editable (bool) : A bool value
+			editable (bool) : A bool representing the editable
 		"""
 
-		if not isinstance(editable, bool):
+		if editable is not None and not isinstance(editable, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: editable EXPECTED TYPE: bool', None, None)
 		
 		self.__editable = editable
@@ -201,10 +201,10 @@ class Note(object):
 		The method to set the value to se_module
 
 		Parameters:
-			se_module (string) : A string value
+			se_module (string) : A string representing the se_module
 		"""
 
-		if not isinstance(se_module, str):
+		if se_module is not None and not isinstance(se_module, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: se_module EXPECTED TYPE: str', None, None)
 		
 		self.__se_module = se_module
@@ -225,10 +225,10 @@ class Note(object):
 		The method to set the value to is_shared_to_client
 
 		Parameters:
-			is_shared_to_client (bool) : A bool value
+			is_shared_to_client (bool) : A bool representing the is_shared_to_client
 		"""
 
-		if not isinstance(is_shared_to_client, bool):
+		if is_shared_to_client is not None and not isinstance(is_shared_to_client, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: is_shared_to_client EXPECTED TYPE: bool', None, None)
 		
 		self.__is_shared_to_client = is_shared_to_client
@@ -257,7 +257,7 @@ class Note(object):
 		except Exception:
 			from ..users import User
 
-		if not isinstance(modified_by, User):
+		if modified_by is not None and not isinstance(modified_by, User):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modified_by EXPECTED TYPE: User', None, None)
 		
 		self.__modified_by = modified_by
@@ -278,10 +278,10 @@ class Note(object):
 		The method to set the value to size
 
 		Parameters:
-			size (string) : A string value
+			size (string) : A string representing the size
 		"""
 
-		if not isinstance(size, str):
+		if size is not None and not isinstance(size, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: size EXPECTED TYPE: str', None, None)
 		
 		self.__size = size
@@ -302,10 +302,10 @@ class Note(object):
 		The method to set the value to state
 
 		Parameters:
-			state (string) : A string value
+			state (string) : A string representing the state
 		"""
 
-		if not isinstance(state, str):
+		if state is not None and not isinstance(state, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: state EXPECTED TYPE: str', None, None)
 		
 		self.__state = state
@@ -326,10 +326,10 @@ class Note(object):
 		The method to set the value to voice_note
 
 		Parameters:
-			voice_note (bool) : A bool value
+			voice_note (bool) : A bool representing the voice_note
 		"""
 
-		if not isinstance(voice_note, bool):
+		if voice_note is not None and not isinstance(voice_note, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: voice_note EXPECTED TYPE: bool', None, None)
 		
 		self.__voice_note = voice_note
@@ -340,7 +340,7 @@ class Note(object):
 		The method to get the id
 
 		Returns:
-			string: A string value
+			int: A int value
 		"""
 
 		return self.__id
@@ -350,11 +350,11 @@ class Note(object):
 		The method to set the value to id
 
 		Parameters:
-			id (string) : A string value
+			id (int) : An int representing the id
 		"""
 
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		self.__id = id
 		self.__key_modified['id'] = 1
@@ -382,7 +382,7 @@ class Note(object):
 		except Exception:
 			from ..users import User
 
-		if not isinstance(created_by, User):
+		if created_by is not None and not isinstance(created_by, User):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: created_by EXPECTED TYPE: User', None, None)
 		
 		self.__created_by = created_by
@@ -403,10 +403,10 @@ class Note(object):
 		The method to set the value to note_title
 
 		Parameters:
-			note_title (string) : A string value
+			note_title (string) : A string representing the note_title
 		"""
 
-		if not isinstance(note_title, str):
+		if note_title is not None and not isinstance(note_title, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: note_title EXPECTED TYPE: str', None, None)
 		
 		self.__note_title = note_title
@@ -427,10 +427,10 @@ class Note(object):
 		The method to set the value to note_content
 
 		Parameters:
-			note_content (string) : A string value
+			note_content (string) : A string representing the note_content
 		"""
 
-		if not isinstance(note_content, str):
+		if note_content is not None and not isinstance(note_content, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: note_content EXPECTED TYPE: str', None, None)
 		
 		self.__note_content = note_content
@@ -441,13 +441,13 @@ class Note(object):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -460,14 +460,14 @@ class Note(object):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
