@@ -1,15 +1,15 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.parameter_map import ParameterMap
 	from zcrmsdk.src.com.zoho.crm.api.util import APIResponse, CommonAPIHandler, Constants
 	from zcrmsdk.src.com.zoho.crm.api.param import Param
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.header import Header
 	from zcrmsdk.src.com.zoho.crm.api.header_map import HeaderMap
 except Exception:
+	from ..exception import SDKException
 	from ..parameter_map import ParameterMap
 	from ..util import APIResponse, CommonAPIHandler, Constants
 	from ..param import Param
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from ..header import Header
 	from ..header_map import HeaderMap
 
@@ -29,6 +29,9 @@ class NotesOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
@@ -42,6 +45,7 @@ class NotesOperations(object):
 		api_path = api_path + '/crm/v2/Notes'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		handler_instance.param = param_instance
 		handler_instance.header = header_instance
 		try:
@@ -59,6 +63,9 @@ class NotesOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -66,7 +73,7 @@ class NotesOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -74,8 +81,10 @@ class NotesOperations(object):
 		api_path = api_path + '/crm/v2/Notes'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.notes.action_handler import ActionHandler
 		except Exception:
@@ -91,6 +100,9 @@ class NotesOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -98,7 +110,7 @@ class NotesOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -106,8 +118,10 @@ class NotesOperations(object):
 		api_path = api_path + '/crm/v2/Notes'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.notes.action_handler import ActionHandler
 		except Exception:
@@ -123,6 +137,9 @@ class NotesOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
@@ -133,6 +150,7 @@ class NotesOperations(object):
 		api_path = api_path + '/crm/v2/Notes'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
 		handler_instance.param = param_instance
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.notes.action_handler import ActionHandler
@@ -145,14 +163,17 @@ class NotesOperations(object):
 		The method to get note
 
 		Parameters:
-			id (string) : A string value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -160,6 +181,7 @@ class NotesOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.notes.response_handler import ResponseHandler
 		except Exception:
@@ -172,10 +194,13 @@ class NotesOperations(object):
 
 		Parameters:
 			request (BodyWrapper) : An instance of BodyWrapper
-			id (string) : A string value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -183,11 +208,11 @@ class NotesOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -195,6 +220,7 @@ class NotesOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
 		try:
@@ -208,14 +234,17 @@ class NotesOperations(object):
 		The method to delete note
 
 		Parameters:
-			id (string) : A string value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -223,6 +252,7 @@ class NotesOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.notes.action_handler import ActionHandler
 		except Exception:
@@ -232,7 +262,6 @@ class NotesOperations(object):
 
 class GetNotesParam(object):
 	page = Param('page', 'com.zoho.crm.api.Notes.GetNotesParam')
-
 	per_page = Param('per_page', 'com.zoho.crm.api.Notes.GetNotesParam')
 
 
@@ -242,4 +271,3 @@ class GetNotesHeader(object):
 
 class DeleteNotesParam(object):
 	ids = Param('ids', 'com.zoho.crm.api.Notes.DeleteNotesParam')
-
