@@ -1,9 +1,9 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class Org(object):
@@ -58,10 +58,10 @@ class Org(object):
 		The method to set the value to country
 
 		Parameters:
-			country (string) : A string value
+			country (string) : A string representing the country
 		"""
 
-		if not isinstance(country, str):
+		if country is not None and not isinstance(country, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: country EXPECTED TYPE: str', None, None)
 		
 		self.__country = country
@@ -82,10 +82,10 @@ class Org(object):
 		The method to set the value to photo_id
 
 		Parameters:
-			photo_id (string) : A string value
+			photo_id (string) : A string representing the photo_id
 		"""
 
-		if not isinstance(photo_id, str):
+		if photo_id is not None and not isinstance(photo_id, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: photo_id EXPECTED TYPE: str', None, None)
 		
 		self.__photo_id = photo_id
@@ -106,10 +106,10 @@ class Org(object):
 		The method to set the value to city
 
 		Parameters:
-			city (string) : A string value
+			city (string) : A string representing the city
 		"""
 
-		if not isinstance(city, str):
+		if city is not None and not isinstance(city, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: city EXPECTED TYPE: str', None, None)
 		
 		self.__city = city
@@ -130,10 +130,10 @@ class Org(object):
 		The method to set the value to description
 
 		Parameters:
-			description (string) : A string value
+			description (string) : A string representing the description
 		"""
 
-		if not isinstance(description, str):
+		if description is not None and not isinstance(description, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: description EXPECTED TYPE: str', None, None)
 		
 		self.__description = description
@@ -154,10 +154,10 @@ class Org(object):
 		The method to set the value to mc_status
 
 		Parameters:
-			mc_status (bool) : A bool value
+			mc_status (bool) : A bool representing the mc_status
 		"""
 
-		if not isinstance(mc_status, bool):
+		if mc_status is not None and not isinstance(mc_status, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: mc_status EXPECTED TYPE: bool', None, None)
 		
 		self.__mc_status = mc_status
@@ -178,10 +178,10 @@ class Org(object):
 		The method to set the value to gapps_enabled
 
 		Parameters:
-			gapps_enabled (bool) : A bool value
+			gapps_enabled (bool) : A bool representing the gapps_enabled
 		"""
 
-		if not isinstance(gapps_enabled, bool):
+		if gapps_enabled is not None and not isinstance(gapps_enabled, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: gapps_enabled EXPECTED TYPE: bool', None, None)
 		
 		self.__gapps_enabled = gapps_enabled
@@ -202,10 +202,10 @@ class Org(object):
 		The method to set the value to domain_name
 
 		Parameters:
-			domain_name (string) : A string value
+			domain_name (string) : A string representing the domain_name
 		"""
 
-		if not isinstance(domain_name, str):
+		if domain_name is not None and not isinstance(domain_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: domain_name EXPECTED TYPE: str', None, None)
 		
 		self.__domain_name = domain_name
@@ -226,10 +226,10 @@ class Org(object):
 		The method to set the value to translation_enabled
 
 		Parameters:
-			translation_enabled (bool) : A bool value
+			translation_enabled (bool) : A bool representing the translation_enabled
 		"""
 
-		if not isinstance(translation_enabled, bool):
+		if translation_enabled is not None and not isinstance(translation_enabled, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: translation_enabled EXPECTED TYPE: bool', None, None)
 		
 		self.__translation_enabled = translation_enabled
@@ -250,10 +250,10 @@ class Org(object):
 		The method to set the value to street
 
 		Parameters:
-			street (string) : A string value
+			street (string) : A string representing the street
 		"""
 
-		if not isinstance(street, str):
+		if street is not None and not isinstance(street, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: street EXPECTED TYPE: str', None, None)
 		
 		self.__street = street
@@ -274,10 +274,10 @@ class Org(object):
 		The method to set the value to alias
 
 		Parameters:
-			alias (string) : A string value
+			alias (string) : A string representing the alias
 		"""
 
-		if not isinstance(alias, str):
+		if alias is not None and not isinstance(alias, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: alias EXPECTED TYPE: str', None, None)
 		
 		self.__alias = alias
@@ -298,10 +298,10 @@ class Org(object):
 		The method to set the value to currency
 
 		Parameters:
-			currency (string) : A string value
+			currency (string) : A string representing the currency
 		"""
 
-		if not isinstance(currency, str):
+		if currency is not None and not isinstance(currency, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: currency EXPECTED TYPE: str', None, None)
 		
 		self.__currency = currency
@@ -312,7 +312,7 @@ class Org(object):
 		The method to get the id
 
 		Returns:
-			string: A string value
+			int: A int value
 		"""
 
 		return self.__id
@@ -322,11 +322,11 @@ class Org(object):
 		The method to set the value to id
 
 		Parameters:
-			id (string) : A string value
+			id (int) : An int representing the id
 		"""
 
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		self.__id = id
 		self.__key_modified['id'] = 1
@@ -346,10 +346,10 @@ class Org(object):
 		The method to set the value to state
 
 		Parameters:
-			state (string) : A string value
+			state (string) : A string representing the state
 		"""
 
-		if not isinstance(state, str):
+		if state is not None and not isinstance(state, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: state EXPECTED TYPE: str', None, None)
 		
 		self.__state = state
@@ -370,10 +370,10 @@ class Org(object):
 		The method to set the value to fax
 
 		Parameters:
-			fax (string) : A string value
+			fax (string) : A string representing the fax
 		"""
 
-		if not isinstance(fax, str):
+		if fax is not None and not isinstance(fax, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: fax EXPECTED TYPE: str', None, None)
 		
 		self.__fax = fax
@@ -394,10 +394,10 @@ class Org(object):
 		The method to set the value to employee_count
 
 		Parameters:
-			employee_count (string) : A string value
+			employee_count (string) : A string representing the employee_count
 		"""
 
-		if not isinstance(employee_count, str):
+		if employee_count is not None and not isinstance(employee_count, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: employee_count EXPECTED TYPE: str', None, None)
 		
 		self.__employee_count = employee_count
@@ -418,10 +418,10 @@ class Org(object):
 		The method to set the value to zip
 
 		Parameters:
-			zip (string) : A string value
+			zip (string) : A string representing the zip
 		"""
 
-		if not isinstance(zip, str):
+		if zip is not None and not isinstance(zip, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: zip EXPECTED TYPE: str', None, None)
 		
 		self.__zip = zip
@@ -442,10 +442,10 @@ class Org(object):
 		The method to set the value to website
 
 		Parameters:
-			website (string) : A string value
+			website (string) : A string representing the website
 		"""
 
-		if not isinstance(website, str):
+		if website is not None and not isinstance(website, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: website EXPECTED TYPE: str', None, None)
 		
 		self.__website = website
@@ -466,10 +466,10 @@ class Org(object):
 		The method to set the value to currency_symbol
 
 		Parameters:
-			currency_symbol (string) : A string value
+			currency_symbol (string) : A string representing the currency_symbol
 		"""
 
-		if not isinstance(currency_symbol, str):
+		if currency_symbol is not None and not isinstance(currency_symbol, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: currency_symbol EXPECTED TYPE: str', None, None)
 		
 		self.__currency_symbol = currency_symbol
@@ -490,10 +490,10 @@ class Org(object):
 		The method to set the value to mobile
 
 		Parameters:
-			mobile (string) : A string value
+			mobile (string) : A string representing the mobile
 		"""
 
-		if not isinstance(mobile, str):
+		if mobile is not None and not isinstance(mobile, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: mobile EXPECTED TYPE: str', None, None)
 		
 		self.__mobile = mobile
@@ -514,10 +514,10 @@ class Org(object):
 		The method to set the value to currency_locale
 
 		Parameters:
-			currency_locale (string) : A string value
+			currency_locale (string) : A string representing the currency_locale
 		"""
 
-		if not isinstance(currency_locale, str):
+		if currency_locale is not None and not isinstance(currency_locale, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: currency_locale EXPECTED TYPE: str', None, None)
 		
 		self.__currency_locale = currency_locale
@@ -538,10 +538,10 @@ class Org(object):
 		The method to set the value to primary_zuid
 
 		Parameters:
-			primary_zuid (string) : A string value
+			primary_zuid (string) : A string representing the primary_zuid
 		"""
 
-		if not isinstance(primary_zuid, str):
+		if primary_zuid is not None and not isinstance(primary_zuid, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: primary_zuid EXPECTED TYPE: str', None, None)
 		
 		self.__primary_zuid = primary_zuid
@@ -562,10 +562,10 @@ class Org(object):
 		The method to set the value to zia_portal_id
 
 		Parameters:
-			zia_portal_id (string) : A string value
+			zia_portal_id (string) : A string representing the zia_portal_id
 		"""
 
-		if not isinstance(zia_portal_id, str):
+		if zia_portal_id is not None and not isinstance(zia_portal_id, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: zia_portal_id EXPECTED TYPE: str', None, None)
 		
 		self.__zia_portal_id = zia_portal_id
@@ -586,10 +586,10 @@ class Org(object):
 		The method to set the value to time_zone
 
 		Parameters:
-			time_zone (string) : A string value
+			time_zone (string) : A string representing the time_zone
 		"""
 
-		if not isinstance(time_zone, str):
+		if time_zone is not None and not isinstance(time_zone, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: time_zone EXPECTED TYPE: str', None, None)
 		
 		self.__time_zone = time_zone
@@ -610,10 +610,10 @@ class Org(object):
 		The method to set the value to zgid
 
 		Parameters:
-			zgid (string) : A string value
+			zgid (string) : A string representing the zgid
 		"""
 
-		if not isinstance(zgid, str):
+		if zgid is not None and not isinstance(zgid, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: zgid EXPECTED TYPE: str', None, None)
 		
 		self.__zgid = zgid
@@ -634,10 +634,10 @@ class Org(object):
 		The method to set the value to country_code
 
 		Parameters:
-			country_code (string) : A string value
+			country_code (string) : A string representing the country_code
 		"""
 
-		if not isinstance(country_code, str):
+		if country_code is not None and not isinstance(country_code, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: country_code EXPECTED TYPE: str', None, None)
 		
 		self.__country_code = country_code
@@ -666,7 +666,7 @@ class Org(object):
 		except Exception:
 			from .license_details import LicenseDetails
 
-		if not isinstance(license_details, LicenseDetails):
+		if license_details is not None and not isinstance(license_details, LicenseDetails):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: license_details EXPECTED TYPE: LicenseDetails', None, None)
 		
 		self.__license_details = license_details
@@ -687,10 +687,10 @@ class Org(object):
 		The method to set the value to phone
 
 		Parameters:
-			phone (string) : A string value
+			phone (string) : A string representing the phone
 		"""
 
-		if not isinstance(phone, str):
+		if phone is not None and not isinstance(phone, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: phone EXPECTED TYPE: str', None, None)
 		
 		self.__phone = phone
@@ -711,10 +711,10 @@ class Org(object):
 		The method to set the value to company_name
 
 		Parameters:
-			company_name (string) : A string value
+			company_name (string) : A string representing the company_name
 		"""
 
-		if not isinstance(company_name, str):
+		if company_name is not None and not isinstance(company_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: company_name EXPECTED TYPE: str', None, None)
 		
 		self.__company_name = company_name
@@ -735,10 +735,10 @@ class Org(object):
 		The method to set the value to privacy_settings
 
 		Parameters:
-			privacy_settings (bool) : A bool value
+			privacy_settings (bool) : A bool representing the privacy_settings
 		"""
 
-		if not isinstance(privacy_settings, bool):
+		if privacy_settings is not None and not isinstance(privacy_settings, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: privacy_settings EXPECTED TYPE: bool', None, None)
 		
 		self.__privacy_settings = privacy_settings
@@ -759,10 +759,10 @@ class Org(object):
 		The method to set the value to primary_email
 
 		Parameters:
-			primary_email (string) : A string value
+			primary_email (string) : A string representing the primary_email
 		"""
 
-		if not isinstance(primary_email, str):
+		if primary_email is not None and not isinstance(primary_email, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: primary_email EXPECTED TYPE: str', None, None)
 		
 		self.__primary_email = primary_email
@@ -783,10 +783,10 @@ class Org(object):
 		The method to set the value to iso_code
 
 		Parameters:
-			iso_code (string) : A string value
+			iso_code (string) : A string representing the iso_code
 		"""
 
-		if not isinstance(iso_code, str):
+		if iso_code is not None and not isinstance(iso_code, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: iso_code EXPECTED TYPE: str', None, None)
 		
 		self.__iso_code = iso_code
@@ -797,13 +797,13 @@ class Org(object):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -816,14 +816,14 @@ class Org(object):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
