@@ -1,9 +1,9 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class Field(object):
@@ -12,10 +12,10 @@ class Field(object):
 		Creates an instance of Field with the given parameters
 
 		Parameters:
-			api_name (string) : A string value
+			api_name (string) : A string representing the api_name
 		"""
 
-		if not isinstance(api_name, str):
+		if api_name is not None and not isinstance(api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: api_name EXPECTED TYPE: str', None, None)
 		
 		self.__api_name = api_name
@@ -152,6 +152,7 @@ class Field(object):
 
 
 
+
 	class Tasks(object):
 		
 		@classmethod
@@ -228,6 +229,7 @@ class Field(object):
 
 
 
+
 	class Vendors(object):
 		
 		@classmethod
@@ -312,6 +314,7 @@ class Field(object):
 
 
 
+
 	class Calls(object):
 		
 		@classmethod
@@ -408,6 +411,7 @@ class Field(object):
 
 
 
+
 	class Leads(object):
 		
 		@classmethod
@@ -564,6 +568,7 @@ class Field(object):
 
 
 
+
 	class Deals(object):
 		
 		@classmethod
@@ -668,6 +673,7 @@ class Field(object):
 
 
 
+
 	class Campaigns(object):
 		
 		@classmethod
@@ -748,6 +754,7 @@ class Field(object):
 
 
 
+
 	class Quotes(object):
 		
 		@classmethod
@@ -888,6 +895,7 @@ class Field(object):
 
 
 
+
 	class Invoices(object):
 		
 		@classmethod
@@ -1036,6 +1044,7 @@ class Field(object):
 
 
 
+
 	class Attachments(object):
 		
 		@classmethod
@@ -1076,6 +1085,7 @@ class Field(object):
 
 
 
+
 	class Price_Books(object):
 		
 		@classmethod
@@ -1128,6 +1138,7 @@ class Field(object):
 
 
 
+
 	class Sales_Orders(object):
 		
 		@classmethod
@@ -1288,6 +1299,7 @@ class Field(object):
 
 
 
+
 	class Contacts(object):
 		
 		@classmethod
@@ -1476,6 +1488,7 @@ class Field(object):
 
 
 
+
 	class Solutions(object):
 		
 		@classmethod
@@ -1548,6 +1561,7 @@ class Field(object):
 
 
 
+
 	class Events(object):
 		
 		@classmethod
@@ -1672,6 +1686,7 @@ class Field(object):
 
 
 
+
 	class Purchase_Orders(object):
 		
 		@classmethod
@@ -1824,6 +1839,7 @@ class Field(object):
 
 
 
+
 	class Accounts(object):
 		
 		@classmethod
@@ -1972,6 +1988,7 @@ class Field(object):
 
 
 
+
 	class Cases(object):
 		
 		@classmethod
@@ -2088,6 +2105,7 @@ class Field(object):
 
 
 
+
 	class Notes(object):
 		
 		@classmethod
