@@ -1,10 +1,10 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.record.record import Record
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from .record import Record
 
 
@@ -37,7 +37,7 @@ class InventoryLineItems(Record):
 		except Exception:
 			from .line_item_product import LineItemProduct
 
-		if not isinstance(product, LineItemProduct):
+		if product is not None and not isinstance(product, LineItemProduct):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: product EXPECTED TYPE: LineItemProduct', None, None)
 		
 		self.add_key_value('product', product)
@@ -57,10 +57,10 @@ class InventoryLineItems(Record):
 		The method to set the value to quantity
 
 		Parameters:
-			quantity (float) : A float value
+			quantity (float) : A float representing the quantity
 		"""
 
-		if not isinstance(quantity, float):
+		if quantity is not None and not isinstance(quantity, float):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: quantity EXPECTED TYPE: float', None, None)
 		
 		self.add_key_value('quantity', quantity)
@@ -80,10 +80,10 @@ class InventoryLineItems(Record):
 		The method to set the value to discount
 
 		Parameters:
-			discount (string) : A string value
+			discount (string) : A string representing the discount
 		"""
 
-		if not isinstance(discount, str):
+		if discount is not None and not isinstance(discount, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: discount EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('Discount', discount)
@@ -103,10 +103,10 @@ class InventoryLineItems(Record):
 		The method to set the value to total_after_discount
 
 		Parameters:
-			total_after_discount (float) : A float value
+			total_after_discount (float) : A float representing the total_after_discount
 		"""
 
-		if not isinstance(total_after_discount, float):
+		if total_after_discount is not None and not isinstance(total_after_discount, float):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: total_after_discount EXPECTED TYPE: float', None, None)
 		
 		self.add_key_value('total_after_discount', total_after_discount)
@@ -126,10 +126,10 @@ class InventoryLineItems(Record):
 		The method to set the value to net_total
 
 		Parameters:
-			net_total (float) : A float value
+			net_total (float) : A float representing the net_total
 		"""
 
-		if not isinstance(net_total, float):
+		if net_total is not None and not isinstance(net_total, float):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: net_total EXPECTED TYPE: float', None, None)
 		
 		self.add_key_value('net_total', net_total)
@@ -149,10 +149,10 @@ class InventoryLineItems(Record):
 		The method to set the value to book
 
 		Parameters:
-			book (float) : A float value
+			book (float) : A float representing the book
 		"""
 
-		if not isinstance(book, float):
+		if book is not None and not isinstance(book, float):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: book EXPECTED TYPE: float', None, None)
 		
 		self.add_key_value('book', book)
@@ -172,10 +172,10 @@ class InventoryLineItems(Record):
 		The method to set the value to tax
 
 		Parameters:
-			tax (float) : A float value
+			tax (float) : A float representing the tax
 		"""
 
-		if not isinstance(tax, float):
+		if tax is not None and not isinstance(tax, float):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: tax EXPECTED TYPE: float', None, None)
 		
 		self.add_key_value('Tax', tax)
@@ -195,10 +195,10 @@ class InventoryLineItems(Record):
 		The method to set the value to list_price
 
 		Parameters:
-			list_price (float) : A float value
+			list_price (float) : A float representing the list_price
 		"""
 
-		if not isinstance(list_price, float):
+		if list_price is not None and not isinstance(list_price, float):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: list_price EXPECTED TYPE: float', None, None)
 		
 		self.add_key_value('list_price', list_price)
@@ -218,10 +218,10 @@ class InventoryLineItems(Record):
 		The method to set the value to unit_price
 
 		Parameters:
-			unit_price (float) : A float value
+			unit_price (float) : A float representing the unit_price
 		"""
 
-		if not isinstance(unit_price, float):
+		if unit_price is not None and not isinstance(unit_price, float):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: unit_price EXPECTED TYPE: float', None, None)
 		
 		self.add_key_value('unit_price', unit_price)
@@ -241,10 +241,10 @@ class InventoryLineItems(Record):
 		The method to set the value to quantity_in_stock
 
 		Parameters:
-			quantity_in_stock (float) : A float value
+			quantity_in_stock (float) : A float representing the quantity_in_stock
 		"""
 
-		if not isinstance(quantity_in_stock, float):
+		if quantity_in_stock is not None and not isinstance(quantity_in_stock, float):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: quantity_in_stock EXPECTED TYPE: float', None, None)
 		
 		self.add_key_value('quantity_in_stock', quantity_in_stock)
@@ -264,37 +264,14 @@ class InventoryLineItems(Record):
 		The method to set the value to total
 
 		Parameters:
-			total (float) : A float value
+			total (float) : A float representing the total
 		"""
 
-		if not isinstance(total, float):
+		if total is not None and not isinstance(total, float):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: total EXPECTED TYPE: float', None, None)
 		
 		self.add_key_value('total', total)
 
-	def get_id(self):
-		"""
-		The method to get the id
-
-		Returns:
-			string: A string value
-		"""
-
-		return self.get_key_value('id')
-
-	def set_id(self, id):
-		"""
-		The method to set the value to id
-
-		Parameters:
-			id (string) : A string value
-		"""
-
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
-		
-		self.add_key_value('id', id)
-
 	def get_product_description(self):
 		"""
 		The method to get the product_description
@@ -310,10 +287,10 @@ class InventoryLineItems(Record):
 		The method to set the value to product_description
 
 		Parameters:
-			product_description (string) : A string value
+			product_description (string) : A string representing the product_description
 		"""
 
-		if not isinstance(product_description, str):
+		if product_description is not None and not isinstance(product_description, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: product_description EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('product_description', product_description)
@@ -336,7 +313,7 @@ class InventoryLineItems(Record):
 			line_tax (list) : An instance of list
 		"""
 
-		if not isinstance(line_tax, list):
+		if line_tax is not None and not isinstance(line_tax, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: line_tax EXPECTED TYPE: list', None, None)
 		
 		self.add_key_value('line_tax', line_tax)
