@@ -1,10 +1,10 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Choice, Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.record.mass_update_response import MassUpdateResponse
 except Exception:
+	from ..exception import SDKException
 	from ..util import Choice, Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from .mass_update_response import MassUpdateResponse
 
 
@@ -38,7 +38,7 @@ class MassUpdate(MassUpdateResponse):
 			status (Choice) : An instance of Choice
 		"""
 
-		if not isinstance(status, Choice):
+		if status is not None and not isinstance(status, Choice):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: status EXPECTED TYPE: Choice', None, None)
 		
 		self.__status = status
@@ -59,10 +59,10 @@ class MassUpdate(MassUpdateResponse):
 		The method to set the value to failed_count
 
 		Parameters:
-			failed_count (int) : A int value
+			failed_count (int) : An int representing the failed_count
 		"""
 
-		if not isinstance(failed_count, int):
+		if failed_count is not None and not isinstance(failed_count, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: failed_count EXPECTED TYPE: int', None, None)
 		
 		self.__failed_count = failed_count
@@ -83,10 +83,10 @@ class MassUpdate(MassUpdateResponse):
 		The method to set the value to updated_count
 
 		Parameters:
-			updated_count (int) : A int value
+			updated_count (int) : An int representing the updated_count
 		"""
 
-		if not isinstance(updated_count, int):
+		if updated_count is not None and not isinstance(updated_count, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: updated_count EXPECTED TYPE: int', None, None)
 		
 		self.__updated_count = updated_count
@@ -107,10 +107,10 @@ class MassUpdate(MassUpdateResponse):
 		The method to set the value to not_updated_count
 
 		Parameters:
-			not_updated_count (int) : A int value
+			not_updated_count (int) : An int representing the not_updated_count
 		"""
 
-		if not isinstance(not_updated_count, int):
+		if not_updated_count is not None and not isinstance(not_updated_count, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: not_updated_count EXPECTED TYPE: int', None, None)
 		
 		self.__not_updated_count = not_updated_count
@@ -131,10 +131,10 @@ class MassUpdate(MassUpdateResponse):
 		The method to set the value to total_count
 
 		Parameters:
-			total_count (int) : A int value
+			total_count (int) : An int representing the total_count
 		"""
 
-		if not isinstance(total_count, int):
+		if total_count is not None and not isinstance(total_count, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: total_count EXPECTED TYPE: int', None, None)
 		
 		self.__total_count = total_count
@@ -145,13 +145,13 @@ class MassUpdate(MassUpdateResponse):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -164,14 +164,14 @@ class MassUpdate(MassUpdateResponse):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
