@@ -1,15 +1,15 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.parameter_map import ParameterMap
 	from zcrmsdk.src.com.zoho.crm.api.util import APIResponse, CommonAPIHandler, Utility, Constants
 	from zcrmsdk.src.com.zoho.crm.api.param import Param
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.header import Header
 	from zcrmsdk.src.com.zoho.crm.api.header_map import HeaderMap
 except Exception:
+	from ..exception import SDKException
 	from ..parameter_map import ParameterMap
 	from ..util import APIResponse, CommonAPIHandler, Utility, Constants
 	from ..param import Param
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from ..header import Header
 	from ..header_map import HeaderMap
 
@@ -26,11 +26,14 @@ class RecordOperations(object):
 		Parameters:
 			param_instance (ParameterMap) : An instance of ParameterMap
 			header_instance (HeaderMap) : An instance of HeaderMap
-			module_api_name (string) : A string value
-			id (int) : A int value
+			module_api_name (string) : A string representing the module_api_name
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
@@ -39,10 +42,10 @@ class RecordOperations(object):
 		if header_instance is not None and not isinstance(header_instance, HeaderMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(id, int):
+		if id is not None and not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -53,6 +56,7 @@ class RecordOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		handler_instance.param = param_instance
 		handler_instance.header = header_instance
 		Utility.get_fields(module_api_name)
@@ -69,11 +73,14 @@ class RecordOperations(object):
 
 		Parameters:
 			request (BodyWrapper) : An instance of BodyWrapper
-			module_api_name (string) : A string value
-			id (int) : A int value
+			module_api_name (string) : A string representing the module_api_name
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -81,13 +88,13 @@ class RecordOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(id, int):
+		if id is not None and not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -98,6 +105,7 @@ class RecordOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
 		Utility.get_fields(module_api_name)
@@ -114,20 +122,23 @@ class RecordOperations(object):
 
 		Parameters:
 			param_instance (ParameterMap) : An instance of ParameterMap
-			module_api_name (string) : A string value
-			id (int) : A int value
+			module_api_name (string) : A string representing the module_api_name
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(id, int):
+		if id is not None and not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -138,9 +149,8 @@ class RecordOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
 		handler_instance.param = param_instance
-		Utility.get_fields(module_api_name)
-		handler_instance.module_api_name = module_api_name
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
@@ -154,10 +164,13 @@ class RecordOperations(object):
 		Parameters:
 			param_instance (ParameterMap) : An instance of ParameterMap
 			header_instance (HeaderMap) : An instance of HeaderMap
-			module_api_name (string) : A string value
+			module_api_name (string) : A string representing the module_api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
@@ -166,7 +179,7 @@ class RecordOperations(object):
 		if header_instance is not None and not isinstance(header_instance, HeaderMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -175,6 +188,7 @@ class RecordOperations(object):
 		api_path = api_path + str(module_api_name)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		handler_instance.param = param_instance
 		handler_instance.header = header_instance
 		Utility.get_fields(module_api_name)
@@ -191,10 +205,13 @@ class RecordOperations(object):
 
 		Parameters:
 			request (BodyWrapper) : An instance of BodyWrapper
-			module_api_name (string) : A string value
+			module_api_name (string) : A string representing the module_api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -202,10 +219,10 @@ class RecordOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -214,8 +231,10 @@ class RecordOperations(object):
 		api_path = api_path + str(module_api_name)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		Utility.get_fields(module_api_name)
 		handler_instance.module_api_name = module_api_name
 		try:
@@ -230,10 +249,13 @@ class RecordOperations(object):
 
 		Parameters:
 			request (BodyWrapper) : An instance of BodyWrapper
-			module_api_name (string) : A string value
+			module_api_name (string) : A string representing the module_api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -241,10 +263,10 @@ class RecordOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -253,8 +275,10 @@ class RecordOperations(object):
 		api_path = api_path + str(module_api_name)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		Utility.get_fields(module_api_name)
 		handler_instance.module_api_name = module_api_name
 		try:
@@ -269,16 +293,19 @@ class RecordOperations(object):
 
 		Parameters:
 			param_instance (ParameterMap) : An instance of ParameterMap
-			module_api_name (string) : A string value
+			module_api_name (string) : A string representing the module_api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -287,9 +314,8 @@ class RecordOperations(object):
 		api_path = api_path + str(module_api_name)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
 		handler_instance.param = param_instance
-		Utility.get_fields(module_api_name)
-		handler_instance.module_api_name = module_api_name
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
@@ -302,10 +328,13 @@ class RecordOperations(object):
 
 		Parameters:
 			request (BodyWrapper) : An instance of BodyWrapper
-			module_api_name (string) : A string value
+			module_api_name (string) : A string representing the module_api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -313,10 +342,10 @@ class RecordOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -326,6 +355,7 @@ class RecordOperations(object):
 		api_path = api_path + '/upsert'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_ACTION
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
 		Utility.get_fields(module_api_name)
@@ -343,10 +373,13 @@ class RecordOperations(object):
 		Parameters:
 			param_instance (ParameterMap) : An instance of ParameterMap
 			header_instance (HeaderMap) : An instance of HeaderMap
-			module_api_name (string) : A string value
+			module_api_name (string) : A string representing the module_api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
@@ -355,7 +388,7 @@ class RecordOperations(object):
 		if header_instance is not None and not isinstance(header_instance, HeaderMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -365,10 +398,9 @@ class RecordOperations(object):
 		api_path = api_path + '/deleted'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		handler_instance.param = param_instance
 		handler_instance.header = header_instance
-		Utility.get_fields(module_api_name)
-		handler_instance.module_api_name = module_api_name
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.deleted_records_handler import DeletedRecordsHandler
 		except Exception:
@@ -381,16 +413,19 @@ class RecordOperations(object):
 
 		Parameters:
 			param_instance (ParameterMap) : An instance of ParameterMap
-			module_api_name (string) : A string value
+			module_api_name (string) : A string representing the module_api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -400,6 +435,7 @@ class RecordOperations(object):
 		api_path = api_path + '/search'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		handler_instance.param = param_instance
 		Utility.get_fields(module_api_name)
 		handler_instance.module_api_name = module_api_name
@@ -415,10 +451,13 @@ class RecordOperations(object):
 
 		Parameters:
 			request (ConvertBodyWrapper) : An instance of ConvertBodyWrapper
-			id (int) : A int value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -426,10 +465,10 @@ class RecordOperations(object):
 		except Exception:
 			from .convert_body_wrapper import ConvertBodyWrapper
 
-		if not isinstance(request, ConvertBodyWrapper):
+		if request is not None and not isinstance(request, ConvertBodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: ConvertBodyWrapper', None, None)
 		
-		if not isinstance(id, int):
+		if id is not None and not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -439,8 +478,10 @@ class RecordOperations(object):
 		api_path = api_path + '/actions/convert'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		Utility.get_fields("Deals")
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.convert_action_handler import ConvertActionHandler
@@ -453,17 +494,20 @@ class RecordOperations(object):
 		The method to get photo
 
 		Parameters:
-			module_api_name (string) : A string value
-			id (int) : A int value
+			module_api_name (string) : A string representing the module_api_name
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(id, int):
+		if id is not None and not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -475,6 +519,7 @@ class RecordOperations(object):
 		api_path = api_path + '/photo'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.download_handler import DownloadHandler
 		except Exception:
@@ -487,11 +532,14 @@ class RecordOperations(object):
 
 		Parameters:
 			request (FileBodyWrapper) : An instance of FileBodyWrapper
-			module_api_name (string) : A string value
-			id (int) : A int value
+			module_api_name (string) : A string representing the module_api_name
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -499,13 +547,13 @@ class RecordOperations(object):
 		except Exception:
 			from .file_body_wrapper import FileBodyWrapper
 
-		if not isinstance(request, FileBodyWrapper):
+		if request is not None and not isinstance(request, FileBodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: FileBodyWrapper', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(id, int):
+		if id is not None and not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -517,8 +565,10 @@ class RecordOperations(object):
 		api_path = api_path + '/photo'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.content_type = 'multipart/form-data'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.file_handler import FileHandler
 		except Exception:
@@ -530,17 +580,20 @@ class RecordOperations(object):
 		The method to delete photo
 
 		Parameters:
-			module_api_name (string) : A string value
-			id (int) : A int value
+			module_api_name (string) : A string representing the module_api_name
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(id, int):
+		if id is not None and not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -552,6 +605,7 @@ class RecordOperations(object):
 		api_path = api_path + '/photo'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.file_handler import FileHandler
 		except Exception:
@@ -564,10 +618,13 @@ class RecordOperations(object):
 
 		Parameters:
 			request (MassUpdateBodyWrapper) : An instance of MassUpdateBodyWrapper
-			module_api_name (string) : A string value
+			module_api_name (string) : A string representing the module_api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -575,10 +632,10 @@ class RecordOperations(object):
 		except Exception:
 			from .mass_update_body_wrapper import MassUpdateBodyWrapper
 
-		if not isinstance(request, MassUpdateBodyWrapper):
+		if request is not None and not isinstance(request, MassUpdateBodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: MassUpdateBodyWrapper', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -588,8 +645,10 @@ class RecordOperations(object):
 		api_path = api_path + '/actions/mass_update'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		Utility.get_fields(module_api_name)
 		handler_instance.module_api_name = module_api_name
 		try:
@@ -604,16 +663,19 @@ class RecordOperations(object):
 
 		Parameters:
 			param_instance (ParameterMap) : An instance of ParameterMap
-			module_api_name (string) : A string value
+			module_api_name (string) : A string representing the module_api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -623,6 +685,7 @@ class RecordOperations(object):
 		api_path = api_path + '/actions/mass_update'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		handler_instance.param = param_instance
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.mass_update_response_handler import MassUpdateResponseHandler
@@ -633,21 +696,13 @@ class RecordOperations(object):
 
 class GetRecordParam(object):
 	approved = Param('approved', 'com.zoho.crm.api.Record.GetRecordParam')
-
 	converted = Param('converted', 'com.zoho.crm.api.Record.GetRecordParam')
-
 	cvid = Param('cvid', 'com.zoho.crm.api.Record.GetRecordParam')
-
 	uid = Param('uid', 'com.zoho.crm.api.Record.GetRecordParam')
-
 	fields = Param('fields', 'com.zoho.crm.api.Record.GetRecordParam')
-
 	startdatetime = Param('startDateTime', 'com.zoho.crm.api.Record.GetRecordParam')
-
 	enddatetime = Param('endDateTime', 'com.zoho.crm.api.Record.GetRecordParam')
-
 	territory_id = Param('territory_id', 'com.zoho.crm.api.Record.GetRecordParam')
-
 	include_child = Param('include_child', 'com.zoho.crm.api.Record.GetRecordParam')
 
 
@@ -661,31 +716,18 @@ class DeleteRecordParam(object):
 
 class GetRecordsParam(object):
 	approved = Param('approved', 'com.zoho.crm.api.Record.GetRecordsParam')
-
 	converted = Param('converted', 'com.zoho.crm.api.Record.GetRecordsParam')
-
 	cvid = Param('cvid', 'com.zoho.crm.api.Record.GetRecordsParam')
-
 	ids = Param('ids', 'com.zoho.crm.api.Record.GetRecordsParam')
-
 	uid = Param('uid', 'com.zoho.crm.api.Record.GetRecordsParam')
-
 	fields = Param('fields', 'com.zoho.crm.api.Record.GetRecordsParam')
-
 	sort_by = Param('sort_by', 'com.zoho.crm.api.Record.GetRecordsParam')
-
 	sort_order = Param('sort_order', 'com.zoho.crm.api.Record.GetRecordsParam')
-
 	page = Param('page', 'com.zoho.crm.api.Record.GetRecordsParam')
-
 	per_page = Param('per_page', 'com.zoho.crm.api.Record.GetRecordsParam')
-
 	startdatetime = Param('startDateTime', 'com.zoho.crm.api.Record.GetRecordsParam')
-
 	enddatetime = Param('endDateTime', 'com.zoho.crm.api.Record.GetRecordsParam')
-
 	territory_id = Param('territory_id', 'com.zoho.crm.api.Record.GetRecordsParam')
-
 	include_child = Param('include_child', 'com.zoho.crm.api.Record.GetRecordsParam')
 
 
@@ -695,15 +737,12 @@ class GetRecordsHeader(object):
 
 class DeleteRecordsParam(object):
 	ids = Param('ids', 'com.zoho.crm.api.Record.DeleteRecordsParam')
-
 	wf_trigger = Param('wf_trigger', 'com.zoho.crm.api.Record.DeleteRecordsParam')
 
 
 class GetDeletedRecordsParam(object):
 	type = Param('type', 'com.zoho.crm.api.Record.GetDeletedRecordsParam')
-
 	page = Param('page', 'com.zoho.crm.api.Record.GetDeletedRecordsParam')
-
 	per_page = Param('per_page', 'com.zoho.crm.api.Record.GetDeletedRecordsParam')
 
 
@@ -713,22 +752,14 @@ class GetDeletedRecordsHeader(object):
 
 class SearchRecordsParam(object):
 	criteria = Param('criteria', 'com.zoho.crm.api.Record.SearchRecordsParam')
-
 	email = Param('email', 'com.zoho.crm.api.Record.SearchRecordsParam')
-
 	phone = Param('phone', 'com.zoho.crm.api.Record.SearchRecordsParam')
-
 	word = Param('word', 'com.zoho.crm.api.Record.SearchRecordsParam')
-
 	converted = Param('converted', 'com.zoho.crm.api.Record.SearchRecordsParam')
-
 	approved = Param('approved', 'com.zoho.crm.api.Record.SearchRecordsParam')
-
 	page = Param('page', 'com.zoho.crm.api.Record.SearchRecordsParam')
-
 	per_page = Param('per_page', 'com.zoho.crm.api.Record.SearchRecordsParam')
 
 
 class GetMassUpdateStatusParam(object):
 	job_id = Param('job_id', 'com.zoho.crm.api.Record.GetMassUpdateStatusParam')
-
