@@ -1,11 +1,11 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Choice, Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.record.action_response import ActionResponse
 	from zcrmsdk.src.com.zoho.crm.api.record.file_handler import FileHandler
 except Exception:
+	from ..exception import SDKException
 	from ..util import Choice, Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from .action_response import ActionResponse
 	from .file_handler import FileHandler
 
@@ -41,7 +41,7 @@ class SuccessResponse(ActionResponse, FileHandler):
 			status (Choice) : An instance of Choice
 		"""
 
-		if not isinstance(status, Choice):
+		if status is not None and not isinstance(status, Choice):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: status EXPECTED TYPE: Choice', None, None)
 		
 		self.__status = status
@@ -65,7 +65,7 @@ class SuccessResponse(ActionResponse, FileHandler):
 			code (Choice) : An instance of Choice
 		"""
 
-		if not isinstance(code, Choice):
+		if code is not None and not isinstance(code, Choice):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: code EXPECTED TYPE: Choice', None, None)
 		
 		self.__code = code
@@ -86,10 +86,10 @@ class SuccessResponse(ActionResponse, FileHandler):
 		The method to set the value to duplicate_field
 
 		Parameters:
-			duplicate_field (string) : A string value
+			duplicate_field (string) : A string representing the duplicate_field
 		"""
 
-		if not isinstance(duplicate_field, str):
+		if duplicate_field is not None and not isinstance(duplicate_field, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: duplicate_field EXPECTED TYPE: str', None, None)
 		
 		self.__duplicate_field = duplicate_field
@@ -113,7 +113,7 @@ class SuccessResponse(ActionResponse, FileHandler):
 			action (Choice) : An instance of Choice
 		"""
 
-		if not isinstance(action, Choice):
+		if action is not None and not isinstance(action, Choice):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: action EXPECTED TYPE: Choice', None, None)
 		
 		self.__action = action
@@ -137,7 +137,7 @@ class SuccessResponse(ActionResponse, FileHandler):
 			message (Choice) : An instance of Choice
 		"""
 
-		if not isinstance(message, Choice):
+		if message is not None and not isinstance(message, Choice):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: message EXPECTED TYPE: Choice', None, None)
 		
 		self.__message = message
@@ -161,7 +161,7 @@ class SuccessResponse(ActionResponse, FileHandler):
 			details (dict) : An instance of dict
 		"""
 
-		if not isinstance(details, dict):
+		if details is not None and not isinstance(details, dict):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: details EXPECTED TYPE: dict', None, None)
 		
 		self.__details = details
@@ -172,13 +172,13 @@ class SuccessResponse(ActionResponse, FileHandler):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -191,14 +191,14 @@ class SuccessResponse(ActionResponse, FileHandler):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
