@@ -1,10 +1,10 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.record.convert_action_response import ConvertActionResponse
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from .convert_action_response import ConvertActionResponse
 
 
@@ -33,10 +33,10 @@ class SuccessfulConvert(ConvertActionResponse):
 		The method to set the value to contacts
 
 		Parameters:
-			contacts (string) : A string value
+			contacts (string) : A string representing the contacts
 		"""
 
-		if not isinstance(contacts, str):
+		if contacts is not None and not isinstance(contacts, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: contacts EXPECTED TYPE: str', None, None)
 		
 		self.__contacts = contacts
@@ -57,10 +57,10 @@ class SuccessfulConvert(ConvertActionResponse):
 		The method to set the value to deals
 
 		Parameters:
-			deals (string) : A string value
+			deals (string) : A string representing the deals
 		"""
 
-		if not isinstance(deals, str):
+		if deals is not None and not isinstance(deals, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: deals EXPECTED TYPE: str', None, None)
 		
 		self.__deals = deals
@@ -81,10 +81,10 @@ class SuccessfulConvert(ConvertActionResponse):
 		The method to set the value to accounts
 
 		Parameters:
-			accounts (string) : A string value
+			accounts (string) : A string representing the accounts
 		"""
 
-		if not isinstance(accounts, str):
+		if accounts is not None and not isinstance(accounts, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: accounts EXPECTED TYPE: str', None, None)
 		
 		self.__accounts = accounts
@@ -95,13 +95,13 @@ class SuccessfulConvert(ConvertActionResponse):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -114,14 +114,14 @@ class SuccessfulConvert(ConvertActionResponse):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
