@@ -1,10 +1,10 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.related_records.response_handler import ResponseHandler
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from .response_handler import ResponseHandler
 
 
@@ -35,7 +35,7 @@ class ResponseWrapper(ResponseHandler):
 			data (list) : An instance of list
 		"""
 
-		if not isinstance(data, list):
+		if data is not None and not isinstance(data, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: data EXPECTED TYPE: list', None, None)
 		
 		self.__data = data
@@ -64,7 +64,7 @@ class ResponseWrapper(ResponseHandler):
 		except Exception:
 			from ..record import Info
 
-		if not isinstance(info, Info):
+		if info is not None and not isinstance(info, Info):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: info EXPECTED TYPE: Info', None, None)
 		
 		self.__info = info
@@ -75,13 +75,13 @@ class ResponseWrapper(ResponseHandler):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -94,14 +94,14 @@ class ResponseWrapper(ResponseHandler):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
