@@ -1,14 +1,14 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Choice, Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.share_records.action_response import ActionResponse
 	from zcrmsdk.src.com.zoho.crm.api.share_records.response_handler import ResponseHandler
 	from zcrmsdk.src.com.zoho.crm.api.share_records.delete_action_handler import DeleteActionHandler
 	from zcrmsdk.src.com.zoho.crm.api.share_records.action_handler import ActionHandler
 	from zcrmsdk.src.com.zoho.crm.api.share_records.delete_action_response import DeleteActionResponse
 except Exception:
+	from ..exception import SDKException
 	from ..util import Choice, Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from .action_response import ActionResponse
 	from .response_handler import ResponseHandler
 	from .delete_action_handler import DeleteActionHandler
@@ -45,7 +45,7 @@ class APIException(ResponseHandler, ActionResponse, ActionHandler, DeleteActionR
 			status (Choice) : An instance of Choice
 		"""
 
-		if not isinstance(status, Choice):
+		if status is not None and not isinstance(status, Choice):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: status EXPECTED TYPE: Choice', None, None)
 		
 		self.__status = status
@@ -69,7 +69,7 @@ class APIException(ResponseHandler, ActionResponse, ActionHandler, DeleteActionR
 			code (Choice) : An instance of Choice
 		"""
 
-		if not isinstance(code, Choice):
+		if code is not None and not isinstance(code, Choice):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: code EXPECTED TYPE: Choice', None, None)
 		
 		self.__code = code
@@ -93,7 +93,7 @@ class APIException(ResponseHandler, ActionResponse, ActionHandler, DeleteActionR
 			message (Choice) : An instance of Choice
 		"""
 
-		if not isinstance(message, Choice):
+		if message is not None and not isinstance(message, Choice):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: message EXPECTED TYPE: Choice', None, None)
 		
 		self.__message = message
@@ -117,7 +117,7 @@ class APIException(ResponseHandler, ActionResponse, ActionHandler, DeleteActionR
 			details (dict) : An instance of dict
 		"""
 
-		if not isinstance(details, dict):
+		if details is not None and not isinstance(details, dict):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: details EXPECTED TYPE: dict', None, None)
 		
 		self.__details = details
@@ -128,13 +128,13 @@ class APIException(ResponseHandler, ActionResponse, ActionHandler, DeleteActionR
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -147,14 +147,14 @@ class APIException(ResponseHandler, ActionResponse, ActionHandler, DeleteActionR
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
