@@ -1,6 +1,6 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Choice, Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.tags.action_response import ActionResponse
 	from zcrmsdk.src.com.zoho.crm.api.tags.response_handler import ResponseHandler
 	from zcrmsdk.src.com.zoho.crm.api.tags.count_handler import CountHandler
@@ -8,8 +8,8 @@ try:
 	from zcrmsdk.src.com.zoho.crm.api.tags.record_action_response import RecordActionResponse
 	from zcrmsdk.src.com.zoho.crm.api.tags.record_action_handler import RecordActionHandler
 except Exception:
+	from ..exception import SDKException
 	from ..util import Choice, Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from .action_response import ActionResponse
 	from .response_handler import ResponseHandler
 	from .count_handler import CountHandler
@@ -47,7 +47,7 @@ class APIException(ResponseHandler, ActionResponse, ActionHandler, RecordActionR
 			status (Choice) : An instance of Choice
 		"""
 
-		if not isinstance(status, Choice):
+		if status is not None and not isinstance(status, Choice):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: status EXPECTED TYPE: Choice', None, None)
 		
 		self.__status = status
@@ -71,7 +71,7 @@ class APIException(ResponseHandler, ActionResponse, ActionHandler, RecordActionR
 			code (Choice) : An instance of Choice
 		"""
 
-		if not isinstance(code, Choice):
+		if code is not None and not isinstance(code, Choice):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: code EXPECTED TYPE: Choice', None, None)
 		
 		self.__code = code
@@ -95,7 +95,7 @@ class APIException(ResponseHandler, ActionResponse, ActionHandler, RecordActionR
 			message (Choice) : An instance of Choice
 		"""
 
-		if not isinstance(message, Choice):
+		if message is not None and not isinstance(message, Choice):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: message EXPECTED TYPE: Choice', None, None)
 		
 		self.__message = message
@@ -119,7 +119,7 @@ class APIException(ResponseHandler, ActionResponse, ActionHandler, RecordActionR
 			details (dict) : An instance of dict
 		"""
 
-		if not isinstance(details, dict):
+		if details is not None and not isinstance(details, dict):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: details EXPECTED TYPE: dict', None, None)
 		
 		self.__details = details
@@ -130,13 +130,13 @@ class APIException(ResponseHandler, ActionResponse, ActionHandler, RecordActionR
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -149,14 +149,14 @@ class APIException(ResponseHandler, ActionResponse, ActionHandler, RecordActionR
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
