@@ -1,13 +1,13 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.parameter_map import ParameterMap
 	from zcrmsdk.src.com.zoho.crm.api.util import APIResponse, CommonAPIHandler, Constants
 	from zcrmsdk.src.com.zoho.crm.api.param import Param
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..parameter_map import ParameterMap
 	from ..util import APIResponse, CommonAPIHandler, Constants
 	from ..param import Param
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class TagsOperations(object):
@@ -24,6 +24,9 @@ class TagsOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
@@ -34,6 +37,7 @@ class TagsOperations(object):
 		api_path = api_path + '/crm/v2/settings/tags'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		handler_instance.param = param_instance
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.response_handler import ResponseHandler
@@ -51,6 +55,9 @@ class TagsOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -58,7 +65,7 @@ class TagsOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
@@ -69,9 +76,11 @@ class TagsOperations(object):
 		api_path = api_path + '/crm/v2/settings/tags'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
 		handler_instance.param = param_instance
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.action_handler import ActionHandler
 		except Exception:
@@ -88,6 +97,9 @@ class TagsOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -95,7 +107,7 @@ class TagsOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
@@ -106,9 +118,11 @@ class TagsOperations(object):
 		api_path = api_path + '/crm/v2/settings/tags'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
 		handler_instance.param = param_instance
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.action_handler import ActionHandler
 		except Exception:
@@ -122,10 +136,13 @@ class TagsOperations(object):
 		Parameters:
 			request (BodyWrapper) : An instance of BodyWrapper
 			param_instance (ParameterMap) : An instance of ParameterMap
-			id (string) : A string value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -133,14 +150,14 @@ class TagsOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -148,6 +165,7 @@ class TagsOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
 		handler_instance.param = param_instance
@@ -162,14 +180,17 @@ class TagsOperations(object):
 		The method to delete tag
 
 		Parameters:
-			id (string) : A string value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -177,6 +198,7 @@ class TagsOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.action_handler import ActionHandler
 		except Exception:
@@ -189,10 +211,13 @@ class TagsOperations(object):
 
 		Parameters:
 			request (MergeWrapper) : An instance of MergeWrapper
-			id (string) : A string value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -200,11 +225,11 @@ class TagsOperations(object):
 		except Exception:
 			from .merge_wrapper import MergeWrapper
 
-		if not isinstance(request, MergeWrapper):
+		if request is not None and not isinstance(request, MergeWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: MergeWrapper', None, None)
 		
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -213,8 +238,10 @@ class TagsOperations(object):
 		api_path = api_path + '/actions/merge'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.action_handler import ActionHandler
 		except Exception:
@@ -227,20 +254,23 @@ class TagsOperations(object):
 
 		Parameters:
 			param_instance (ParameterMap) : An instance of ParameterMap
-			module_api_name (string) : A string value
-			record_id (int) : A int value
+			module_api_name (string) : A string representing the module_api_name
+			record_id (int) : An int representing the record_id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(record_id, int):
+		if record_id is not None and not isinstance(record_id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: record_id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -252,7 +282,9 @@ class TagsOperations(object):
 		api_path = api_path + '/actions/add_tags'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.param = param_instance
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.record_action_handler import RecordActionHandler
 		except Exception:
@@ -265,20 +297,23 @@ class TagsOperations(object):
 
 		Parameters:
 			param_instance (ParameterMap) : An instance of ParameterMap
-			module_api_name (string) : A string value
-			record_id (int) : A int value
+			module_api_name (string) : A string representing the module_api_name
+			record_id (int) : An int representing the record_id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(record_id, int):
+		if record_id is not None and not isinstance(record_id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: record_id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -290,7 +325,9 @@ class TagsOperations(object):
 		api_path = api_path + '/actions/remove_tags'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.param = param_instance
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.record_action_handler import RecordActionHandler
 		except Exception:
@@ -303,16 +340,19 @@ class TagsOperations(object):
 
 		Parameters:
 			param_instance (ParameterMap) : An instance of ParameterMap
-			module_api_name (string) : A string value
+			module_api_name (string) : A string representing the module_api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -322,7 +362,9 @@ class TagsOperations(object):
 		api_path = api_path + '/actions/add_tags'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.param = param_instance
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.record_action_handler import RecordActionHandler
 		except Exception:
@@ -335,16 +377,19 @@ class TagsOperations(object):
 
 		Parameters:
 			param_instance (ParameterMap) : An instance of ParameterMap
-			module_api_name (string) : A string value
+			module_api_name (string) : A string representing the module_api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if not isinstance(module_api_name, str):
+		if module_api_name is not None and not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -354,7 +399,9 @@ class TagsOperations(object):
 		api_path = api_path + '/actions/remove_tags'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.param = param_instance
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.record_action_handler import RecordActionHandler
 		except Exception:
@@ -367,17 +414,20 @@ class TagsOperations(object):
 
 		Parameters:
 			param_instance (ParameterMap) : An instance of ParameterMap
-			id (string) : A string value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
+		if id is not None and not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
@@ -386,6 +436,7 @@ class TagsOperations(object):
 		api_path = api_path + '/actions/records_count'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		handler_instance.param = param_instance
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.tags.count_handler import CountHandler
@@ -396,7 +447,6 @@ class TagsOperations(object):
 
 class GetTagsParam(object):
 	module = Param('module', 'com.zoho.crm.api.Tags.GetTagsParam')
-
 	my_tags = Param('my_tags', 'com.zoho.crm.api.Tags.GetTagsParam')
 
 
@@ -414,7 +464,6 @@ class UpdateTagParam(object):
 
 class AddTagsToRecordParam(object):
 	tag_names = Param('tag_names', 'com.zoho.crm.api.Tags.AddTagsToRecordParam')
-
 	over_write = Param('over_write', 'com.zoho.crm.api.Tags.AddTagsToRecordParam')
 
 
@@ -424,18 +473,14 @@ class RemoveTagsFromRecordParam(object):
 
 class AddTagsToMultipleRecordsParam(object):
 	tag_names = Param('tag_names', 'com.zoho.crm.api.Tags.AddTagsToMultipleRecordsParam')
-
 	ids = Param('ids', 'com.zoho.crm.api.Tags.AddTagsToMultipleRecordsParam')
-
 	over_write = Param('over_write', 'com.zoho.crm.api.Tags.AddTagsToMultipleRecordsParam')
 
 
 class RemoveTagsFromMultipleRecordsParam(object):
 	tag_names = Param('tag_names', 'com.zoho.crm.api.Tags.RemoveTagsFromMultipleRecordsParam')
-
 	ids = Param('ids', 'com.zoho.crm.api.Tags.RemoveTagsFromMultipleRecordsParam')
 
 
 class GetRecordCountForTagParam(object):
 	module = Param('module', 'com.zoho.crm.api.Tags.GetRecordCountForTagParam')
-
