@@ -1,9 +1,9 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class CustomizeInfo(object):
@@ -33,10 +33,10 @@ class CustomizeInfo(object):
 		The method to set the value to notes_desc
 
 		Parameters:
-			notes_desc (bool) : A bool value
+			notes_desc (bool) : A bool representing the notes_desc
 		"""
 
-		if not isinstance(notes_desc, bool):
+		if notes_desc is not None and not isinstance(notes_desc, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: notes_desc EXPECTED TYPE: bool', None, None)
 		
 		self.__notes_desc = notes_desc
@@ -57,10 +57,10 @@ class CustomizeInfo(object):
 		The method to set the value to show_right_panel
 
 		Parameters:
-			show_right_panel (string) : A string value
+			show_right_panel (string) : A string representing the show_right_panel
 		"""
 
-		if not isinstance(show_right_panel, str):
+		if show_right_panel is not None and not isinstance(show_right_panel, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: show_right_panel EXPECTED TYPE: str', None, None)
 		
 		self.__show_right_panel = show_right_panel
@@ -81,10 +81,10 @@ class CustomizeInfo(object):
 		The method to set the value to bc_view
 
 		Parameters:
-			bc_view (string) : A string value
+			bc_view (string) : A string representing the bc_view
 		"""
 
-		if not isinstance(bc_view, str):
+		if bc_view is not None and not isinstance(bc_view, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: bc_view EXPECTED TYPE: str', None, None)
 		
 		self.__bc_view = bc_view
@@ -105,10 +105,10 @@ class CustomizeInfo(object):
 		The method to set the value to show_home
 
 		Parameters:
-			show_home (bool) : A bool value
+			show_home (bool) : A bool representing the show_home
 		"""
 
-		if not isinstance(show_home, bool):
+		if show_home is not None and not isinstance(show_home, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: show_home EXPECTED TYPE: bool', None, None)
 		
 		self.__show_home = show_home
@@ -129,10 +129,10 @@ class CustomizeInfo(object):
 		The method to set the value to show_detail_view
 
 		Parameters:
-			show_detail_view (bool) : A bool value
+			show_detail_view (bool) : A bool representing the show_detail_view
 		"""
 
-		if not isinstance(show_detail_view, bool):
+		if show_detail_view is not None and not isinstance(show_detail_view, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: show_detail_view EXPECTED TYPE: bool', None, None)
 		
 		self.__show_detail_view = show_detail_view
@@ -153,10 +153,10 @@ class CustomizeInfo(object):
 		The method to set the value to unpin_recent_item
 
 		Parameters:
-			unpin_recent_item (string) : A string value
+			unpin_recent_item (string) : A string representing the unpin_recent_item
 		"""
 
-		if not isinstance(unpin_recent_item, str):
+		if unpin_recent_item is not None and not isinstance(unpin_recent_item, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: unpin_recent_item EXPECTED TYPE: str', None, None)
 		
 		self.__unpin_recent_item = unpin_recent_item
@@ -167,13 +167,13 @@ class CustomizeInfo(object):
 		The method to check if the user has modified the given key
 
 		Parameters:
-			key (string) : A string value
+			key (string) : A string representing the key
 
 		Returns:
 			int: A int value
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
 		if key in self.__key_modified:
@@ -186,14 +186,14 @@ class CustomizeInfo(object):
 		The method to mark the given key as modified
 
 		Parameters:
-			key (string) : A string value
-			modification (int) : A int value
+			key (string) : A string representing the key
+			modification (int) : An int representing the modification
 		"""
 
-		if not isinstance(key, str):
+		if key is not None and not isinstance(key, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: key EXPECTED TYPE: str', None, None)
 		
-		if not isinstance(modification, int):
+		if modification is not None and not isinstance(modification, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modification EXPECTED TYPE: int', None, None)
 		
 		self.__key_modified[key] = modification
