@@ -1,11 +1,11 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.util import Constants
 	from zcrmsdk.src.com.zoho.crm.api.record import Record
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..util import Constants
 	from ..record import Record
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class User(Record):
@@ -29,10 +29,10 @@ class User(Record):
 		The method to set the value to country
 
 		Parameters:
-			country (string) : A string value
+			country (string) : A string representing the country
 		"""
 
-		if not isinstance(country, str):
+		if country is not None and not isinstance(country, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: country EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('country', country)
@@ -60,7 +60,7 @@ class User(Record):
 		except Exception:
 			from .customize_info import CustomizeInfo
 
-		if not isinstance(customize_info, CustomizeInfo):
+		if customize_info is not None and not isinstance(customize_info, CustomizeInfo):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: customize_info EXPECTED TYPE: CustomizeInfo', None, None)
 		
 		self.add_key_value('customize_info', customize_info)
@@ -88,7 +88,7 @@ class User(Record):
 		except Exception:
 			from ..roles import Role
 
-		if not isinstance(role, Role):
+		if role is not None and not isinstance(role, Role):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: role EXPECTED TYPE: Role', None, None)
 		
 		self.add_key_value('role', role)
@@ -108,10 +108,10 @@ class User(Record):
 		The method to set the value to signature
 
 		Parameters:
-			signature (string) : A string value
+			signature (string) : A string representing the signature
 		"""
 
-		if not isinstance(signature, str):
+		if signature is not None and not isinstance(signature, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: signature EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('signature', signature)
@@ -131,10 +131,10 @@ class User(Record):
 		The method to set the value to city
 
 		Parameters:
-			city (string) : A string value
+			city (string) : A string representing the city
 		"""
 
-		if not isinstance(city, str):
+		if city is not None and not isinstance(city, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: city EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('city', city)
@@ -154,10 +154,10 @@ class User(Record):
 		The method to set the value to name_format
 
 		Parameters:
-			name_format (string) : A string value
+			name_format (string) : A string representing the name_format
 		"""
 
-		if not isinstance(name_format, str):
+		if name_format is not None and not isinstance(name_format, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: name_format EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('name_format', name_format)
@@ -177,10 +177,10 @@ class User(Record):
 		The method to set the value to personal_account
 
 		Parameters:
-			personal_account (bool) : A bool value
+			personal_account (bool) : A bool representing the personal_account
 		"""
 
-		if not isinstance(personal_account, bool):
+		if personal_account is not None and not isinstance(personal_account, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: personal_account EXPECTED TYPE: bool', None, None)
 		
 		self.add_key_value('personal_account', personal_account)
@@ -200,10 +200,10 @@ class User(Record):
 		The method to set the value to default_tab_group
 
 		Parameters:
-			default_tab_group (string) : A string value
+			default_tab_group (string) : A string representing the default_tab_group
 		"""
 
-		if not isinstance(default_tab_group, str):
+		if default_tab_group is not None and not isinstance(default_tab_group, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: default_tab_group EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('default_tab_group', default_tab_group)
@@ -223,10 +223,10 @@ class User(Record):
 		The method to set the value to language
 
 		Parameters:
-			language (string) : A string value
+			language (string) : A string representing the language
 		"""
 
-		if not isinstance(language, str):
+		if language is not None and not isinstance(language, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: language EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('language', language)
@@ -246,10 +246,10 @@ class User(Record):
 		The method to set the value to locale
 
 		Parameters:
-			locale (string) : A string value
+			locale (string) : A string representing the locale
 		"""
 
-		if not isinstance(locale, str):
+		if locale is not None and not isinstance(locale, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: locale EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('locale', locale)
@@ -269,10 +269,10 @@ class User(Record):
 		The method to set the value to microsoft
 
 		Parameters:
-			microsoft (bool) : A bool value
+			microsoft (bool) : A bool representing the microsoft
 		"""
 
-		if not isinstance(microsoft, bool):
+		if microsoft is not None and not isinstance(microsoft, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: microsoft EXPECTED TYPE: bool', None, None)
 		
 		self.add_key_value('microsoft', microsoft)
@@ -292,42 +292,14 @@ class User(Record):
 		The method to set the value to isonline
 
 		Parameters:
-			isonline (bool) : A bool value
+			isonline (bool) : A bool representing the isonline
 		"""
 
-		if not isinstance(isonline, bool):
+		if isonline is not None and not isinstance(isonline, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: isonline EXPECTED TYPE: bool', None, None)
 		
 		self.add_key_value('Isonline', isonline)
 
-	def get_modified_by(self):
-		"""
-		The method to get the modified_by
-
-		Returns:
-			User: An instance of User
-		"""
-
-		return self.get_key_value('Modified_By')
-
-	def set_modified_by(self, modified_by):
-		"""
-		The method to set the value to modified_by
-
-		Parameters:
-			modified_by (User) : An instance of User
-		"""
-
-		try:
-			from zcrmsdk.src.com.zoho.crm.api.users.user import User
-		except Exception:
-			from .user import User
-
-		if not isinstance(modified_by, User):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modified_by EXPECTED TYPE: User', None, None)
-		
-		self.add_key_value('Modified_By', modified_by)
-
 	def get_street(self):
 		"""
 		The method to get the street
@@ -343,10 +315,10 @@ class User(Record):
 		The method to set the value to street
 
 		Parameters:
-			street (string) : A string value
+			street (string) : A string representing the street
 		"""
 
-		if not isinstance(street, str):
+		if street is not None and not isinstance(street, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: street EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('street', street)
@@ -366,10 +338,10 @@ class User(Record):
 		The method to set the value to currency
 
 		Parameters:
-			currency (string) : A string value
+			currency (string) : A string representing the currency
 		"""
 
-		if not isinstance(currency, str):
+		if currency is not None and not isinstance(currency, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: currency EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('Currency', currency)
@@ -389,10 +361,10 @@ class User(Record):
 		The method to set the value to alias
 
 		Parameters:
-			alias (string) : A string value
+			alias (string) : A string representing the alias
 		"""
 
-		if not isinstance(alias, str):
+		if alias is not None and not isinstance(alias, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: alias EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('alias', alias)
@@ -420,34 +392,11 @@ class User(Record):
 		except Exception:
 			from .theme import Theme
 
-		if not isinstance(theme, Theme):
+		if theme is not None and not isinstance(theme, Theme):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: theme EXPECTED TYPE: Theme', None, None)
 		
 		self.add_key_value('theme', theme)
 
-	def get_id(self):
-		"""
-		The method to get the id
-
-		Returns:
-			string: A string value
-		"""
-
-		return self.get_key_value('id')
-
-	def set_id(self, id):
-		"""
-		The method to set the value to id
-
-		Parameters:
-			id (string) : A string value
-		"""
-
-		if not isinstance(id, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
-		
-		self.add_key_value('id', id)
-
 	def get_state(self):
 		"""
 		The method to get the state
@@ -463,10 +412,10 @@ class User(Record):
 		The method to set the value to state
 
 		Parameters:
-			state (string) : A string value
+			state (string) : A string representing the state
 		"""
 
-		if not isinstance(state, str):
+		if state is not None and not isinstance(state, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: state EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('state', state)
@@ -486,10 +435,10 @@ class User(Record):
 		The method to set the value to fax
 
 		Parameters:
-			fax (string) : A string value
+			fax (string) : A string representing the fax
 		"""
 
-		if not isinstance(fax, str):
+		if fax is not None and not isinstance(fax, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: fax EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('fax', fax)
@@ -509,10 +458,10 @@ class User(Record):
 		The method to set the value to country_locale
 
 		Parameters:
-			country_locale (string) : A string value
+			country_locale (string) : A string representing the country_locale
 		"""
 
-		if not isinstance(country_locale, str):
+		if country_locale is not None and not isinstance(country_locale, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: country_locale EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('country_locale', country_locale)
@@ -532,10 +481,10 @@ class User(Record):
 		The method to set the value to first_name
 
 		Parameters:
-			first_name (string) : A string value
+			first_name (string) : A string representing the first_name
 		"""
 
-		if not isinstance(first_name, str):
+		if first_name is not None and not isinstance(first_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: first_name EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('first_name', first_name)
@@ -555,10 +504,10 @@ class User(Record):
 		The method to set the value to email
 
 		Parameters:
-			email (string) : A string value
+			email (string) : A string representing the email
 		"""
 
-		if not isinstance(email, str):
+		if email is not None and not isinstance(email, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: email EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('email', email)
@@ -586,7 +535,7 @@ class User(Record):
 		except Exception:
 			from .user import User
 
-		if not isinstance(reporting_to, User):
+		if reporting_to is not None and not isinstance(reporting_to, User):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: reporting_to EXPECTED TYPE: User', None, None)
 		
 		self.add_key_value('Reporting_To', reporting_to)
@@ -606,10 +555,10 @@ class User(Record):
 		The method to set the value to decimal_separator
 
 		Parameters:
-			decimal_separator (string) : A string value
+			decimal_separator (string) : A string representing the decimal_separator
 		"""
 
-		if not isinstance(decimal_separator, str):
+		if decimal_separator is not None and not isinstance(decimal_separator, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: decimal_separator EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('decimal_separator', decimal_separator)
@@ -629,39 +578,14 @@ class User(Record):
 		The method to set the value to zip
 
 		Parameters:
-			zip (string) : A string value
+			zip (string) : A string representing the zip
 		"""
 
-		if not isinstance(zip, str):
+		if zip is not None and not isinstance(zip, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: zip EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('zip', zip)
 
-	def get_created_time(self):
-		"""
-		The method to get the created_time
-
-		Returns:
-			datetime: An instance of datetime
-		"""
-
-		return self.get_key_value('created_time')
-
-	def set_created_time(self, created_time):
-		"""
-		The method to set the value to created_time
-
-		Parameters:
-			created_time (datetime) : An instance of datetime
-		"""
-
-		from datetime import datetime
-
-		if not isinstance(created_time, datetime):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: created_time EXPECTED TYPE: datetime', None, None)
-		
-		self.add_key_value('created_time', created_time)
-
 	def get_website(self):
 		"""
 		The method to get the website
@@ -677,39 +601,14 @@ class User(Record):
 		The method to set the value to website
 
 		Parameters:
-			website (string) : A string value
+			website (string) : A string representing the website
 		"""
 
-		if not isinstance(website, str):
+		if website is not None and not isinstance(website, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: website EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('website', website)
 
-	def get_modified_time(self):
-		"""
-		The method to get the modified_time
-
-		Returns:
-			datetime: An instance of datetime
-		"""
-
-		return self.get_key_value('Modified_Time')
-
-	def set_modified_time(self, modified_time):
-		"""
-		The method to set the value to modified_time
-
-		Parameters:
-			modified_time (datetime) : An instance of datetime
-		"""
-
-		from datetime import datetime
-
-		if not isinstance(modified_time, datetime):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: modified_time EXPECTED TYPE: datetime', None, None)
-		
-		self.add_key_value('Modified_Time', modified_time)
-
 	def get_time_format(self):
 		"""
 		The method to get the time_format
@@ -725,10 +624,10 @@ class User(Record):
 		The method to set the value to time_format
 
 		Parameters:
-			time_format (string) : A string value
+			time_format (string) : A string representing the time_format
 		"""
 
-		if not isinstance(time_format, str):
+		if time_format is not None and not isinstance(time_format, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: time_format EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('time_format', time_format)
@@ -748,10 +647,10 @@ class User(Record):
 		The method to set the value to offset
 
 		Parameters:
-			offset (int) : A int value
+			offset (int) : An int representing the offset
 		"""
 
-		if not isinstance(offset, int):
+		if offset is not None and not isinstance(offset, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: offset EXPECTED TYPE: int', None, None)
 		
 		self.add_key_value('offset', offset)
@@ -779,7 +678,7 @@ class User(Record):
 		except Exception:
 			from ..profiles import Profile
 
-		if not isinstance(profile, Profile):
+		if profile is not None and not isinstance(profile, Profile):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: profile EXPECTED TYPE: Profile', None, None)
 		
 		self.add_key_value('profile', profile)
@@ -799,10 +698,10 @@ class User(Record):
 		The method to set the value to mobile
 
 		Parameters:
-			mobile (string) : A string value
+			mobile (string) : A string representing the mobile
 		"""
 
-		if not isinstance(mobile, str):
+		if mobile is not None and not isinstance(mobile, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: mobile EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('mobile', mobile)
@@ -822,10 +721,10 @@ class User(Record):
 		The method to set the value to last_name
 
 		Parameters:
-			last_name (string) : A string value
+			last_name (string) : A string representing the last_name
 		"""
 
-		if not isinstance(last_name, str):
+		if last_name is not None and not isinstance(last_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: last_name EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('last_name', last_name)
@@ -845,42 +744,14 @@ class User(Record):
 		The method to set the value to time_zone
 
 		Parameters:
-			time_zone (string) : A string value
+			time_zone (string) : A string representing the time_zone
 		"""
 
-		if not isinstance(time_zone, str):
+		if time_zone is not None and not isinstance(time_zone, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: time_zone EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('time_zone', time_zone)
 
-	def get_created_by(self):
-		"""
-		The method to get the created_by
-
-		Returns:
-			User: An instance of User
-		"""
-
-		return self.get_key_value('created_by')
-
-	def set_created_by(self, created_by):
-		"""
-		The method to set the value to created_by
-
-		Parameters:
-			created_by (User) : An instance of User
-		"""
-
-		try:
-			from zcrmsdk.src.com.zoho.crm.api.users.user import User
-		except Exception:
-			from .user import User
-
-		if not isinstance(created_by, User):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: created_by EXPECTED TYPE: User', None, None)
-		
-		self.add_key_value('created_by', created_by)
-
 	def get_zuid(self):
 		"""
 		The method to get the zuid
@@ -896,10 +767,10 @@ class User(Record):
 		The method to set the value to zuid
 
 		Parameters:
-			zuid (string) : A string value
+			zuid (string) : A string representing the zuid
 		"""
 
-		if not isinstance(zuid, str):
+		if zuid is not None and not isinstance(zuid, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: zuid EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('zuid', zuid)
@@ -919,10 +790,10 @@ class User(Record):
 		The method to set the value to confirm
 
 		Parameters:
-			confirm (bool) : A bool value
+			confirm (bool) : A bool representing the confirm
 		"""
 
-		if not isinstance(confirm, bool):
+		if confirm is not None and not isinstance(confirm, bool):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: confirm EXPECTED TYPE: bool', None, None)
 		
 		self.add_key_value('confirm', confirm)
@@ -942,10 +813,10 @@ class User(Record):
 		The method to set the value to full_name
 
 		Parameters:
-			full_name (string) : A string value
+			full_name (string) : A string representing the full_name
 		"""
 
-		if not isinstance(full_name, str):
+		if full_name is not None and not isinstance(full_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: full_name EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('full_name', full_name)
@@ -968,7 +839,7 @@ class User(Record):
 			territories (list) : An instance of list
 		"""
 
-		if not isinstance(territories, list):
+		if territories is not None and not isinstance(territories, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: territories EXPECTED TYPE: list', None, None)
 		
 		self.add_key_value('territories', territories)
@@ -988,10 +859,10 @@ class User(Record):
 		The method to set the value to phone
 
 		Parameters:
-			phone (string) : A string value
+			phone (string) : A string representing the phone
 		"""
 
-		if not isinstance(phone, str):
+		if phone is not None and not isinstance(phone, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: phone EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('phone', phone)
@@ -1011,10 +882,10 @@ class User(Record):
 		The method to set the value to dob
 
 		Parameters:
-			dob (string) : A string value
+			dob (string) : A string representing the dob
 		"""
 
-		if not isinstance(dob, str):
+		if dob is not None and not isinstance(dob, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: dob EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('dob', dob)
@@ -1034,10 +905,10 @@ class User(Record):
 		The method to set the value to date_format
 
 		Parameters:
-			date_format (string) : A string value
+			date_format (string) : A string representing the date_format
 		"""
 
-		if not isinstance(date_format, str):
+		if date_format is not None and not isinstance(date_format, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: date_format EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('date_format', date_format)
@@ -1057,10 +928,10 @@ class User(Record):
 		The method to set the value to status
 
 		Parameters:
-			status (string) : A string value
+			status (string) : A string representing the status
 		"""
 
-		if not isinstance(status, str):
+		if status is not None and not isinstance(status, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: status EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('status', status)
@@ -1080,10 +951,10 @@ class User(Record):
 		The method to set the value to name
 
 		Parameters:
-			name (string) : A string value
+			name (string) : A string representing the name
 		"""
 
-		if not isinstance(name, str):
+		if name is not None and not isinstance(name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: name EXPECTED TYPE: str', None, None)
 		
 		self.add_key_value('name', name)
