@@ -1,15 +1,15 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.parameter_map import ParameterMap
 	from zcrmsdk.src.com.zoho.crm.api.util import APIResponse, CommonAPIHandler, Constants
 	from zcrmsdk.src.com.zoho.crm.api.param import Param
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.header import Header
 	from zcrmsdk.src.com.zoho.crm.api.header_map import HeaderMap
 except Exception:
+	from ..exception import SDKException
 	from ..parameter_map import ParameterMap
 	from ..util import APIResponse, CommonAPIHandler, Constants
 	from ..param import Param
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 	from ..header import Header
 	from ..header_map import HeaderMap
 
@@ -29,6 +29,9 @@ class UsersOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
@@ -42,6 +45,7 @@ class UsersOperations(object):
 		api_path = api_path + '/crm/v2/users'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		handler_instance.param = param_instance
 		handler_instance.header = header_instance
 		try:
@@ -55,27 +59,32 @@ class UsersOperations(object):
 		The method to create user
 
 		Parameters:
-			request (BodyWrapper) : An instance of BodyWrapper
+			request (RequestWrapper) : An instance of RequestWrapper
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
-			from zcrmsdk.src.com.zoho.crm.api.users.body_wrapper import BodyWrapper
+			from zcrmsdk.src.com.zoho.crm.api.users.request_wrapper import RequestWrapper
 		except Exception:
-			from .body_wrapper import BodyWrapper
+			from .request_wrapper import RequestWrapper
 
-		if not isinstance(request, BodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		if request is not None and not isinstance(request, RequestWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: RequestWrapper', None, None)
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + '/crm/v2/users'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.users.action_handler import ActionHandler
 		except Exception:
@@ -91,6 +100,9 @@ class UsersOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -98,7 +110,7 @@ class UsersOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -106,8 +118,10 @@ class UsersOperations(object):
 		api_path = api_path + '/crm/v2/users'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.users.action_handler import ActionHandler
 		except Exception:
@@ -120,16 +134,19 @@ class UsersOperations(object):
 
 		Parameters:
 			header_instance (HeaderMap) : An instance of HeaderMap
-			id (int) : A int value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if header_instance is not None and not isinstance(header_instance, HeaderMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
 		
-		if not isinstance(id, int):
+		if id is not None and not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -138,6 +155,7 @@ class UsersOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		handler_instance.header = header_instance
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.users.response_handler import ResponseHandler
@@ -151,10 +169,13 @@ class UsersOperations(object):
 
 		Parameters:
 			request (BodyWrapper) : An instance of BodyWrapper
-			id (int) : A int value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -162,10 +183,10 @@ class UsersOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
-		if not isinstance(id, int):
+		if id is not None and not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -174,6 +195,7 @@ class UsersOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
 		try:
@@ -187,13 +209,16 @@ class UsersOperations(object):
 		The method to delete user
 
 		Parameters:
-			id (int) : A int value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
-		if not isinstance(id, int):
+		if id is not None and not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -202,6 +227,7 @@ class UsersOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.users.action_handler import ActionHandler
 		except Exception:
@@ -211,9 +237,7 @@ class UsersOperations(object):
 
 class GetUsersParam(object):
 	type = Param('type', 'com.zoho.crm.api.Users.GetUsersParam')
-
 	page = Param('page', 'com.zoho.crm.api.Users.GetUsersParam')
-
 	per_page = Param('per_page', 'com.zoho.crm.api.Users.GetUsersParam')
 
 
@@ -223,4 +247,3 @@ class GetUsersHeader(object):
 
 class GetUserHeader(object):
 	if_modified_since = Header('If-Modified-Since', 'com.zoho.crm.api.Users.GetUserHeader')
-
