@@ -54,13 +54,6 @@ class APIHTTPConnector(object):
 
         self.parameters[param_name] = param_value
 
-    def is_set_content_type(self):
-        for url in Constants.SET_TO_CONTENT_TYPE:
-            if url in self.url:
-                return True
-
-        return False
-
     def fire_request(self, converter_instance):
 
         """
@@ -76,8 +69,8 @@ class APIHTTPConnector(object):
         response = None
         logger = logging.getLogger('SDKLogger')
 
-        if self.is_set_content_type():
-            self.headers[Constants.CONTENT_TYPE_HEADER] = self.content_type
+        if self.content_type is not None:
+            self.set_content_type_header()
 
         logger.info(self.__str__())
 
@@ -86,22 +79,22 @@ class APIHTTPConnector(object):
 
         elif self.request_method == Constants.REQUEST_METHOD_PUT:
             data = None
-            if converter_instance is not None:
+            if self.request_body is not None:
                 data = converter_instance.append_to_request(self, self.request_body)
 
             response = requests.put(self.url, data=data, params=self.parameters, headers=self.headers, allow_redirects=False)
 
         elif self.request_method == Constants.REQUEST_METHOD_POST:
             data = None
-            if converter_instance is not None:
+            if self.request_body is not None:
                 data = converter_instance.append_to_request(self, self.request_body)
 
-            if self.file is False:
-                response = requests.post(self.url, data=data, params=self.parameters, headers=self.headers, allow_redirects=False)
-                
-            else:
+            if self.file:
                 response = requests.post(self.url, files=data, headers=self.headers, allow_redirects=False, data={})
 
+            else:
+                response = requests.post(self.url, data=data, params=self.parameters, headers=self.headers, allow_redirects=False)
+
         elif self.request_method == Constants.REQUEST_METHOD_DELETE:
             response = requests.delete(self.url, headers=self.headers, params=self.parameters, allow_redirects=False)
 
@@ -113,3 +106,9 @@ class APIHTTPConnector(object):
 
         return self.request_method + ' - ' + Constants.URL + ' = ' + self.url + ' , ' + Constants.HEADERS + ' = ' + json.dumps(request_headers) \
                + ' , ' + Constants.PARAMS + ' = ' + json.dumps(self.parameters) + '.'
+
+    def set_content_type_header(self):
+        for url in Constants.SET_TO_CONTENT_TYPE:
+            if url in self.url:
+                self.headers[Constants.CONTENT_TYPE_HEADER] = self.content_type
+                return
