@@ -19,6 +19,8 @@ class Constants(object):
 
     REQUEST_METHOD_DELETE = "DELETE"
 
+    REQUEST_METHOD_PATCH = 'PATCH'
+
     OAUTH_HEADER_PREFIX = "Zoho-oauthtoken "
 
     AUTHORIZATION = "Authorization"
@@ -37,84 +39,6 @@ class Constants(object):
 
     STATUS_ERROR = "error"
 
-    TAG = "tags"
-
-    LEADS = "Leads"
-
-    ACCOUNTS = "Accounts"
-
-    CONTACTS = "Contacts"
-
-    DEALS = "Deals"
-
-    QUOTES = "Quotes"
-
-    SALESORDERS = "SalesOrders"
-
-    INVOICES = "Invoices"
-
-    PURCHASEORDERS = "PurchaseOrders"
-
-    PER_PAGE = "per_page"
-
-    PAGE = "page"
-
-    COUNT = "count"
-
-    MORE_RECORDS = "more_records"
-
-    MESSAGE = "message"
-
-    CODE = "code"
-
-    STATUS = "status"
-
-    DETAILS = "details"
-
-    TAXES = "taxes"
-
-    DATA = "data"
-
-    INFO = "info"
-
-    FIELDS = 'fields'
-
-    LAYOUTS = 'layouts'
-
-    CUSTOM_VIEWS = 'custom_views'
-
-    MODULES = 'modules'
-
-    MODULE = 'module'
-
-    ORG = 'org'
-
-    ROLES = 'roles'
-
-    PROFILES = 'profiles'
-
-    USERS = 'users'
-
-    DOWNLOAD_FILE_PATH = "../../../../../../resources"
-
-    USER_EMAIL_ID = "user_email_id"
-
-    CURRENT_USER_EMAIL = "currentUserEmail"
-
-    API_BASEURL = "apiBaseUrl"
-
-    API_VERSION = "apiVersion"
-
-    APPLICATION_LOGFILE_PATH = "applicationLogFilePath"
-
-    ACTION = "action"
-
-    DUPLICATE_FIELD = "duplicate_field"
-
-    NO_CONTENT = "No Content"
-
-    ATTACHMENT_URL = "attachmentUrl"
-
     GRANT_TYPE = "grant_type"
 
     GRANT_TYPE_AUTH_CODE = "authorization_code"
@@ -142,9 +66,14 @@ class Constants(object):
         "Long": int,
         "Double": float,
         "Float": float,
-        "DateTime": datetime.datetime
+        "DateTime": datetime.datetime,
+        "Date": datetime.date
     }
 
+    OBJECT_KEY = "object"
+
+    GIVEN_LENGTH = "given-length"
+
     ZOHO_SDK = "X-ZOHO-SDK"
 
     SDK_VERSION = "3.0.0"
@@ -203,7 +132,7 @@ class Constants(object):
 
     ACCEPTED_TYPE = "accepted_type"
 
-    GIVEN_TYPE = "given_type";
+    GIVEN_TYPE = "given_type"
 
     TYPE_ERROR = "TYPE ERROR"
 
@@ -245,9 +174,17 @@ class Constants(object):
 
     REQUIRED = "required"
 
+    REQUIRED_IN_UPDATE = "required_in_update"
+
+    PRIMARY = "primary"
+
     MANDATORY_VALUE_MISSING_ERROR = "MANDATORY VALUE MISSING ERROR"
 
-    MANDATORY_KEY_MISSING_ERROR = "Value missing for mandatory key: "
+    MANDATORY_VALUE_NULL_ERROR = "MANDATORY VALUE NULL ERROR"
+
+    MANDATORY_KEY_MISSING_ERROR = "Value missing for mandatory key(s): "
+
+    MANDATORY_KEY_NULL_ERROR = "Null Value for mandatory key : "
 
     SET_KEY_MODIFIED = "set_key_modified"
 
@@ -321,11 +258,9 @@ class Constants(object):
 
     JSON_DETAILS_FILE_PATH = 'json_details.json'
 
-    INITIALIZATION_ERROR = "Exception in initialization "
-
     EMAIL = "email"
 
-    USER_ERROR = "USER ERROR"
+    USER_SIGNATURE_ERROR = "USERSIGNATURE ERROR";
 
     USER_INITIALIZATION_ERROR = "Error during User Initialization"
 
@@ -335,8 +270,6 @@ class Constants(object):
 
     TOKEN_TYPE = "token_type"
 
-    TOKEN_INITIALIZATION_ERROR = 'Exception in OAuthToken constructor'
-
     GRANT = "GRANT"
 
     REFRESH = "REFRESH"
@@ -367,15 +300,21 @@ class Constants(object):
 
     PARTICIPANT_API_NAME = "Participants"
 
-    INVENTORY_MODULES = ['Invoices', 'Sales_Orders', 'Purchase_Orders', 'Quotes']
+    INVENTORY_MODULES = ['invoices', 'sales_orders', 'purchase_orders', 'quotes']
 
-    PRICE_BOOKS = "Price_Books"
+    PRICE_BOOKS = "price_books"
 
-    EVENTS = "Events"
+    EVENTS = "events"
 
-    SOLUTIONS = "Solutions"
+    CALLS = "calls"
 
-    ACTIVITIES = "Activities"
+    CALL_DURATION = "call_duration"
+
+    SOLUTIONS = "solutions"
+
+    CASES = "cases"
+
+    ACTIVITIES = "activities"
 
     LAYOUT = "Layout"
 
@@ -465,7 +404,52 @@ class Constants(object):
 
     EXCEPTION = "Exception"
 
+    MODULE = "module"
 
+    REQUEST_CATEGORY_READ = "READ"
 
+    REQUEST_CATEGORY_CREATE = "CREATE"
 
+    REQUEST_CATEGORY_UPDATE = "UPDATE"
 
+    ID = "id"
+
+    CODE = "code"
+
+    STATUS = "status"
+
+    MESSAGE = "message"
+
+    INVALID_URL_ERROR = "Invalid URL Error"
+
+    REQUEST_CATEGORY_ACTION = "ACTION"
+
+    SKIP_MANDATORY = "skip_mandatory"
+
+    FORMULA = "formula"
+
+    PICKLIST = "picklist"
+
+    ACCOUNTS = "accounts"
+
+    PRIMARY_KEY_MISSING_ERROR = "Value missing for required key(s) : "
+
+    REFRESH_SINGLE_MODULE_FIELDS_ERROR = "Exception in refreshing fields of module : "
+
+    REFRESH_ALL_MODULE_FIELDS_ERROR = "Exception in refreshing fields of all modules : "
+
+    GET_TOKENS_DB_ERROR = "Exception in getTokens - DBStore"
+
+    DELETE_TOKENS_DB_ERROR = "Exception in deleteTokens - DBStore"
+
+    GET_TOKENS_FILE_ERROR = "Exception in getTokens - FileStore"
+
+    DELETE_TOKENS_FILE_ERROR = "Exception in deleteTokens - FileStore"
+
+    SDK_UNINITIALIZATION_ERROR = "SDK UNINITIALIZED ERROR"
+
+    SDK_UNINITIALIZATION_MESSAGE = "SDK is UnInitialized"
+
+    INITIALIZATION_EXCEPTION = "Exception in initialization"
+
+    AUTO_REFRESH_FIELDS_ERROR_MESSAGE = "auto_refresh_fields MUST NOT be None."
