@@ -1,13 +1,12 @@
-
 from datetime import datetime, date
-
 from dateutil.tz import tz
+import dateutil.parser
 
 
 class DataTypeConverter(object):
 
     """
-    This class converts JSON value to the expected data type.
+    This class converts JSON value to the expected object type and vice versa.
     """
 
     pre_converter_map = {}
@@ -26,12 +25,12 @@ class DataTypeConverter(object):
 
         DataTypeConverter.add_to_map("String", lambda obj: str(obj), lambda obj: str(obj))
         DataTypeConverter.add_to_map("Integer", lambda obj: int(obj), lambda obj: int(obj))
-        DataTypeConverter.add_to_map("Long", lambda obj: str(obj), lambda obj: str(obj))
+        DataTypeConverter.add_to_map("Long", lambda obj: int(obj), lambda obj: int(obj))
         DataTypeConverter.add_to_map("Boolean", lambda obj: bool(obj), lambda obj: bool(obj))
         DataTypeConverter.add_to_map("Float", lambda obj: float(obj), lambda obj: float(obj))
         DataTypeConverter.add_to_map("Double", lambda obj: float(obj), lambda obj: float(obj))
-        DataTypeConverter.add_to_map("Date", lambda obj: date.fromisoformat(obj), lambda obj: obj.isoformat())
-        DataTypeConverter.add_to_map("DateTime", lambda obj: datetime.fromisoformat(obj).astimezone(tz.tzlocal()), lambda obj: obj.replace(microsecond=0).astimezone(tz.tzlocal()).isoformat())
+        DataTypeConverter.add_to_map("Date", lambda obj: dateutil.parser.isoparse(obj).date(), lambda obj: obj.isoformat())
+        DataTypeConverter.add_to_map("DateTime", lambda obj: dateutil.parser.isoparse(obj).astimezone(tz.tzlocal()), lambda obj: obj.replace(microsecond=0).astimezone(tz.tzlocal()).isoformat())
         DataTypeConverter.add_to_map("Object", lambda obj: obj, lambda obj: obj)
 
     @staticmethod
