@@ -1,17 +1,15 @@
 try:
     import importlib
-    import logging
     import re
     import traceback
     import json
     from zcrmsdk.src.com.zoho.crm.api.util import Converter, Constants, DataTypeConverter, Utility
-    from zcrmsdk.src.com.zoho.api.exception.sdk_exception import SDKException
+    from zcrmsdk.src.com.zoho.crm.api.exception.sdk_exception import SDKException
 except Exception:
     import importlib
     import traceback
-    import logging
     import re
-    from zcrmsdk.src.com.zoho.api.exception import SDKException
+    from ..exception import SDKException
     from .converter import Converter
     from .constants import Constants
     from .datatype_converter import DataTypeConverter
@@ -23,8 +21,6 @@ class JSONConverter(Converter):
     This class processes the API response object to the POJO object and POJO object to a JSON object.
     """
 
-    logger = logging.getLogger('SDKLogger')
-
     def __init__(self, common_api_handler):
 
         super().__init__(common_api_handler)
@@ -34,7 +30,7 @@ class JSONConverter(Converter):
     def append_to_request(self, request_base, request_object):
         return json.dumps(request_object).encode('utf-8')
 
-    def form_request(self, request_instance, pack, instance_number):
+    def form_request(self, request_instance, pack, instance_number, class_member_detail):
         path_split = str(pack).rpartition(".")
         class_name = self.module_to_class(path_split[-1])
         pack = path_split[0] + "." + class_name
@@ -69,24 +65,31 @@ class JSONConverter(Converter):
 
         if isinstance(request_instance, Record):
             module_api_name = self.common_api_handler.module_api_name
-            return_json = self.is_record_request(request_instance, class_detail)
+            return_json = self.is_record_request(request_instance, class_detail, instance_number, class_member_detail)
             self.common_api_handler.module_api_name = module_api_name
             return return_json
 
         else:
-            return self.is_not_record_request(request_instance, class_name, class_detail, instance_number)
+            return self.is_not_record_request(request_instance, class_name, class_detail, instance_number, class_member_detail)
 
-    def is_not_record_request(self, request_instance, class_name, class_detail, instance_number):
+    def is_not_record_request(self, request_instance, class_name, class_detail, instance_number, class_member_detail):
         try:
             from zcrmsdk.src.com.zoho.crm.api.record import FileDetails
         except Exception:
             from ..record import FileDetails
 
+        lookup = False
+        skip_mandatory = False
+        class_member_name = None
+        if class_member_detail is not None:
+            lookup = class_member_detail[Constants.LOOKUP] if Constants.LOOKUP in class_member_detail else False
+            skip_mandatory = class_member_detail[Constants.SKIP_MANDATORY] if Constants.SKIP_MANDATORY in member_detail else False
+            class_member_name = class_member_detail[Constants.NAME]
+
         request_json = {}
+        required_keys, primary_keys = [], []
 
         for member_name, member_detail in class_detail.items():
-            modification = None
-
             if Constants.READ_ONLY in member_name or (Constants.NAME not in member_detail):
                 continue
 
@@ -95,46 +98,109 @@ class JSONConverter(Converter):
             try:
                 modification = getattr(request_instance, Constants.IS_KEY_MODIFIED)(key_name)
             except Exception as e:
-                JSONConverter.logger.info(Constants.EXCEPTION_IS_KEY_MODIFIED + e.__str__())
+                raise SDKException(code=Constants.EXCEPTION_IS_KEY_MODIFIED, cause=e)
 
-            if (modification is None or modification == 0) and Constants.REQUIRED in member_detail and bool(
-                    member_detail[Constants.REQUIRED]):
-                raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR,
-                                   Constants.MANDATORY_KEY_MISSING_ERROR + member_name)
+            if Constants.REQUIRED in member_detail and member_detail[Constants.REQUIRED]:
+                required_keys.append(key_name)
 
-            field_value = getattr(request_instance,
-                                  self.construct_private_member(class_name=class_name, member_name=member_name))
+            required_in_update = True
+            if Constants.REQUIRED_IN_UPDATE in member_detail:
+                required_in_update = member_detail[Constants.REQUIRED_IN_UPDATE]
 
-            if modification is not None and not modification == 0 and self.value_checker(class_name=class_name,
-                                                                                     member_name=member_name,
-                                                                                     key_details=member_detail,
-                                                                                     value=field_value,
-                                                                                     unique_values_map=self.unique_dict,
-                                                                                     instance_number=instance_number) is True:
-                key_name = member_detail.get(Constants.NAME)
+            if Constants.PRIMARY in member_detail and member_detail[Constants.PRIMARY] and required_in_update:
+                primary_keys.append(key_name)
 
-                if isinstance(request_instance, FileDetails):
-                    if key_name.lower() == Constants.ATTACHMENT_ID.lower():
-                        request_json[key_name.lower()] = field_value
+            if modification is not None and modification != 0:
+                field_value = getattr(request_instance,
+                                      self.construct_private_member(class_name=class_name, member_name=member_name))
 
-                    elif key_name.lower() == Constants.FILE_ID.lower():
-                        request_json[key_name.lower()] = field_value
+                if self.value_checker(class_name=class_name, member_name=member_name, key_details=member_detail,
+                                      value=field_value, unique_values_map=self.unique_dict,
+                                      instance_number=instance_number) is True:
+                    if field_value is None and not skip_mandatory:
+                        self.mandatory_check(request_instance, member_name, member_detail, lookup, skip_mandatory)
+
+                    if key_name in required_keys:
+                        required_keys.remove(key_name)
+
+                    if key_name in primary_keys:
+                        primary_keys.remove(key_name)
+
+                    if isinstance(request_instance, FileDetails):
+                        if key_name.lower() == Constants.ATTACHMENT_ID.lower():
+                            request_json[key_name.lower()] = field_value
+
+                        elif key_name.lower() == Constants.FILE_ID.lower():
+                            request_json[key_name.lower()] = field_value
+
+                        else:
+                            request_json[key_name.lower()] = None if field_value is None else field_value
 
                     else:
-                        request_json[key_name.lower()] = None if field_value is None else field_value
+                        request_json[key_name] = self.set_data(member_detail, field_value)
 
-                else:
-                    request_json[key_name] = self.set_data(member_detail, field_value)
+        if self.common_api_handler.mandatory_checker is not None and self.common_api_handler.mandatory_checker and not skip_mandatory:
+            if self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_CREATE:
+                if lookup:
+                    if len(primary_keys) > 0:
+                        error = {
+                            Constants.FIELD: class_member_name,
+                            Constants.TYPE: request_instance.__class__.__name__,
+                            Constants.KEYS: str(primary_keys),
+                            Constants.INSTANCE_NUMBER: instance_number
+                        }
+                        raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.PRIMARY_KEY_MISSING_ERROR,
+                                           error)
+
+                elif len(required_keys) > 0:
+                    error = {
+                        Constants.FIELD: class_member_name,
+                        Constants.TYPE: request_instance.__class__.__name__,
+                        Constants.KEYS: str(required_keys),
+                        Constants.INSTANCE_NUMBER: instance_number
+                    }
+                    raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.MANDATORY_KEY_MISSING_ERROR,
+                                       error)
+
+            if self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_UPDATE:
+                if len(primary_keys) > 0:
+                    error = {
+                        Constants.FIELD: class_member_name,
+                        Constants.TYPE: request_instance.__class__.__name__,
+                        Constants.KEYS: str(primary_keys),
+                        Constants.INSTANCE_NUMBER: instance_number
+                    }
+                    raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.PRIMARY_KEY_MISSING_ERROR,
+                                       error)
+
+        elif lookup and self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_UPDATE and not skip_mandatory:
+            if len(primary_keys) > 0:
+                error = {
+                    Constants.FIELD: class_member_name,
+                    Constants.TYPE: request_instance.__class__.__name__,
+                    Constants.KEYS: str(primary_keys),
+                    Constants.INSTANCE_NUMBER: instance_number
+                }
+                raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.PRIMARY_KEY_MISSING_ERROR, error)
 
         return request_json
 
-    def is_record_request(self, record_instance, class_detail):
+    def is_record_request(self, record_instance, class_detail, instance_number, member_detail):
         try:
             from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
         except Exception:
             from ..initializer import Initializer
 
-        request_json, module_detail = {}, {}
+        lookup = False
+        skip_mandatory = False
+        class_member_name = None
+        if member_detail is not None:
+            lookup = member_detail[Constants.LOOKUP] if Constants.LOOKUP in member_detail else False
+            skip_mandatory = member_detail[
+                Constants.SKIP_MANDATORY] if Constants.SKIP_MANDATORY in member_detail else False
+            class_member_name = member_detail[Constants.NAME]
+
+        request_json, module_detail, unique_values = {}, {}, {}
         module_api_name = self.common_api_handler.module_api_name
         class_name = record_instance.__class__.__name__
 
@@ -161,12 +227,37 @@ class JSONConverter(Converter):
         key_values = getattr(record_instance, self.construct_private_member(class_name, Constants.KEY_VALUES))
         key_modified = getattr(record_instance, self.construct_private_member(class_name, Constants.KEY_MODIFIED))
 
-        for key_name in key_values.keys():
+        required_keys, primary_keys = [], []
+
+        if not skip_mandatory:
+            for key_name, key_detail in module_detail.items():
+                name = key_detail[Constants.NAME]
+                if Constants.REQUIRED in key_detail and key_detail[Constants.REQUIRED]:
+                    if name not in required_keys:
+                        required_keys.append(name)
+
+                if Constants.PRIMARY in key_detail and key_detail[Constants.PRIMARY]:
+                    if name not in primary_keys:
+                        primary_keys.append(name)
+
+        for key_name, key_detail in class_detail.items():
+            name = key_detail[Constants.NAME]
+            if Constants.REQUIRED in key_detail and key_detail[Constants.REQUIRED]:
+                if name not in required_keys:
+                    required_keys.append(name)
+
+            if Constants.PRIMARY in key_detail and key_detail[Constants.PRIMARY]:
+                if name not in primary_keys:
+                    primary_keys.append(name)
+
+        for key_name in key_modified.keys():
+            if key_modified.get(key_name) != 1:
+                continue
+
             key_detail = {}
-            key_value = key_values.get(key_name)
+            key_value = key_values.get(key_name) if key_name in key_values else None
             json_value = None
             member_name = self.build_name(key_name)
-            modification = key_modified.get(key_name)
 
             if len(module_detail) > 0 and (member_name in module_detail or key_name in module_detail):
                 if key_name in module_detail:
@@ -181,23 +272,70 @@ class JSONConverter(Converter):
                 if Constants.READ_ONLY in key_detail or (Constants.NAME not in key_detail):
                     continue
 
-                is_required = Constants.REQUIRED in key_detail and bool(key_detail[Constants.REQUIRED])
+                if self.value_checker(class_name, key_name, key_detail, key_value, unique_values, instance_number):
+                    if key_value is None:
+                        self.mandatory_check(record_instance, key_name, key_detail, lookup, skip_mandatory)
 
-                if (modification is None or modification == 0) and is_required:
-                    raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.MANDATORY_KEY_MISSING_ERROR + member_name)
+                    if Constants.PRIMARY in key_detail and key_detail[Constants.PRIMARY]:
+                        is_primary_key_added = True
 
-                elif (modification is None or modification == 0) and not is_required:
-                    continue
+                    json_value = self.set_data(key_detail, key_value)
 
-                json_value = self.set_data(key_detail, key_value)
             else:
                 json_value = self.redirector_for_object_to_json(key_value)
 
-            if modification is None or modification == 0:
-                continue
+            if key_name in required_keys:
+                required_keys.remove(key_name)
+
+            if key_name in primary_keys:
+                primary_keys.remove(key_name)
 
             request_json[key_name] = json_value
 
+        if self.common_api_handler.mandatory_checker is not None and self.common_api_handler.mandatory_checker and not skip_mandatory:
+            if self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_CREATE:
+                if lookup:
+                    if len(primary_keys) > 0:
+                        error = {
+                            Constants.FIELD: class_member_name,
+                            Constants.TYPE: record_instance.__class__.__name__,
+                            Constants.KEYS: str(primary_keys),
+                            Constants.INSTANCE_NUMBER: instance_number
+                        }
+                        raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.PRIMARY_KEY_MISSING_ERROR,
+                                           error)
+
+                elif len(required_keys) > 0:
+                    error = {
+                        Constants.FIELD: class_member_name,
+                        Constants.TYPE: record_instance.__class__.__name__,
+                        Constants.KEYS: str(required_keys),
+                        Constants.INSTANCE_NUMBER: instance_number
+                    }
+                    raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.MANDATORY_KEY_MISSING_ERROR,
+                                       error)
+
+            if self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_UPDATE:
+                if len(primary_keys) > 0:
+                    error = {
+                        Constants.FIELD: class_member_name,
+                        Constants.TYPE: record_instance.__class__.__name__,
+                        Constants.KEYS: str(primary_keys),
+                        Constants.INSTANCE_NUMBER: instance_number
+                    }
+                    raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.PRIMARY_KEY_MISSING_ERROR,
+                                       error)
+
+        elif lookup and self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_UPDATE and not skip_mandatory:
+            if len(primary_keys) > 0:
+                error = {
+                    Constants.FIELD: class_member_name,
+                    Constants.TYPE: record_instance.__class__.__name__,
+                    Constants.KEYS: str(primary_keys),
+                    Constants.INSTANCE_NUMBER: instance_number
+                }
+                raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.PRIMARY_KEY_MISSING_ERROR, error)
+
         return request_json
 
     def set_data(self, member_detail, field_value):
@@ -210,16 +348,14 @@ class JSONConverter(Converter):
             elif data_type == Constants.MAP_NAMESPACE:
                 return self.set_json_object(field_value, member_detail)
 
-            elif data_type == Constants.CHOICE_NAMESPACE or (
-                    Constants.STRUCTURE_NAME in member_detail and member_detail[Constants.STRUCTURE_NAME] == Constants.CHOICE_NAMESPACE):
+            elif data_type == Constants.CHOICE_NAMESPACE or (Constants.STRUCTURE_NAME in member_detail and member_detail[Constants.STRUCTURE_NAME] == Constants.CHOICE_NAMESPACE):
                 return field_value.get_value()
 
             elif Constants.STRUCTURE_NAME in member_detail and Constants.MODULE in member_detail:
-                return self.is_record_request(field_value, self.__get_module_detail_from_user_spec_json(
-                    member_detail[Constants.MODULE]))
+                return self.is_record_request(field_value, self.__get_module_detail_from_user_spec_json(member_detail[Constants.MODULE]), 0, member_detail)
 
             elif Constants.STRUCTURE_NAME in member_detail:
-                return self.form_request(field_value, member_detail[Constants.STRUCTURE_NAME], 1)
+                return self.form_request(field_value, member_detail[Constants.STRUCTURE_NAME], 0, member_detail)
 
             else:
                 return DataTypeConverter.post_convert(field_value, data_type)
@@ -254,11 +390,10 @@ class JSONConverter(Converter):
 
         if len(request_objects) > 0:
             if member_detail is None or (member_detail is not None and Constants.STRUCTURE_NAME not in member_detail):
-
                 for request in request_objects:
                     json_array.append(self.redirector_for_object_to_json(request))
-            else:
 
+            else:
                 pack = member_detail[Constants.STRUCTURE_NAME]
 
                 if pack == Constants.CHOICE_NAMESPACE:
@@ -266,14 +401,15 @@ class JSONConverter(Converter):
                         json_array.append(request.get_value())
 
                 elif Constants.MODULE in member_detail and member_detail[Constants.MODULE] is not None:
+                    instance_count = 0
                     for request in request_objects:
-                        json_array.append(self.is_record_request(request, self.__get_module_detail_from_user_spec_json(
-                            member_detail[Constants.MODULE])))
+                        json_array.append(self.is_record_request(request, self.__get_module_detail_from_user_spec_json(member_detail[Constants.MODULE]), instance_count, member_detail))
+                        instance_count += 1
 
                 else:
                     instance_count = 0
                     for request in request_objects:
-                        json_array.append(self.form_request(request, pack, instance_count))
+                        json_array.append(self.form_request(request, pack, instance_count, member_detail))
                         instance_count += 1
 
         return json_array
@@ -288,8 +424,34 @@ class JSONConverter(Converter):
         else:
             return request
 
-    def get_wrapped_response(self, response, pack):
+    def mandatory_check(self, instance, member_name, member_detail, lookup, skip_mandatory):
+        is_required = member_detail[Constants.REQUIRED] if Constants.REQUIRED in member_detail else False
+        is_primary = member_detail[Constants.PRIMARY] if Constants.PRIMARY in member_detail else False
 
+        if not skip_mandatory:
+            if not lookup:
+                if is_required and self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_CREATE:
+                    error = {
+                        Constants.FIELD: member_name,
+                        Constants.TYPE: instance.__class__.__name__
+                    }
+                    raise SDKException(Constants.MANDATORY_VALUE_NULL_ERROR, Constants.MANDATORY_KEY_NULL_ERROR, error)
+
+                if is_required and self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_UPDATE:
+                    error = {
+                        Constants.FIELD: member_name,
+                        Constants.TYPE: instance.__class__.__name__
+                    }
+                    raise SDKException(Constants.MANDATORY_VALUE_NULL_ERROR, Constants.MANDATORY_KEY_NULL_ERROR, error)
+
+            if is_primary and self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_UPDATE and self.common_api_handler.mandatory_checker is not None and self.common_api_handler.mandatory_checker:
+                error = {
+                    Constants.FIELD: member_name,
+                    Constants.TYPE: instance.__class__.__name__
+                }
+                raise SDKException(Constants.MANDATORY_VALUE_NULL_ERROR, Constants.MANDATORY_KEY_NULL_ERROR, error)
+
+    def get_wrapped_response(self, response, pack):
         try:
             return self.get_response(response.json(), pack)
 
@@ -297,7 +459,6 @@ class JSONConverter(Converter):
             return None
 
     def get_response(self, response, package_name):
-
         try:
             from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
         except Exception:
@@ -401,6 +562,7 @@ class JSONConverter(Converter):
             key_value = None
 
             if len(key_detail) > 0:
+                key_name = key_detail[Constants.NAME]
                 key_value = self.get_data(key_data, key_detail)
 
             else:
@@ -425,7 +587,8 @@ class JSONConverter(Converter):
                 member_value = self.get_map_data(key_data, member_detail)
 
             elif data_type == Constants.CHOICE_NAMESPACE or (
-                    Constants.STRUCTURE_NAME in member_detail and member_detail[Constants.STRUCTURE_NAME] == Constants.CHOICE_NAMESPACE):
+                    Constants.STRUCTURE_NAME in member_detail and member_detail[
+                Constants.STRUCTURE_NAME] == Constants.CHOICE_NAMESPACE):
                 member_value = self.__get_choice_instance(key_data)
 
             elif Constants.STRUCTURE_NAME in member_detail and Constants.MODULE in member_detail:
@@ -477,7 +640,7 @@ class JSONConverter(Converter):
                 elif Constants.MODULE in member_detail and member_detail[Constants.MODULE] is not None:
                     for response in responses:
                         values.append(self.is_record_response(response, self.__get_module_detail_from_user_spec_json(
-                            member_detail[Constants.MODULE])))
+                            member_detail[Constants.MODULE]), pack))
 
                 else:
                     for response in responses:
@@ -550,7 +713,8 @@ class JSONConverter(Converter):
                 if key_name is not None and key_name in response_json and response_json.get(key_name) is not None:
                     key_data = response_json[key_name]
                     data_type = type(key_data).__name__
-                    structure_name = member_detail[Constants.STRUCTURE_NAME] if Constants.STRUCTURE_NAME in member_detail else None
+                    structure_name = member_detail[
+                        Constants.STRUCTURE_NAME] if Constants.STRUCTURE_NAME in member_detail else None
 
                     if isinstance(key_data, dict):
                         data_type = Constants.MAP_NAMESPACE
@@ -558,7 +722,11 @@ class JSONConverter(Converter):
                     if isinstance(key_data, list):
                         data_type = Constants.LIST_NAMESPACE
 
-                    if data_type == member_detail[Constants.TYPE]:
+                    if data_type == member_detail[Constants.TYPE] or (
+                            member_detail[Constants.TYPE] in Constants.TYPE_VS_DATATYPE and isinstance(key_data,
+                                                                                                       Constants.TYPE_VS_DATATYPE[
+                                                                                                           member_detail[
+                                                                                                               Constants.TYPE]])):
                         matches += 1
 
                     elif member_detail[Constants.TYPE] == Constants.CHOICE_NAMESPACE:
