@@ -1,4 +1,3 @@
-
 import os
 
 
@@ -12,9 +11,11 @@ class StreamWrapper(object):
 
         """
         Creates a StreamWrapper class instance with the specified parameters.
-        :param name: A str containing the file name.
-        :param stream: A stream containing the file stream.
-        :param file_path: A str containing the absolute file path.
+
+        Parameters:
+            name (str) : A string containing the file name.
+            stream (stream) : A stream containing the file stream.
+            file_path (str) : A string containing the absolute file path.
         """
 
         if file_path is not None:
@@ -29,7 +30,9 @@ class StreamWrapper(object):
 
         """
         This is a getter method to get the file name.
-        :return: A str representing the file name.
+
+        Returns:
+            string : A string representing the file name.
         """
 
         return self.__name
@@ -38,7 +41,9 @@ class StreamWrapper(object):
 
         """
         This is a getter method to get the file input stream.
-        :return: A stream representing the file input stream.
+
+        Returns:
+            stream :  A stream representing the file stream.
         """
 
         return self.__stream
