@@ -11,7 +11,7 @@ try:
     from zcrmsdk.src.com.zoho.crm.api.util.constants import Constants
     from zcrmsdk.src.com.zoho.crm.api.util.converter import Converter
     from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
-    from zcrmsdk.src.com.zoho.api.exception import SDKException
+    from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
     from zcrmsdk.src.com.zoho.crm.api.header_map import HeaderMap
 
 except Exception:
@@ -27,7 +27,7 @@ except Exception:
     from .constants import Constants
     from .converter import Converter
     from ..initializer import Initializer
-    from zcrmsdk.src.com.zoho.api.exception import SDKException
+    from ..exception import SDKException
     from ..header_map import HeaderMap
 
 
@@ -35,10 +35,12 @@ class Utility(object):
     """
     This class handles module field details.
     """
+
     apitype_vs_datatype = {}
     apitype_vs_structurename = {}
     new_file = False
     get_modified_modules = False
+    force_refresh = False
     lock = threading.RLock()
     logger = logging.getLogger('SDKLogger')
 
@@ -57,67 +59,109 @@ class Utility(object):
         except Exception:
             from ..initializer import Initializer
 
-        with Utility.lock:
-            resources_path = os.path.join(Initializer.get_initializer().resource_path,
-                                          Constants.FIELD_DETAILS_DIRECTORY)
+        last_modified_time = None
 
-            if not os.path.exists(resources_path):
-                if Utility.search_json_details(module_api_name) is not None:
-                    return
-                os.makedirs(resources_path)
+        try:
+            with Utility.lock:
+                resources_path = os.path.join(Initializer.get_initializer().resource_path,
+                                              Constants.FIELD_DETAILS_DIRECTORY)
 
-            record_field_details_path = Utility.get_file_name()
+                if not os.path.exists(resources_path):
+                    if module_api_name is not None and Utility.search_json_details(module_api_name) is not None:
+                        return
+                    os.makedirs(resources_path)
 
-            if os.path.exists(record_field_details_path):
-                record_field_details_json = Initializer.get_json(record_field_details_path)
+                record_field_details_path = Utility.get_file_name()
 
-                if Initializer.get_initializer().auto_refresh_fields and not Utility.new_file and not Utility.get_modified_modules:
+                if os.path.exists(record_field_details_path):
+                    record_field_details_json = Initializer.get_json(record_field_details_path)
+
+                    if Initializer.get_initializer().auto_refresh_fields and not Utility.new_file and not Utility.get_modified_modules and (Constants.FIELDS_LAST_MODIFIED_TIME not in record_field_details_json or Utility.force_refresh or (time.time() * 1000 - record_field_details_json[Constants.FIELDS_LAST_MODIFIED_TIME]) > 3600000):
+                        Utility.get_modified_modules = True
+                        last_modified_time = record_field_details_json[Constants.FIELDS_LAST_MODIFIED_TIME] if Constants.FIELDS_LAST_MODIFIED_TIME in record_field_details_json else None
+                        Utility.modify_fields(record_field_details_path, last_modified_time)
+                        Utility.get_modified_modules = False
+
+                    elif not Initializer.get_initializer().auto_refresh_fields and Utility.force_refresh and not Utility.get_modified_modules:
+                        Utility.get_modified_modules = True
+                        Utility.modify_fields(record_field_details_path, last_modified_time)
+                        Utility.get_modified_modules = False
+
+                    record_field_details_json = Initializer.get_json(record_field_details_path)
+
+                    if module_api_name is None or module_api_name.lower() in record_field_details_json:
+                        return
+
+                    else:
+                        Utility.fill_data_type()
+                        record_field_details_json[module_api_name.lower()] = {}
+                        Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
+                        field_details = Utility.get_fields_details(module_api_name)
+                        record_field_details_json = Initializer.get_json(record_field_details_path)
+                        record_field_details_json[module_api_name.lower()] = field_details
+                        Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
+
+                elif Initializer.get_initializer().auto_refresh_fields:
+                    Utility.new_file = True
+                    Utility.fill_data_type()
+                    module_api_names = Utility.get_modules(None)
+                    record_field_details_json = {
+                        Constants.FIELDS_LAST_MODIFIED_TIME: time.time() * 1000
+                    }
+
+                    for module in module_api_names:
+                        if module.lower() not in record_field_details_json:
+                            record_field_details_json[module.lower()] = {}
+                            Utility.write_to_file(file_path=record_field_details_path,
+                                                  file_contents=record_field_details_json)
+                            field_details = Utility.get_fields_details(module)
+                            record_field_details_json = Initializer.get_json(record_field_details_path)
+                            record_field_details_json[module.lower()] = field_details
+                            Utility.write_to_file(file_path=record_field_details_path,
+                                                  file_contents=record_field_details_json)
+
+                    Utility.new_file = False
+
+                elif Utility.force_refresh and not Utility.get_modified_modules:
                     Utility.get_modified_modules = True
-                    Utility.modify_fields(record_field_details_path, record_field_details_json[
-                        Constants.FIELDS_LAST_MODIFIED_TIME] if Constants.FIELDS_LAST_MODIFIED_TIME in record_field_details_json else None)
+                    record_field_details_json = {}
+                    Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
+                    Utility.modify_fields(record_field_details_path, last_modified_time)
                     Utility.get_modified_modules = False
 
-                if module_api_name in Initializer.get_json(record_field_details_path):
-                    return
-
                 else:
                     Utility.fill_data_type()
-                    record_field_details_json[module_api_name] = {}
+                    record_field_details_json = {module_api_name.lower(): {}}
                     Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
                     field_details = Utility.get_fields_details(module_api_name)
                     record_field_details_json = Initializer.get_json(record_field_details_path)
-                    record_field_details_json[module_api_name] = field_details
+                    record_field_details_json[module_api_name.lower()] = field_details
                     Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
 
-            elif Initializer.get_initializer().auto_refresh_fields:
-                Utility.new_file = True
-                Utility.fill_data_type()
-                module_api_names = Utility.get_modules(None)
-                record_field_details_json = {
-                    Constants.FIELDS_LAST_MODIFIED_TIME: time.time() * 1000
-                }
+        except Exception as e:
+            if record_field_details_path is not None and os.path.exists(record_field_details_path):
+                try:
+                    record_field_details_json = Initializer.get_json(record_field_details_path)
+                    if module_api_name is not None and module_api_name.lower() in record_field_details_json:
+                        del record_field_details_json[module_api_name.lower()]
 
-                for module in module_api_names:
-                    if module not in record_field_details_json:
-                        record_field_details_json[module] = {}
-                        Utility.write_to_file(file_path=record_field_details_path,
-                                              file_contents=record_field_details_json)
-                        field_details = Utility.get_fields_details(module)
-                        record_field_details_json = Initializer.get_json(record_field_details_path)
-                        record_field_details_json[module] = field_details
-                        Utility.write_to_file(file_path=record_field_details_path,
-                                              file_contents=record_field_details_json)
+                    if Utility.new_file:
+                        if Constants.FIELDS_LAST_MODIFIED_TIME in record_field_details_json:
+                            del record_field_details_json[Constants.FIELDS_LAST_MODIFIED_TIME]
+                        Utility.new_file = False
 
-                Utility.new_file = False
+                    if Utility.get_modified_modules or Utility.force_refresh:
+                        Utility.get_modified_modules = False
+                        Utility.force_refresh = False
 
-            else:
-                Utility.fill_data_type()
-                record_field_details_json = {module_api_name: {}}
-                Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
-                field_details = Utility.get_fields_details(module_api_name)
-                record_field_details_json = Initializer.get_json(record_field_details_path)
-                record_field_details_json[module_api_name] = field_details
-                Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
+                        if last_modified_time is not None:
+                            record_field_details_json[Constants.FIELDS_LAST_MODIFIED_TIME] = last_modified_time
+
+                    Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
+                except Exception as ex:
+                    Utility.logger.info(Constants.EXCEPTION + ex.__str__())
+
+            Utility.logger.info(Constants.EXCEPTION + e.__str__())
 
     @staticmethod
     def modify_fields(record_field_details_path, modified_time):
@@ -127,14 +171,28 @@ class Utility(object):
         Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
         if len(modified_modules) > 0:
             for module in modified_modules:
-                if module in record_field_details_json:
-                    del record_field_details_json[module]
+                if module.lower() in record_field_details_json:
+                    Utility.delete_fields(record_field_details_json, module)
 
             Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
 
             for module in modified_modules:
                 Utility.get_fields(module)
 
+    @staticmethod
+    def delete_fields(record_field_details_json, module):
+        subform_modules = []
+        fields_json = record_field_details_json[module.lower()]
+        for key,value in fields_json.items():
+            if Constants.SUBFORM in value and value[Constants.SUBFORM]:
+                subform_modules.append(value[Constants.MODULE])
+
+        del record_field_details_json[module.lower()]
+
+        if len(subform_modules) > 0:
+            for subform_module in subform_modules:
+                Utility.delete_fields(record_field_details_json, subform_module)
+
     @staticmethod
     def get_file_name():
         return os.path.join(Initializer.get_initializer().resource_path, Constants.FIELD_DETAILS_DIRECTORY,
@@ -145,7 +203,7 @@ class Utility(object):
         with Utility.lock:
             try:
                 is_new_data = False
-                key = module_api_name + Constants.UNDERSCORE + Constants.RELATED_LISTS
+                key = (module_api_name + Constants.UNDERSCORE + Constants.RELATED_LISTS).lower()
                 resources_path = os.path.join(Initializer.get_initializer().resource_path,
                                               Constants.FIELD_DETAILS_DIRECTORY)
 
@@ -154,8 +212,7 @@ class Utility(object):
                 record_field_details_path = Utility.get_file_name()
 
                 if not os.path.exists(record_field_details_path) or (
-                        os.path.exists(record_field_details_path) and key not in Initializer.get_json(
-                    record_field_details_path)):
+                        os.path.exists(record_field_details_path) and key not in Initializer.get_json(record_field_details_path)):
                     is_new_data = True
                     related_list_values = Utility.get_related_list_details(module_api_name)
                     record_field_details_json = Initializer.get_json(record_field_details_path) if os.path.exists(
@@ -326,10 +383,16 @@ class Utility(object):
 
         return api_names
 
+    @staticmethod
+    def refresh_modules():
+        Utility.force_refresh = True
+        Utility.get_fields(None)
+        Utility.force_refresh = False
+
     @staticmethod
     def get_json_object(json, key):
         for key_in_json in json.keys():
-            if key_in_json == key:
+            if key_in_json.lower() == key.lower():
                 return json[key_in_json]
 
         return None
@@ -340,32 +403,39 @@ class Utility(object):
         module = ''
         key_name = field.get_api_name()
 
-        if key_name.lower() == Constants.PRODUCT_DETAILS.lower() and module_api_name in Constants.INVENTORY_MODULES:
+        if field.get_system_mandatory() is not None and field.get_system_mandatory() and not(module_api_name.lower() == Constants.CALLS and key_name.lower() == Constants.CALL_DURATION):
+            field_detail[Constants.REQUIRED] = True
+
+        if key_name.lower() == Constants.PRODUCT_DETAILS.lower() and module_api_name.lower() in Constants.INVENTORY_MODULES:
             field_detail[Constants.NAME] = key_name
             field_detail[Constants.TYPE] = Constants.LIST_NAMESPACE
             field_detail[Constants.STRUCTURE_NAME] = Constants.INVENTORY_LINE_ITEMS
+            field_detail[Constants.SKIP_MANDATORY] = True
 
             return
 
-        elif key_name.lower() == Constants.PRICING_DETAILS.lower() and module_api_name.lower() == Constants.PRICE_BOOKS.lower():
+        elif key_name.lower() == Constants.PRICING_DETAILS.lower() and module_api_name.lower() == Constants.PRICE_BOOKS:
             field_detail[Constants.NAME] = key_name
             field_detail[Constants.TYPE] = Constants.LIST_NAMESPACE
             field_detail[Constants.STRUCTURE_NAME] = Constants.PRICINGDETAILS
+            field_detail[Constants.SKIP_MANDATORY] = True
 
             return
 
         elif key_name.lower() == Constants.PARTICIPANT_API_NAME.lower() and (
-                module_api_name.lower() == Constants.EVENTS.lower() or module_api_name.lower() == Constants.ACTIVITIES.lower()):
+                module_api_name.lower() == Constants.EVENTS or module_api_name.lower() == Constants.ACTIVITIES):
             field_detail[Constants.NAME] = key_name
             field_detail[Constants.TYPE] = Constants.LIST_NAMESPACE
             field_detail[Constants.STRUCTURE_NAME] = Constants.PARTICIPANTS
+            field_detail[Constants.SKIP_MANDATORY] = True
 
             return
 
-        elif key_name.lower() == Constants.COMMENTS.lower() and module_api_name.lower() == Constants.SOLUTIONS.lower():
+        elif key_name.lower() == Constants.COMMENTS.lower() and (module_api_name.lower() == Constants.SOLUTIONS or module_api_name.lower() == Constants.CASES):
             field_detail[Constants.NAME] = key_name
             field_detail[Constants.TYPE] = Constants.LIST_NAMESPACE
             field_detail[Constants.STRUCTURE_NAME] = Constants.COMMENT_NAMESPACE
+            field_detail[Constants.LOOKUP] = True
 
             return
 
@@ -373,35 +443,53 @@ class Utility(object):
             field_detail[Constants.NAME] = key_name
             field_detail[Constants.TYPE] = Constants.LAYOUT_NAMESPACE
             field_detail[Constants.STRUCTURE_NAME] = Constants.LAYOUT_NAMESPACE
+            field_detail[Constants.LOOKUP] = True
 
             return
 
         elif api_type in Utility.apitype_vs_datatype:
             field_detail[Constants.TYPE] = Utility.apitype_vs_datatype.get(api_type)
 
+        elif api_type.lower() == Constants.FORMULA.lower():
+            if field.get_formula() is not None:
+                return_type = field.get_formula().get_return_type()
+                if return_type in Utility.apitype_vs_datatype:
+                    field_detail[Constants.TYPE] = Utility.apitype_vs_datatype.get(return_type)
+
+            field_detail[Constants.READ_ONLY] = True
+
         else:
             return
 
+        if Constants.LOOKUP in api_type.lower():
+            field_detail[Constants.LOOKUP] = True
+
         if api_type in Utility.apitype_vs_structurename:
             field_detail[Constants.STRUCTURE_NAME] = Utility.apitype_vs_structurename.get(api_type)
 
-        if field.get_pick_list_values() is not None and len(field.get_pick_list_values()) > 0:
-            values = list(map(lambda x: x.get_actual_value(), field.get_pick_list_values()))
-
+        if api_type.lower() == Constants.PICKLIST and field.get_pick_list_values() is not None and len(field.get_pick_list_values()) > 0:
+            values = list(map(lambda x: x.get_display_value(), field.get_pick_list_values()))
             field_detail[Constants.VALUES] = values
 
         if api_type == Constants.SUBFORM:
             module = field.get_subform().get_module()
-
             field_detail[Constants.MODULE] = module
+            field_detail[Constants.SKIP_MANDATORY] = True
+            field_detail[Constants.SUBFORM] = True
+
         if api_type == Constants.LOOKUP:
             module = field.get_lookup().get_module()
 
             if module is not None and not module == Constants.SE_MODULE:
                 field_detail[Constants.MODULE] = module
+                if module.lower() == Constants.ACCOUNTS and not field.get_custom_field():
+                    field_detail[Constants.SKIP_MANDATORY] = True
+
             else:
                 module = ''
 
+            field_detail[Constants.LOOKUP] = True
+
         if len(module) > 0:
             Utility.get_fields(module)
 
@@ -474,22 +562,18 @@ class Utility(object):
 
         for field_api_name in field_api_names_lookup:
             Utility.apitype_vs_datatype[field_api_name] = Constants.RECORD_NAMESPACE
-
             Utility.apitype_vs_structurename[field_api_name] = Constants.RECORD_NAMESPACE
 
         for field_api_name in field_api_names_owner_lookup:
             Utility.apitype_vs_datatype[field_api_name] = Constants.USER_NAMESPACE
-
             Utility.apitype_vs_structurename[field_api_name] = Constants.USER_NAMESPACE
 
         for field_api_name in field_api_names_multiuser_lookup:
             Utility.apitype_vs_datatype[field_api_name] = Constants.LIST_NAMESPACE
-
             Utility.apitype_vs_structurename[field_api_name] = Constants.USER_NAMESPACE
 
         for field_api_name in field_api_names_multimodule_lookup:
             Utility.apitype_vs_datatype[field_api_name] = Constants.LIST_NAMESPACE
-
             Utility.apitype_vs_structurename[field_api_name] = Constants.MODULE_NAMESPACE
 
         for field_api_name in field_api_names_picklist:
@@ -497,32 +581,26 @@ class Utility(object):
 
         for field_api_name in field_api_names_multiselect_picklist:
             Utility.apitype_vs_datatype[field_api_name] = Constants.LIST_NAMESPACE
-
             Utility.apitype_vs_structurename[field_api_name] = Constants.CHOICE_NAMESPACE
 
         for field_api_name in field_api_names_subform:
             Utility.apitype_vs_datatype[field_api_name] = Constants.LIST_NAMESPACE
-
             Utility.apitype_vs_structurename[field_api_name] = Constants.RECORD_NAMESPACE
 
         for field_api_name in field_api_names_field_file:
             Utility.apitype_vs_datatype[field_api_name] = Constants.LIST_NAMESPACE
-
             Utility.apitype_vs_structurename[field_api_name] = Constants.FIELD_FILE_NAMESPACE
 
         for field_api_name in field_api_name_task_remind_at:
             Utility.apitype_vs_datatype[field_api_name] = Constants.REMINDAT_NAMESPACE
-
             Utility.apitype_vs_structurename[field_api_name] = Constants.REMINDAT_NAMESPACE
 
         for field_api_name in field_api_name_recurring_activity:
             Utility.apitype_vs_datatype[field_api_name] = Constants.RECURRING_ACTIVITY_NAMESPACE
-
             Utility.apitype_vs_structurename[field_api_name] = Constants.RECURRING_ACTIVITY_NAMESPACE
 
         for field_api_name in field_api_name_reminder:
             Utility.apitype_vs_datatype[field_api_name] = Constants.LIST_NAMESPACE
-
             Utility.apitype_vs_structurename[field_api_name] = Constants.REMINDER_NAMESPACE
 
     @staticmethod
