@@ -1,13 +1,13 @@
 try:
+	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
 	from zcrmsdk.src.com.zoho.crm.api.parameter_map import ParameterMap
 	from zcrmsdk.src.com.zoho.crm.api.util import APIResponse, CommonAPIHandler, Constants
 	from zcrmsdk.src.com.zoho.crm.api.param import Param
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 except Exception:
+	from ..exception import SDKException
 	from ..parameter_map import ParameterMap
 	from ..util import APIResponse, CommonAPIHandler, Constants
 	from ..param import Param
-	from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class VariablesOperations(object):
@@ -24,6 +24,9 @@ class VariablesOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
@@ -34,6 +37,7 @@ class VariablesOperations(object):
 		api_path = api_path + '/crm/v2/settings/variables'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		handler_instance.param = param_instance
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.response_handler import ResponseHandler
@@ -50,6 +54,9 @@ class VariablesOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -57,7 +64,7 @@ class VariablesOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -65,8 +72,10 @@ class VariablesOperations(object):
 		api_path = api_path + '/crm/v2/settings/variables'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_POST
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.action_handler import ActionHandler
 		except Exception:
@@ -82,6 +91,9 @@ class VariablesOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -89,7 +101,7 @@ class VariablesOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -97,8 +109,10 @@ class VariablesOperations(object):
 		api_path = api_path + '/crm/v2/settings/variables'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
+		handler_instance.mandatory_checker = True
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.action_handler import ActionHandler
 		except Exception:
@@ -114,6 +128,9 @@ class VariablesOperations(object):
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
@@ -124,6 +141,7 @@ class VariablesOperations(object):
 		api_path = api_path + '/crm/v2/settings/variables'
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
 		handler_instance.param = param_instance
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.action_handler import ActionHandler
@@ -137,16 +155,19 @@ class VariablesOperations(object):
 
 		Parameters:
 			param_instance (ParameterMap) : An instance of ParameterMap
-			id (int) : A int value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if not isinstance(id, int):
+		if id is not None and not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -155,6 +176,7 @@ class VariablesOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		handler_instance.param = param_instance
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.response_handler import ResponseHandler
@@ -168,10 +190,13 @@ class VariablesOperations(object):
 
 		Parameters:
 			request (BodyWrapper) : An instance of BodyWrapper
-			id (int) : A int value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -179,10 +204,10 @@ class VariablesOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
-		if not isinstance(id, int):
+		if id is not None and not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -191,6 +216,7 @@ class VariablesOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
 		try:
@@ -204,13 +230,16 @@ class VariablesOperations(object):
 		The method to delete variable
 
 		Parameters:
-			id (int) : A int value
+			id (int) : An int representing the id
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
-		if not isinstance(id, int):
+		if id is not None and not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -219,6 +248,7 @@ class VariablesOperations(object):
 		api_path = api_path + str(id)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.action_handler import ActionHandler
 		except Exception:
@@ -231,16 +261,19 @@ class VariablesOperations(object):
 
 		Parameters:
 			param_instance (ParameterMap) : An instance of ParameterMap
-			api_name (string) : A string value
+			api_name (string) : A string representing the api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if not isinstance(api_name, str):
+		if api_name is not None and not isinstance(api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -249,6 +282,7 @@ class VariablesOperations(object):
 		api_path = api_path + str(api_name)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_GET
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
 		handler_instance.param = param_instance
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.variables.response_handler import ResponseHandler
@@ -262,10 +296,13 @@ class VariablesOperations(object):
 
 		Parameters:
 			request (BodyWrapper) : An instance of BodyWrapper
-			api_name (string) : A string value
+			api_name (string) : A string representing the api_name
 
 		Returns:
 			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
 		"""
 
 		try:
@@ -273,10 +310,10 @@ class VariablesOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if not isinstance(request, BodyWrapper):
+		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
-		if not isinstance(api_name, str):
+		if api_name is not None and not isinstance(api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -285,6 +322,7 @@ class VariablesOperations(object):
 		api_path = api_path + str(api_name)
 		handler_instance.api_path = api_path
 		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
+		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
 		handler_instance.content_type = 'application/json'
 		handler_instance.request = request
 		try:
@@ -308,4 +346,3 @@ class GetVariableByIDParam(object):
 
 class GetVariableForAPINameParam(object):
 	group = Param('group', 'com.zoho.crm.api.Variables.GetVariableForAPINameParam')
-
